@@ -49,25 +49,20 @@ void CurvePlacementWidget::setCurrentPlot( const QString & p )
 
 void CurvePlacementWidget::newWindow()
 {
-    KstApp *app = KstApp::inst();
-    app->slotFileNewWindow(this);
+    KstData::self()->newWindow(this);
     update();
 }
 
 void CurvePlacementWidget::update()
 {
-    KstApp *app = KstApp::inst();
-
     _plotWindow->clear();
-    KMdiIterator<KMdiChildView*> *it = app->createIterator();
-    while (it->currentItem()) {
-	_plotWindow->insertItem(it->currentItem()->caption());
-	it->next();
+    QStringList windows = KstData::self()->windowList();
+    for (QStringList::ConstIterator i = windows.begin(); i != windows.end(); ++i) {
+	_plotWindow->insertItem(*i);
     }
-    app->deleteIterator(it);
-    KMdiChildView *c = app->activeWindow();
-    if (c) {
-	_plotWindow->setCurrentItem(c->caption());
+    QString cur = KstData::self()->currentWindow();
+    if (!cur.isEmpty()) {
+	_plotWindow->setCurrentItem(cur);
     }
 
     updatePlotList();
@@ -79,26 +74,19 @@ void CurvePlacementWidget::update()
 
 void CurvePlacementWidget::updatePlotList()
 {
-    KstApp *app = KstApp::inst();
-    KMdiChildView *c = app->findWindow(_plotWindow->currentText());
-
     QString old;
     if (_plotList->count()) {
 	old = _plotList->currentText();
     }
 
+    QStringList plots = KstData::self()->plotList(_plotWindow->currentText());
     _plotList->clear();
-    if (c) {
-	Kst2DPlotList plots = static_cast<KstViewWindow*>(c)->view()->findChildrenType<Kst2DPlot>();
+    for (QStringList::ConstIterator i = plots.begin(); i != plots.end(); ++i) {
+	_plotList->insertItem(*i);
+    }
 
-	Kst2DPlotList::Iterator i = plots.begin();
-	for ( ; i != plots.end(); ++i) {
-	    _plotList->insertItem((*i)->tagName());
-	}
-
-	if (!old.isNull() && _plotList->count() > 0) {
-	    _plotList->setCurrentText(old);
-	}
+    if (!old.isNull() && _plotList->count() > 0) {
+	_plotList->setCurrentText(old);
     }
 }
 
@@ -117,13 +105,10 @@ void CurvePlacementWidget::updateEnabled()
 
 void CurvePlacementWidget::updateGrid()
 {
-    KstApp *app = KstApp::inst();
-    KMdiChildView *c = app->findWindow(_plotWindow->currentText());
-    KstViewWindow *w = dynamic_cast<KstViewWindow*>(c);
-    if (w) {
-	KstTopLevelViewPtr view = w->view();
-	_reGrid->setChecked(view->onGrid());
-	_plotColumns->setValue(view->columns());
+    int cols = KstData::self()->columns(_plotWindow->currentText());
+    _reGrid->setChecked(cols > -1);
+    if (cols > -1) {
+	_plotColumns->setValue(cols);
     }
 }
 
