@@ -331,7 +331,7 @@ double Object::timeForSample(int sample) {
 }
 
 
-int Object::sampleForTimeRelative(int search, bool *ok) {
+int Object::sampleForTimeRelative(double ms, bool *ok) {
   if (_tt == Undetermined) {
     _tt = typeOfTime();
   }
@@ -350,11 +350,11 @@ int Object::sampleForTimeRelative(int search, bool *ok) {
     }
     return -1;
   }
-  return sampleForTime(int(floor(left + 0.5)) + search, ok);
+  return sampleForTime(floor(left + 0.5) + ms / 1000, ok);
 }
 
 
-int Object::sampleForTime(int search, bool *ok) {
+int Object::sampleForTime(double ms, bool *ok) {
   PIOLONG location = -1;
   bool found = false;
 
@@ -374,7 +374,7 @@ int Object::sampleForTime(int search, bool *ok) {
   PIOLONG LastIndex = *g->lastIndex;
   double left = fetchTimePoint(FirstIndex);
   double right = fetchTimePoint(LastIndex);
-  double sch = search;
+  double sch = ms;
 
   if (sch >= left && sch <= right) {
     if (sch == left) {
