@@ -43,24 +43,54 @@ void DataWizard::init()
     _url->setURL(default_source);
     _url->completionObject()->setDir(QDir::currentDirPath());
     _url->setFocus();
+    
+    // x vector selection
+    connect(_xAxisCreateFromField, SIGNAL(toggled(bool)), _xVector, SLOT(setEnabled(bool)));
+    connect(_xAxisUseExisting, SIGNAL(toggled(bool)), _xVectorExisting, SLOT(setEnabled(bool)));
+    connect(_xAxisCreateFromField, SIGNAL(clicked()), this, SLOT(xChanged()));
+    connect(_xAxisUseExisting, SIGNAL(clicked()), this, SLOT(xChanged()));
+    _xAxisCreateFromField->setChecked(true);
+    _xVectorExisting->setEnabled(false);
+    _xVectorExisting->_newVector->hide();
+    _xVectorExisting->_editVector->hide();
 }
 
 
-void DataWizard::plotColsChanged() {
-  _reGrid->setChecked(true);
+void DataWizard::destroy()
+{
+    delete _configWidget;
+}
+
+
+void DataWizard::setInput(const QString& input)
+{
+    _url->setURL(input);
+}
+
+
+void DataWizard::plotColsChanged()
+{
+    _reGrid->setChecked(true);
 }
 
 
 bool DataWizard::xVectorOk()
 {
-    QString txt = _xVector->currentText();
+    if (!_xAxisGroup->isEnabled()) {
+	return true;
+    }
 
-    for (int i = 0; i < _xVector->count(); ++i) {
-      if (_xVector->text(i) == txt) {
-       return true;
-      }
+    if (_xAxisCreateFromField->isChecked()) {
+	QString txt = _xVector->currentText();
+	for (int i = 0; i < _xVector->count(); ++i) {
+	    if (_xVector->text(i) == txt) {
+		return true;
+	    }
+	}
+	return false;
+    } else {
+	return (KST::vectorList.findTag(_xVectorExisting->selectedVector()) != KST::vectorList.end());
     }
-    return false;
 }
 
 
@@ -69,29 +99,20 @@ bool DataWizard::yVectorsOk()
     QListViewItemIterator it(_vectors);
 
     while (it.current()) {
-	QCheckListItem *i = static_cast<QCheckListItem*>(it.current());
-	if (i->isOn()) {
-	    return true;
-	}
-	++it;
+      QCheckListItem *i = static_cast<QCheckListItem*>(it.current());
+      if (i->isOn()) {
+          return true;
+      }
+      ++it;
     }
 
     return false;
 }
 
 
-void DataWizard::xChanged(const QString& txt)
+void DataWizard::xChanged()
 {
-    bool found = false;
-
-    for (int i = 0; i < _xVector->count(); ++i) {
-	if (_xVector->text(i) == txt) {
-	    found = true;
-	    break;
-	}
-    }
-
-    setNextEnabled(_pageVectors, found && yVectorsOk());
+  setNextEnabled(_pageVectors, xVectorOk() && yVectorsOk());
 }
 
 
@@ -145,9 +166,11 @@ void DataWizard::sourceChanged(const QString& text)
 	int count;
 
 	if (ds) {
+	    ds->readLock();
 	    fl = ds->fieldList();
 	    fileType = ds->fileType();
 	    complete = ds->fieldListIsComplete();
+	    ds->readUnlock();
 	    ds = 0L;
 	} else {
 	    fl = KstDataSource::fieldListForSource(file, QString::null, &fileType, &complete);
@@ -155,7 +178,9 @@ void DataWizard::sourceChanged(const QString& text)
 
 	if (!fl.isEmpty() && !fileType.isEmpty()) {
 	    if (ds) {
+		ds->writeLock();
 		_configWidget = ds->configWidget();
+		ds->writeUnlock();
 	    } else {
 		_configWidget = KstDataSource::configWidgetForSource(file, fileType);
 	    }
@@ -188,15 +213,17 @@ void DataWizard::sourceChanged(const QString& text)
 	    QString str;
 	    str.sprintf("%0*d", count, index);
 	    pItem->setText(1, str);
-	    index++;
+	    ++index;
 	}
 	_vectors->sort();
 
 	KST::vectorDefaults.sync();
 	QString defaultX = KST::vectorDefaults.wizardXVector();
-	if (defaultX == "INDEX" || fl.contains(defaultX)) {
+	if (fl.contains(defaultX)) {
 	    _xVector->setCurrentText(defaultX);
-	}
+	} else {
+	    _xVector->setCurrentItem(0);
+	}                
 	_file = file;
     } else {
 	_fileType->setText(QString::null);
@@ -226,12 +253,16 @@ void DataWizard::showPage( QWidget *page )
 	if (!ds) {
 	    ds = KstDataSource::loadSource(_file);
 	}
+	ds->readLock();
 	_kstDataRange->setAllowTime(ds && ds->supportsTimeConversions());
+	ds->readUnlock();
 	_vectorReduction->setFocus();
     } else if (page == _pageFilters) {
 	QString save = _filterList->currentText();
 	_filterList->clear();
     } else if (page == _pagePlot) {
+	QString vectorName = _xAxisCreateFromField->isChecked() ? 
+	    _xVector->currentText() : _xVectorExisting->selectedVector();
 	KST::vectorDefaults.setWizardXVector(_xVector->currentText());
 	KST::vectorDefaults.sync();
 
@@ -241,7 +272,7 @@ void DataWizard::showPage( QWidget *page )
 	while (it.current()) {
 	    QCheckListItem *i = static_cast<QCheckListItem*>(it.current());
 	    if (i->isOn()) {
-		n_curves++;
+		++n_curves;
 	    }
 	    ++it;
 	}
@@ -309,11 +340,9 @@ void DataWizard::updateColumns()
 	v = static_cast<KstViewWindow*>(KstApp::inst()->findWindow(_windowName->currentText()));
     }
 
-    if (v) {
-	if (v->view()->onGrid()) {
-	    _plotColumns->setValue(v->view()->columns());
-	    _reGrid->setChecked(true);
-	}
+    if (v && v->view()->onGrid()) {
+	_plotColumns->setValue(v->view()->columns());
+	_reGrid->setChecked(true);
     }
 }
 
@@ -346,7 +375,7 @@ void DataWizard::updatePlotBox()
 	    plots += v->view()->findChildrenType<Kst2DPlot>();
 	}
 
-	for (Kst2DPlotList::Iterator i = plots.begin(); i != plots.end(); ++i) {
+	for (Kst2DPlotList::ConstIterator i = plots.begin(); i != plots.end(); ++i) {
 	    _existingPlotName->insertItem((*i)->tagName());
 	}
 
@@ -364,7 +393,7 @@ void DataWizard::updatePlotBox()
 	_onePlot->setChecked(true);
     }
 
-    if (_existingPlot->isEnabled() && _existingPlotName->listBox()->findItem(psave)) {
+    if (_existingPlot->isEnabled() && _existingPlotName->listBox() && _existingPlotName->listBox()->findItem(psave)) {
 	_existingPlotName->setCurrentText(psave);
     }
     updateColumns();
@@ -448,7 +477,7 @@ void DataWizard::finished()
     uint n_steps = 0;
     int ptype = 0;
     int prg = 0;
-
+  
     KstDataSourcePtr ds = *KST::dataSourceList.findReusableFileName(_file);
     if (!ds) {
 	ds = KstDataSource::loadSource(_file);
@@ -469,30 +498,46 @@ void DataWizard::finished()
     memoryAvailable = S(kb_main_free + kb_main_buffers + kb_main_cached);
 #endif
 
+    ds->writeLock();
     int f0Value, nValue;
-    if (_kstDataRange->isTime()) {
+    if (_kstDataRange->isStartAbsoluteTime()) {
+	f0Value = ds->sampleForTime(_kstDataRange->f0DateTimeValue());
+    } else if (_kstDataRange->isStartRelativeTime()) {
 	f0Value = ds->sampleForTime(_kstDataRange->f0Value());
-	nValue = ds->sampleForTime(_kstDataRange->nValue());
     } else {
-	f0Value = _kstDataRange->f0Value();
-	nValue = _kstDataRange->nValue();
+	f0Value = int(_kstDataRange->f0Value());
+    }
+    if (_kstDataRange->isRangeRelativeTime()) {
+	double nValStored = _kstDataRange->nValue();
+	if (_kstDataRange->CountFromEnd->isChecked()) {
+	    int frameCount = ds->frameCount(_xVector->currentText());
+	    double msCount = ds->relativeTimeForSample(frameCount - 1);
+	    nValue = frameCount - 1 - ds->sampleForTime(msCount - nValStored);
+	} else {
+	    double fTime = ds->relativeTimeForSample(f0Value);
+	    nValue = ds->sampleForTime(fTime + nValStored) - ds->sampleForTime(fTime);
+	}
+    } else {
+	nValue = int(_kstDataRange->nValue());
     }
 
-    if (_kstDataRange->ReadToEnd->isChecked()) {
-	frames = ds->frameCount(_xVector->currentText()) - f0Value;
-    } else {
-	frames = _kstDataRange->nValue();
-	if (frames > (unsigned long)ds->frameCount(_xVector->currentText())) {
-	    frames = ds->frameCount(_xVector->currentText());
+    // only add to memory requirement if xVector is to be created 
+    if (_xAxisCreateFromField->isChecked()) {
+	if (_kstDataRange->ReadToEnd->isChecked()) {
+	    frames = ds->frameCount(_xVector->currentText()) - f0Value;
+	} else {
+	    frames = kMin(nValue, ds->frameCount(_xVector->currentText()));
+	}
+
+	if (_kstDataRange->DoSkip->isChecked()) {
+	    memoryRequested += frames / _kstDataRange->Skip->value() * sizeof(double);
+	} else {
+	    memoryRequested += frames * ds->samplesPerFrame(_xVector->currentText())*sizeof(double);
 	}
     }
 
-    if (_kstDataRange->DoSkip->isChecked()) {
-	memoryRequested += frames / _kstDataRange->Skip->value() * sizeof(double);
-    } else {
-	memoryRequested += frames * ds->samplesPerFrame(_xVector->currentText())*sizeof(double);
-    }
 
+    // memory estimate for the y vectors
     {
 	QListViewItemIterator it(_vectors);
 	int fftLen = int(pow(2.0, double(_kstFFTOptions->FFTLen->text().toInt() - 1)));
@@ -523,8 +568,10 @@ void DataWizard::finished()
 	}
     }
 
+
+    ds->writeUnlock();
     if (memoryRequested > memoryAvailable) {
-	KMessageBox::sorry(this, i18n("You requested to read in %1 MB of data but it seems that you only have approximately %2 MB of usable memory available.  Please load less data.").arg(memoryRequested/(1024*1024)).arg(memoryAvailable/(1024*1024)));
+	KMessageBox::sorry(this, i18n("You requested to read in %1 MB of data but it seems that you only have approximately %2 MB of usable memory available.  You cannot load this much data.").arg(memoryRequested/(1024*1024)).arg(memoryAvailable/(1024*1024)));
 	return;
     }
 
@@ -550,18 +597,28 @@ void DataWizard::finished()
 	}
     }
 
-    n_steps += 1; // for the creation of the x-vector
-    prg = 0;
-    app->slotUpdateProgress(n_steps, prg, i18n("Creating vectors..."));
+    KstVectorPtr xv;
+    
+    // only create x vector if needed
+    if (_xAxisCreateFromField->isChecked()) {
+	n_steps += 1; // for the creation of the x-vector
+	prg = 0;
+	app->slotUpdateProgress(n_steps, prg, i18n("Creating vectors..."));
 
-    // create the x-vector
-    KstVectorPtr xv = new KstRVector(ds, _xVector->currentText(),
-	    name, _kstDataRange->CountFromEnd->isChecked() ? -1 : f0Value,
-	    _kstDataRange->ReadToEnd->isChecked() ? -1 : nValue,
-	    _kstDataRange->DoSkip->isChecked() ? _kstDataRange->Skip->value() : 0, _kstDataRange->DoSkip->isChecked(),
-	    _kstDataRange->DoFilter->isChecked());
-    KST::addVectorToList(xv);
-    app->slotUpdateProgress(n_steps, ++prg, i18n("Creating vectors..."));
+	// create the x-vector
+	xv = new KstRVector(ds, _xVector->currentText(),
+		name, _kstDataRange->CountFromEnd->isChecked() ? -1 : f0Value,
+		_kstDataRange->ReadToEnd->isChecked() ? -1 : nValue,
+		_kstDataRange->DoSkip->isChecked() ? _kstDataRange->Skip->value() : 0, 
+		_kstDataRange->DoSkip->isChecked(),
+		_kstDataRange->DoFilter->isChecked());
+	KST::addVectorToList(xv);
+
+	app->slotUpdateProgress(n_steps, ++prg, i18n("Creating vectors..."));
+    } else {
+	xv = *(KST::vectorList.findTag(_xVectorExisting->selectedVector()));
+	app->slotUpdateProgress(n_steps, prg, i18n("Creating vectors..."));
+    }
 
     // create the y-vectors
     {
@@ -572,17 +629,17 @@ void DataWizard::finished()
 	    QCheckListItem *i = static_cast<QCheckListItem*>(it.current());
 	    if (i->isOn()) {
 		vectorCount = KST::vectorList.count();
+		name = KST::suggestVectorName(it.current()->text(0));
 
-                name = KST::suggestVectorName(it.current()->text(0));
-                
 		KstVectorPtr v = new KstRVector(ds, it.current()->text(0), name,
 			_kstDataRange->CountFromEnd->isChecked() ? -1 : f0Value,
 			_kstDataRange->ReadToEnd->isChecked() ? -1 : nValue,
-			_kstDataRange->DoSkip->isChecked() ? _kstDataRange->Skip->value() : 0, _kstDataRange->DoSkip->isChecked(),
+			_kstDataRange->DoSkip->isChecked() ? _kstDataRange->Skip->value() : 0, 
+			_kstDataRange->DoSkip->isChecked(),
 			_kstDataRange->DoFilter->isChecked());
 		KST::addVectorToList(v);
 		l.append(v);
-		n_curves++;
+		++n_curves;
 		app->slotUpdateProgress(n_steps, ++prg, i18n("Creating vectors..."));
 	    }
 	    ++it;
@@ -593,11 +650,20 @@ void DataWizard::finished()
     QString newName;
     KstViewWindow *w;
     if (_newWindow->isChecked() || _newWindows->isChecked()) {
-	newName = _newWindowName->text();
-	if (newName == defaultTag) {
-	    newName = KST::suggestWinName();
+	w = dynamic_cast<KstViewWindow*>(app->activeWindow());
+	if (w && w->view()->children().isEmpty()) {
+	    // Use the existing view
+	    newName = w->caption();
+	    if (newName.isEmpty()) {
+		newName = w->tabCaption();
+	    }
+	} else {
+	    newName = _newWindowName->text();
+	    if (newName == defaultTag) {
+		newName = KST::suggestWinName();
+	    }
+	    w = static_cast<KstViewWindow*>(app->findWindow(app->newWindow(newName)));
 	}
-	w = static_cast<KstViewWindow*>(app->findWindow(app->newWindow(newName)));
     } else if (_currentWindow->isChecked()) {
 	w = static_cast<KstViewWindow*>(app->activeWindow());
     } else {
@@ -626,8 +692,8 @@ void DataWizard::finished()
 	    }
 	    Kst2DPlotPtr p = kst_cast<Kst2DPlot>(w->view()->findChild(w->createPlot<Kst2DPlot>(KST::suggestPlotName(), false)));
 	    plots.append(p.data());
-	    p->setXAxisInterpretation(false, KstAxisInterpretation(), KstAxisDisplay(), true, 0.0);
-	    p->setYAxisInterpretation(false, KstAxisInterpretation(), KstAxisDisplay(), true, 0.0);
+	    p->setXAxisInterpretation(false, KstAxisInterpretation(), KstAxisDisplay());
+	    p->setYAxisInterpretation(false, KstAxisInterpretation(), KstAxisDisplay());
 	}
     } else if (_multiplePlots->isChecked()) {
 	Kst2DPlotPtr p;
@@ -645,8 +711,8 @@ void DataWizard::finished()
 	    for (uint i = 0; i < l.count(); ++i) {
 		p = kst_cast<Kst2DPlot>(w->view()->findChild(w->createPlot<Kst2DPlot>(KST::suggestPlotName(), false)));
 		plots.append(p.data());
-		p->setXAxisInterpretation(false, KstAxisInterpretation(), KstAxisDisplay(), true, 0.0);
-		p->setYAxisInterpretation(false, KstAxisInterpretation(), KstAxisDisplay(), true, 0.0);
+		p->setXAxisInterpretation(false, KstAxisInterpretation(), KstAxisDisplay());
+		p->setYAxisInterpretation(false, KstAxisInterpretation(), KstAxisDisplay());
 	    }
 	}
     } else if (_existingPlot->isChecked()) {
@@ -674,12 +740,11 @@ void DataWizard::finished()
 	    for (int i = 0; i < _plotNumber->value(); ++i) {
 		p = kst_cast<Kst2DPlot>(w->view()->findChild(w->createPlot<Kst2DPlot>(KST::suggestPlotName(), false)));
 		plots.append(p.data());
-		p->setXAxisInterpretation(false, KstAxisInterpretation(), KstAxisDisplay(), true, 0.0);
-		p->setYAxisInterpretation(false, KstAxisInterpretation(), KstAxisDisplay(), true, 0.0);
+		p->setXAxisInterpretation(false, KstAxisInterpretation(), KstAxisDisplay());
+		p->setYAxisInterpretation(false, KstAxisInterpretation(), KstAxisDisplay());
 	    }
 	}
     }
-
     // create the data curves
     app->slotUpdateProgress(n_steps, prg, i18n("Creating curves..."));
     KstViewObjectList::Iterator pit = plots.begin();
@@ -688,12 +753,13 @@ void DataWizard::finished()
           name = KST::suggestCurveName((*it)->tagName(), false);
 	    Kst2DPlotPtr plot = kst_cast<Kst2DPlot>(*pit);
 	    if (plot) {
-		color = KstColorSequence::next(plot->Curves, plot->backgroundColor());
+		KstVCurveList vcurves = kstObjectSubList<KstBaseCurve,KstVCurve>(plot->Curves);
+		color = KstColorSequence::next(vcurves, plot->backgroundColor());
 	    } else {
 		color = KstColorSequence::next();
 	    }
 	    colors.append(color);
-	    KstBaseCurvePtr c = new KstVCurve(name, xv, *it, 0L, 0L, 0L, 0L, color);
+	    KstVCurvePtr c = new KstVCurve(name, xv, *it, 0L, 0L, 0L, 0L, color);
 	    if (_drawBoth->isChecked()) {
 		c->setHasPoints(true);
 		c->Point.setType(ptype++ % KSTPOINT_MAXTYPE);
@@ -710,7 +776,7 @@ void DataWizard::finished()
 	    KST::dataObjectList.append(KstDataObjectPtr(c));
 	    KST::dataObjectList.lock().writeUnlock();
 	    if (plot) {
-		plot->addCurve(c);
+		plot->addCurve(KstBaseCurvePtr(c));
 	    }
 	    if (!_onePlot->isChecked()) { // change plots if we are not onePlot
 		if (_radioButtonPlotDataPSD->isChecked()) { // if xy and psd
@@ -767,11 +833,14 @@ void DataWizard::finished()
 			_kstFFTOptions->Apodize->isChecked(),
 			_kstFFTOptions->RemoveMean->isChecked(),
 			_kstFFTOptions->VectorUnits->text(),
-			_kstFFTOptions->RateUnits->text());
+			_kstFFTOptions->RateUnits->text(), 
+			_kstFFTOptions->ApodizeFxn->currentItem(),
+			_kstFFTOptions->Sigma->value());
 		if (_radioButtonPlotPSD->isChecked() || colors.count() <= (unsigned long)indexColor) {
-                  c = new KstVCurve(KST::suggestCurveName(name, true), p->vX(), p->vY(), 0L, 0L, 0L, 0L, KstColorSequence::next(plot->Curves, plot->backgroundColor()));
+		    KstVCurveList vcurves = kstObjectSubList<KstBaseCurve,KstVCurve>(plot->Curves);
+		    c = new KstVCurve(KST::suggestCurveName(name, true), p->vX(), p->vY(), 0L, 0L, 0L, 0L, KstColorSequence::next(vcurves, plot->backgroundColor()));
 		} else {
-                  c = new KstVCurve(KST::suggestCurveName(name, true), p->vX(), p->vY(), 0L, 0L, 0L, 0L, colors[indexColor]);
+		    c = new KstVCurve(KST::suggestCurveName(name, true), p->vX(), p->vY(), 0L, 0L, 0L, 0L, colors[indexColor]);
 		    indexColor++;
 		}
 		if (_drawBoth->isChecked()) {
@@ -818,28 +887,14 @@ void DataWizard::finished()
 	    ++pit;
 	    continue;
 	}
-	pp->GenerateDefaultLabels();
-	if (!xl) {
-	    pp->setXLabel(QString::null);
-	}
-	if (!yl) {
-	    pp->setYLabel(QString::null);
-	}
-	if (!tl) {
-	    pp->setTopLabel(QString::null);
-	}
+	pp->generateDefaultLabels(xl, yl, tl);
 	if (_legendsOn->isChecked()) {
-	    pp->Legend->setShow(true);
-	    pp->Legend->setFront(true);
-	} else if (_legendsOff->isChecked()) {
-	    pp->Legend->setShow(false);
+            pp->getOrCreateLegend();
 	} else if (_legendsAuto->isChecked()) {
 	    if (pp->Curves.count() > 1) {
-		pp->Legend->setShow(true);
-		pp->Legend->setFront(true);
+                pp->getOrCreateLegend();
 	    }
 	}
-
 	++pit;
     }
 
@@ -854,7 +909,7 @@ void DataWizard::finished()
     } else if (w->view()->onGrid()) {
 	w->view()->cleanup(-1);
     }
-    w->view()->paint(P_PAINT);
+    w->view()->paint(KstPainter::P_PAINT);
     app->slotUpdateProgress(0, 0, QString::null);
     if (!wasPaused) {
 	app->setPaused(false);
@@ -870,15 +925,15 @@ void DataWizard::applyFiltersChecked( bool on )
 
 void DataWizard::enableXEntries()
 {
-    _xVector->setEnabled(true);
-    _xvectLabel->setEnabled(true);
+    _xAxisGroup->setEnabled(true);
+    xChanged();
 }
 
 
 void DataWizard::disableXEntries()
 {
-    _xVector->setEnabled(false);
-    _xvectLabel->setEnabled(false);
+    _xAxisGroup->setEnabled(false);
+    xChanged();
 }
 
 
