@@ -20,6 +20,7 @@
 
 #include "kststring.h"
 #include "kstvector.h"
+#include "kst_export.h"
 
 class Plugin;
 
@@ -29,12 +30,12 @@ class Plugin;
 namespace Equation {
 
   /* Global lock for the parser */
-  QMutex& mutex();
+  KST_EXPORT QMutex& mutex();
 
   /*    Evaluate the expression @p txt and returns the value as a double.
    *    Returns the value, or 0.0 and sets ok = false on error.
    */
-  double interpret(const char *txt, bool *ok = 0L);
+  KST_EXPORT double interpret(const char *txt, bool *ok = 0L);
 
   class Context {
     public:
@@ -194,6 +195,9 @@ namespace Equation {
       QString _tagName;
       KstVectorPtr _vector;
       KstScalarPtr _scalar;
+      bool _isEquation;
+      Node *_equation;
+      QString _vectorIndex;
   };
 
   class NodeVisitor {
@@ -206,7 +210,7 @@ namespace Equation {
   };
 
 
-  class FoldVisitor : public NodeVisitor {
+  class KST_EXPORT FoldVisitor : public NodeVisitor {
     public:
       FoldVisitor(Context*, Node**);
       ~FoldVisitor();
