@@ -17,21 +17,16 @@
 
 #include "elog.h"
 #include "elogeventthreadsubmit.h"
-#include "elogthreadsubmit.h"
-#include "elogthreadattrs.h"
+#include "elogbasicthreadsubmit.h"
 
-#include <kaction.h>
 #include <kapplication.h>
-#include <kfiledialog.h>
 #include <kgenericfactory.h>
-#include <kmdimainfrm.h>
-#include <kmessagebox.h>
+
 #include <kst.h>
-#include <kstevents.h>
 
 K_EXPORT_COMPONENT_FACTORY(kstextension_elog, KGenericFactory<KstELOG>)
 
-KstELOG::KstELOG(QObject *parent, const char *name, const QStringList& l) : KstExtension(parent, name, l), KXMLGUIClient() {
+KstELOG::KstELOG(QObject *parent, const char *name, const QStringList& list) : KstExtension(parent, name, list), KXMLGUIClient() {
   QCustomEvent eventAlive(KstELOGAliveEvent);
 
   new KAction(i18n("&ELOG..."), 0, 0, this, SLOT(doShow()), actionCollection(), "elog_settings_show");
@@ -106,7 +101,7 @@ void KstELOG::submitEventEntry(const QString& strMessage) {
                                  eventEntry()->attributes(),
                                  configuration()->submitAsHTML(),
                                  configuration()->suppressEmail());
-  pThread->start();
+  pThread->doTransmit();
 }
 
 
@@ -114,8 +109,7 @@ void KstELOG::submitEntry() {
   ElogThreadSubmit* pThread;
   KstELOGCaptureStruct captureStruct;
   QByteArray	byteArrayCapture;
-  QByteArray	byteArrayCaptureRaw;
-  QDataStream dataStreamCapture( byteArrayCaptureRaw, IO_ReadWrite );
+  QDataStream dataStreamCapture( byteArrayCapture, IO_ReadWrite );
   QCustomEvent eventCapture(KstELOGCaptureEvent);
 
   if( entry()->includeCapture() ) {
@@ -125,12 +119,9 @@ void KstELOG::submitEntry() {
     eventCapture.setData( &captureStruct );
 
     QApplication::sendEvent( (QObject*)app(), (QEvent*)&eventCapture );
-    if( byteArrayCaptureRaw.size() > 0 ) {
-      byteArrayCapture.duplicate( byteArrayCaptureRaw.data() + 4, byteArrayCaptureRaw.size() - 4 );
-    }
   }
 
-  pThread = new ElogThreadSubmit(this,
+  pThread = new ElogBasicThreadSubmit(this,
                                  entry()->includeCapture(),
                                  entry()->includeConfiguration(),
                                  entry()->includeDebugInfo(),
@@ -143,7 +134,7 @@ void KstELOG::submitEntry() {
                                  entry()->attributes(),
                                  configuration()->submitAsHTML(),
                                  configuration()->suppressEmail());
-  pThread->start();
+  pThread->doTransmit();
 }
 
 
@@ -175,7 +166,10 @@ void KstELOG::launchBrowser() {
   // FIXME: be able to raise() an existing browser window one day
   QString url;
 
-  url = _elogConfiguration->ipAddress() + ":" + QString::number(_elogConfiguration->portNumber());
+  if (!_elogConfiguration->ipAddress().startsWith("http://")) {
+    url = "http://";
+  }
+  url += _elogConfiguration->ipAddress() + ":" + QString::number(_elogConfiguration->portNumber());
   if (!_elogConfiguration->name().isEmpty()) {
     url += "/";
     url += _elogConfiguration->name();
