@@ -18,8 +18,9 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
+#include <time.h>
 
-
+#include <klocale.h>
 #include <kmdcodec.h>
 
 #include "elogthreadsubmit.h"
