@@ -11,4 +11,7 @@ c.tagName = "myCurve";
 var w = new Window;
 var p = new Plot(w);
 p.curves.append(c);
+p.topLabel = "JavaScript Demo"
+p.xLabel = "Index"
+p.yLabel = "sin(x)"
 
