@@ -28,12 +28,14 @@
 
 #include <kst.h>
 
+#include <qdeepcopy.h>
 #include <qlayout.h>
 #include <qsplitter.h>
 
 #include <kaction.h>
 #include <kfiledialog.h>
 #include <kgenericfactory.h>
+#include <kjs/function.h>
 #include <kjsembed/jsbuiltin.h>
 #include <kjsembed/jsconsolewidget.h>
 #include <kjsembed/jsfactory.h>
@@ -42,19 +44,29 @@
 #include <kmessagebox.h>
 #include <kparts/part.h>
 
+#include "bind_arrow.h"
+#include "bind_box.h"
 #include "bind_curve.h"
+#include "bind_datamatrix.h"
 #include "bind_datasource.h"
 #include "bind_datavector.h"
 #include "bind_debug.h"
 #include "bind_equation.h"
+#include "bind_ellipse.h"
 #include "bind_histogram.h"
 #include "bind_jsdataobject.h"
 #include "bind_kst.h"
+#include "bind_label.h"
+#include "bind_legend.h"
+#include "bind_line.h"
+#include "bind_matrix.h"
+#include "bind_picture.h"
 #include "bind_plot.h"
 #include "bind_plugin.h"
 #include "bind_point.h"
 #include "bind_powerspectrum.h"
 #include "bind_scalar.h"
+#include "bind_size.h"
 #include "bind_string.h"
 #include "bind_vector.h"
 #include "bind_window.h"
@@ -63,6 +75,39 @@
 K_EXPORT_COMPONENT_FACTORY(kstextension_js, KGenericFactory<KstJS>)
 
 
+class Function : public KJS::ObjectImp {
+  public:
+    virtual bool implementsCall() const {
+      return true;
+    }
+};
+
+
+class LoadScript : public Function {
+  public:
+  LoadScript(KstJS *ext) : Function(), _e(ext) {}
+  virtual KJS::Value call(KJS::ExecState* exec, KJS::Object&, const KJS::List& args) {
+    if (args.size() != 1) {
+      KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly one argument.");
+      exec->setException(eobj);
+      return KJS::Undefined();
+    }
+    if (!_e) {
+      return KJS::Boolean(false);
+    }
+    QString file = args[0].toString(exec).qstring();
+    if (_e->_jsPart->runFile(file)) {
+      if (!_e->_scripts.contains(file)) {
+        _e->_scripts.append(file);
+      }
+      return KJS::Boolean(true);
+    }
+    return KJS::Boolean(false);
+  }
+  QGuardedPtr<KstJS> _e;
+};
+
+
 KstJS::KstJS(QObject *parent, const char *name, const QStringList& l) : KstExtension(parent, name, l), KXMLGUIClient() {
   KJSEmbed::JSSecurityPolicy::setDefaultPolicy(KJSEmbed::JSSecurityPolicy::CapabilityAll);
   _jsPart = new KJSEmbed::KJSEmbedPart(0L, "javascript", this, "kjsembedpart");
@@ -94,14 +139,36 @@ KstJS::~KstJS() {
   delete _iface;
   _iface = 0L;
   destroyRegistry();
-  // crash
-  //app()->guiFactory()->removeClient(this);
+  KstApp *app = this->app();
+  if (app && app->guiFactory()) {
+    app->guiFactory()->removeClient(this);
+  }
+}
+
+
+void KstJS::processArguments(const QString& args) {
+  _args.append(args);
+  QTimer::singleShot(0, this, SLOT(doArgs()));
+}
+
+
+void KstJS::doArgs() {
+  static bool executing = false;
+  if (!_jsPart || executing) {
+    QTimer::singleShot(0, this, SLOT(doArgs()));
+    return;
+  }
+  executing = true;
+  QStringList a = QDeepCopy<QStringList>(_args);
+  _args.clear();
+  for (QStringList::ConstIterator i = a.begin(); i != a.end(); ++i) {
+    _jsPart->execute(*i);
+  }
+  executing = false;
 }
 
 
 void KstJS::createBindings() {
-  // FIXME: bad
-  _jsPart->addObject(app(), "kst");
   _jsPart->factory()->addType("KstJSUIBuilder");
   _jsPart->factory()->addType("KActionCollection");
   if (_merge) {
@@ -112,12 +179,15 @@ void KstJS::createBindings() {
   KJS::Object globalObj = _jsPart->globalObject();
 
   new KstBindPoint(exec, &globalObj);
+  new KstBindSize(exec, &globalObj);
   
   new KstBindVector(exec, &globalObj);
   new KstBindScalar(exec, &globalObj);
   new KstBindString(exec, &globalObj);
   new KstBindDataSource(exec, &globalObj);
   new KstBindDataVector(exec, &globalObj);
+  new KstBindMatrix(exec, &globalObj);
+  new KstBindDataMatrix(exec, &globalObj);
 
   new KstBindEquation(exec, &globalObj);
   new KstBindPlugin(exec, &globalObj);
@@ -128,11 +198,20 @@ void KstJS::createBindings() {
   new KstBindCurve(exec, &globalObj);
 
   new KstBindPlot(exec, &globalObj);
+  new KstBindLine(exec, &globalObj);
+  new KstBindLabel(exec, &globalObj);
+  new KstBindLegend(exec, &globalObj);
+  new KstBindBox(exec, &globalObj);
+  new KstBindEllipse(exec, &globalObj);
+  new KstBindPicture(exec, &globalObj);
+  new KstBindArrow(exec, &globalObj);
 
   new KstBindWindow(exec, &globalObj);
   new KstBindDebug(exec, &globalObj);
   new KstBindKst(exec, &globalObj, this);
 
+  globalObj.put(exec, "loadScript", KJS::Object(new LoadScript(this)));
+
   createRegistry();
 }
 
@@ -301,8 +380,8 @@ void KstJSUIBuilder::merge() {
 
 
 KstJSUIHelper::KstJSUIHelper(const QString& ui, KstJS *js)
-  : KXMLGUIClient(), _js(js), _ui(ui) {
-    setInstance(_js->app()->instance());
+: KXMLGUIClient(), _js(js), _ui(ui) {
+  setInstance(_js->app()->instance());
 }
 
 
