@@ -1355,7 +1355,7 @@ void KstApp::slotFilePrint() {
     return;
   }
 
-  KPrinter printer;
+  KPrinter printer(true, QPrinter::HighResolution);
   KstSettings *ks = KstSettings::globalSettings();
 
   printer.setOption("kde-pagesize", ks->printing.pageSize);
@@ -1575,7 +1575,7 @@ void KstApp::immediatePrintToFile(const QString& filename) {
     return;
   }
 
-  KPrinter printer;
+  KPrinter printer(true, QPrinter::HighResolution);
   printer.setPageSize(KPrinter::Letter);
   printer.setOrientation(KPrinter::Landscape);
   printer.setOutputToFile(true);
