@@ -291,6 +291,15 @@ public:
   int xMajorTicks() const { return _xMajorTicks; }
   int yMajorTicks() const { return _yMajorTicks; }
 
+  void setMajorPenWidth(int mpw) { _majorPenWidth = mpw; }
+  int majorPenWidth() const { return _majorPenWidth; }
+
+  void setMinorPenWidth(int mpw) { _minorPenWidth = mpw; }
+  int minorPenWidth() const { return _minorPenWidth; }
+
+  void setAxisPenWidth(int apw) { _axisPenWidth = apw; }
+  int axisPenWidth() const { return _axisPenWidth; }
+
   // set and get tick mark display options
   void setXTicksInPlot(bool yes);
   void setXTicksOutPlot(bool yes);
@@ -357,7 +366,7 @@ public slots:
   virtual void copyObject();
   virtual void copyObjectQuietly(KstViewObject& parent, const QString& name = QString::null) const;
   void draw(); // draw into back buffer
-  void draw(KstPainter& p, double resolutionEnhancement = 1); // This actually does the drawing
+  void draw(KstPainter& p); // This actually does the drawing
   void paintSelf(KstPainter& p, const QRegion& bounds);
   void updateSelf();
   void editCurve(int id);
@@ -468,6 +477,10 @@ private:
   bool _yMinorGrid : 1;
   bool _majorGridColorDefault : 1;
   bool _minorGridColorDefault : 1;
+  
+  int _majorPenWidth;
+  int _minorPenWidth;
+  int _axisPenWidth;
 
   bool _cursorOffset : 1;
 
@@ -582,7 +595,7 @@ private:
       double y_orig_px, double ytick_px,
       double ytick_len_px, int y_px,
       bool offsetY);
-  void plotGridLines(QPainter& p,
+  void plotGridLines(KstPainter& p,
       double XTick, double xleft_bdr_px, double xright_bdr_px,
       double x_orig_px, double xtick_px, double xtick_len_px, int x_px,
       double YTick, double ytop_bdr_px, double ybot_bdr_px,
