@@ -203,81 +203,77 @@ bool KstCurveDialogI::newObject() {
     return false;
   }
 
-  KstVectorList::Iterator VX, VY;
-  KstVectorList::Iterator EX, EY, EXMinus, EYMinus;
+  KstVectorPtr EXMinus, EYMinus;
 
   // find VX and VY
   KST::vectorList.lock().readLock();
-  VX = KST::vectorList.findTag(_w->_xVector->selectedVector());
-  VY = KST::vectorList.findTag(_w->_yVector->selectedVector());
-  EX = KST::vectorList.findTag(_w->_xError->selectedVector());
-  EY = KST::vectorList.findTag(_w->_yError->selectedVector());
+  KstVectorPtr VX = *KST::vectorList.findTag(_w->_xVector->selectedVector());
+  KstVectorPtr VY = *KST::vectorList.findTag(_w->_yVector->selectedVector());
+  KstVectorPtr EX = *KST::vectorList.findTag(_w->_xError->selectedVector());
+  KstVectorPtr EY = *KST::vectorList.findTag(_w->_yError->selectedVector());
   if (_w->_checkBoxXMinusSameAsPlus->isChecked()) {
     EXMinus = EX;
   } else {
-    EXMinus = KST::vectorList.findTag(_w->_xMinusError->selectedVector());
+    EXMinus = *KST::vectorList.findTag(_w->_xMinusError->selectedVector());
   }
   if (_w->_checkBoxYMinusSameAsPlus->isChecked()) {
     EYMinus = EY;
   } else {
-    EYMinus = KST::vectorList.findTag(_w->_yMinusError->selectedVector());
+    EYMinus = *KST::vectorList.findTag(_w->_yMinusError->selectedVector());
   }
-  if (VX == KST::vectorList.end() || VY == KST::vectorList.end()) {
+  KST::vectorList.lock().readUnlock();
+  if (!VX || !VY) {
     kstdFatal() << "Bug in kst: the XVector field in plotDialog refers to "
                 << "a non existent vector...." << endl;
   }
 
   // readlock the vectors, because when we update the curve, they get read
-  KstReadLocker rl1(*VX), rl2(*VY);
-  bool haveEx = EX != KST::vectorList.end();
-  bool haveEy = EY != KST::vectorList.end();
-  bool haveExMinus = EXMinus != KST::vectorList.end();
-  bool haveEyMinus = EYMinus != KST::vectorList.end();
-  if (haveEx) {
-    (*EX)->readLock();
-  }
-  if (haveEy) {
-    (*EY)->readLock();
-  }
-  if (haveExMinus) {
-    (*EXMinus)->readLock();
-  }
-  if (haveEyMinus) {
-    (*EYMinus)->readLock();
-  }
+  VX->readLock();
+  VY->readLock();
 
   QString tag_name = _tagName->text();
   if (tag_name == defaultTag) {
-    tag_name = KST::suggestCurveName((*VY)->tagName());
+    tag_name = KST::suggestCurveName(VY->tagName());
   }
 
   // verify that the curve name is unique
   if (KstData::self()->dataTagNameNotUnique(tag_name)) {
     _tagName->setFocus();
-    KST::vectorList.lock().readUnlock();
-    if (haveEx) {
-      (*EX)->readUnlock();
-    }
-    if (haveEy) {
-      (*EY)->readUnlock();
-    }
-    if (haveExMinus) {
-      (*EXMinus)->readUnlock();
-    }
-    if (haveEyMinus) {
-      (*EYMinus)->readUnlock();
-    }
     return false;
   }
 
+  if (EX) {
+    EX->readLock();
+  }
+  if (EY) {
+    EY->readLock();
+  }
+  if (EXMinus) {
+    EXMinus->readLock();
+  }
+  if (EYMinus) {
+    EYMinus->readLock();
+  }
+
   // create the curve
-  KstVCurvePtr curve = new KstVCurve(tag_name, *VX, *VY,
-                        haveEx ? *EX : KstVectorPtr(0L),
-                        haveEy ? *EY : KstVectorPtr(0L),
-                        haveExMinus ? *EXMinus : KstVectorPtr(0L),
-                        haveEyMinus ? *EYMinus : KstVectorPtr(0L),
-                        _w->_curveAppearance->color());
-  
+  KstVCurvePtr curve = new KstVCurve(tag_name, VX, VY, EX, EY, EXMinus, EYMinus, _w->_curveAppearance->color());
+
+  if (EX) {
+    EX->readUnlock();
+  }
+  if (EY) {
+    EY->readUnlock();
+  }
+  if (EXMinus) {
+    EXMinus->readUnlock();
+  }
+  if (EYMinus) {
+    EYMinus->readUnlock();
+  }
+
+  VY->readUnlock();
+  VX->readUnlock();
+
   QString legend_text = _legendText->text();
   if (legend_text == defaultTag) {
     curve->setLegendText(QString(""));
@@ -285,8 +281,6 @@ bool KstCurveDialogI::newObject() {
     curve->setLegendText(legend_text);
   }
   
-  KST::vectorList.lock().readUnlock();
-
   curve->setHasPoints(_w->_curveAppearance->showPoints());
   curve->setHasLines(_w->_curveAppearance->showLines());
   curve->setHasBars(_w->_curveAppearance->showBars());
@@ -330,19 +324,6 @@ bool KstCurveDialogI::newObject() {
     }
   }
 
-  if (haveEx) {
-    (*EX)->readUnlock();
-  }
-  if (haveEy) {
-    (*EY)->readUnlock();
-  }
-  if (haveExMinus) {
-    (*EXMinus)->readUnlock();
-  }
-  if (haveEyMinus) {
-    (*EYMinus)->readUnlock();
-  }
-
   KST::dataObjectList.lock().writeLock();
   KST::dataObjectList.append(curve.data());
   KST::dataObjectList.lock().writeUnlock();
