@@ -19,7 +19,7 @@
 
 #include <assert.h>
 
-#include <kdebug.h>
+#include "ksdebug.h"
 #include <kio/netaccess.h>
 #include <klibloader.h>
 #include <klocale.h>
@@ -93,6 +93,28 @@ namespace KST {
 
         return 0L;
       }
+      
+      QStringList matrixList(KConfig *cfg, const QString& filename, const QString& type = QString::null, QString *typeSuggestion = 0L, bool *complete = 0L) const {
+        
+        QStringList (*sym)(KConfig*, const QString&, const QString&, QString*, bool*) = (QStringList(*)(KConfig*, const QString&, const QString&, QString*, bool*))symbol("matrixList");
+        if (sym) {
+          return (sym)(cfg, filename, type, typeSuggestion, complete);  
+        }
+        // fallback incase the helper isn't implemented
+        //  (note: less efficient now)
+        KstDataSourcePtr ds = create(cfg, filename, type);
+        if (ds) {
+          QStringList rc = ds->matrixList();
+          if (typeSuggestion) {
+            *typeSuggestion = ds->fileType();
+          }
+          if (complete) {
+            *complete = ds->fieldListIsComplete();
+          }
+          return rc;
+        }
+        return QStringList();
+      }
 
       QStringList fieldList(KConfig *cfg, const QString& filename, const QString& type = QString::null, QString *typeSuggestion = 0L, bool *complete = 0L) const {
         QStringList (*sym)(KConfig*, const QString&, const QString&, QString*, bool*) = (QStringList(*)(KConfig*, const QString&, const QString&, QString*, bool*))symbol("fieldList");
@@ -153,6 +175,15 @@ namespace KST {
         return QStringList();
       }
 
+      Q_UINT32 key() const {
+        Q_UINT32 (*sym)() = (Q_UINT32(*)())symbol("key");
+        if (sym) {
+          return (sym)();
+        }
+
+        return Q_UINT32();
+      }
+
       bool hasConfigWidget() const {
         return 0L != symbol("widget");
       }
@@ -198,8 +229,14 @@ namespace KST {
         _lib = KLibLoader::self()->library(libname);
         if (!_lib) {
           KstDebug::self()->log(i18n("Error loading data-source plugin [%1]: %2").arg(libname).arg(KLibLoader::self()->lastErrorMessage()), KstDebug::Error);
+          return false;
         }
-        return _lib != 0L;
+
+        if (key() != KST_CURRENT_DATASOURCE_KEY) {
+          KstDebug::self()->log(i18n("Error loading data-source plugin [%1]: %2").arg(libname).arg(i18n("Plugin is too old and needs to be recompiled.")), KstDebug::Error);
+          return false;
+        }
+        return true;
       }
 
       QString _plugLib;
@@ -507,6 +544,37 @@ QStringList KstDataSource::fieldListForSource(const QString& filename, const QSt
 }
 
 
+QStringList KstDataSource::matrixListForSource(const QString& filename, const QString& type, QString *outType, bool *complete) {
+  if (filename == "stdin" || filename == "-") {
+    return QStringList();
+  }
+
+  QString fn = obtainFile(filename);
+  if (fn.isEmpty()) {
+    return QStringList();
+  }
+
+  QValueList<PluginSortContainer> bestPlugins = bestPluginsForSource(fn, type);
+  QStringList rc;
+  for (QValueList<PluginSortContainer>::Iterator i = bestPlugins.begin(); i != bestPlugins.end(); ++i) {
+    QString typeSuggestion;
+    rc = (*i).plugin->matrixList(kConfigObject, fn, QString::null, &typeSuggestion, complete);
+    if (!rc.isEmpty()) {
+      if (outType) {
+        if (typeSuggestion.isEmpty()) {
+          *outType = (*i).plugin->provides()[0];
+        } else {
+          *outType = typeSuggestion;
+        }
+      }
+      break;
+    }
+  }
+
+  return rc;
+}
+
+
 KstDataSourcePtr KstDataSource::loadSource(QDomElement& e) {
   QString filename, type;
 
@@ -535,19 +603,11 @@ KstDataSourcePtr KstDataSource::loadSource(QDomElement& e) {
 }
 
 
-class KstDataSourcePrivate {
-  public:
-    KstDataSourcePrivate() { _reusable = true; }
-    ~KstDataSourcePrivate() {}
-    bool _reusable;
-};
-
-
 KstDataSource::KstDataSource(KConfig *cfg, const QString& filename, const QString& type)
 : KstObject(), _filename(filename), _cfg(cfg) {
   Q_UNUSED(type)
   _valid = false;
-  d = new KstDataSourcePrivate;
+  _reusable = true;
   _numFramesScalar = new KstScalar(filename + i18n("-frames"));
   // Don't set provider - this is always up-to-date
 }
@@ -558,8 +618,6 @@ KstDataSource::~KstDataSource() {
   KST::scalarList.remove(_numFramesScalar);
   KST::scalarList.lock().writeUnlock();
   _numFramesScalar = 0L;
-  delete d;
-  d = 0L;
 }
 
 
@@ -594,6 +652,37 @@ int KstDataSource::readField(double *v, const QString& field, int s, int n) {
 }
 
 
+int KstDataSource::readMatrix(KstMatrixData* data, const QString& matrix, int xStart, int yStart, int xNumSteps, int yNumSteps, int skip) {
+  Q_UNUSED(data)
+  Q_UNUSED(matrix)
+  Q_UNUSED(xStart)
+  Q_UNUSED(yStart)
+  Q_UNUSED(xNumSteps)
+  Q_UNUSED(yNumSteps)
+  Q_UNUSED(skip)
+  return -9999;
+}
+ 
+  
+int KstDataSource::readMatrix(KstMatrixData* data, const QString& matrix, int xStart, int yStart, int xNumSteps, int yNumSteps) {
+  Q_UNUSED(data)
+  Q_UNUSED(matrix)
+  Q_UNUSED(xStart)
+  Q_UNUSED(yStart)
+  Q_UNUSED(xNumSteps)
+  Q_UNUSED(yNumSteps)
+  return -1;
+}
+
+
+bool KstDataSource::matrixDimensions(const QString& matrix, int* xDim, int* yDim) {
+  Q_UNUSED(matrix)
+  Q_UNUSED(xDim)
+  Q_UNUSED(yDim)
+  return false;  
+}
+
+
 bool KstDataSource::isValid() const {
   return _valid;
 }
@@ -605,6 +694,12 @@ bool KstDataSource::isValidField(const QString& field) const {
 }
 
 
+bool KstDataSource::isValidMatrix(const QString& field) const {
+  Q_UNUSED(field)
+  return false;  
+}
+
+
 int KstDataSource::samplesPerFrame(const QString &field) {
   Q_UNUSED(field)
   return 0;
@@ -633,6 +728,11 @@ QStringList KstDataSource::fieldList() const {
 }
 
 
+QStringList KstDataSource::matrixList() const { 
+  return _matrixList;  
+}
+
+
 QString KstDataSource::fileType() const {
   return QString::null;
 }
@@ -652,13 +752,6 @@ void KstDataSource::save(QTextStream &ts, const QString& indent) {
 }
 
 
-void KstDataSource::virtual_hook(int id, void *data) {
-  Q_UNUSED(id)
-  Q_UNUSED(data)
-  //KstObject::virtual_hook(id, data);
-}
-
-
 void *KstDataSource::bufferMalloc(size_t size) {
   return KST::malloc(size);
 }
@@ -718,7 +811,7 @@ bool KstDataSource::supportsTimeConversions() const {
 }
 
 
-int KstDataSource::sampleForTime(const QDateTime& time, bool *ok) {
+int KstDataSource::sampleForTime(const KST::ExtDateTime& time, bool *ok) {
   Q_UNUSED(time)
   if (ok) {
     *ok = false;
@@ -728,8 +821,8 @@ int KstDataSource::sampleForTime(const QDateTime& time, bool *ok) {
 
 
 
-int KstDataSource::sampleForTime(int seconds, bool *ok) {
-  Q_UNUSED(seconds)
+int KstDataSource::sampleForTime(double ms, bool *ok) {
+  Q_UNUSED(ms)
   if (ok) {
     *ok = false;
   }
@@ -738,17 +831,17 @@ int KstDataSource::sampleForTime(int seconds, bool *ok) {
 
 
 
-QDateTime KstDataSource::timeForSample(int sample, bool *ok) {
+KST::ExtDateTime KstDataSource::timeForSample(int sample, bool *ok) {
   Q_UNUSED(sample)
   if (ok) {
     *ok = false;
   }
-  return QDateTime::currentDateTime();
+  return KST::ExtDateTime::currentDateTime();
 }
 
 
 
-int KstDataSource::relativeTimeForSample(int sample, bool *ok) {
+double KstDataSource::relativeTimeForSample(int sample, bool *ok) {
   Q_UNUSED(sample)
   if (ok) {
     *ok = false;
@@ -758,18 +851,18 @@ int KstDataSource::relativeTimeForSample(int sample, bool *ok) {
 
 
 bool KstDataSource::reusable() const {
-  return d->_reusable;
+  return _reusable;
 }
 
 
 void KstDataSource::disableReuse() {
-  d->_reusable = false;
+  _reusable = false;
 }
 
 
 /////////////////////////////////////////////////////////////////////////////
 KstDataSourceConfigWidget::KstDataSourceConfigWidget()
-: QWidget(0L), _cfg(0L), d(0L) {
+: QWidget(0L), _cfg(0L) {
 }
 
 
