@@ -19,7 +19,7 @@
 #include "kstdatasource.h"
 #include "kstdebug.h"
 #include "kstdoc.h"
-#include "kstversion.h"
+#include "kstrevision.h"
 #include "logevents.h"
 
 #include <kapplication.h>
@@ -48,6 +48,8 @@ KstDebug::KstDebug()
 : QObject() {
   _applyLimit = false;
   _limit = 10000;
+  _kstRevision = QString::fromLatin1(KSTREVISION);
+  _hasNewError = false;
 }
 
 
@@ -93,6 +95,10 @@ void KstDebug::log(const QString& msg, LogLevel level) {
     _messages.erase(first, last);
   }
 
+  if (level == Error) {
+    _hasNewError = true;
+  }
+
   if (_handler) {
     LogEvent *e = new LogEvent(LogEvent::LogAdded);
     e->_msg = message;
@@ -102,6 +108,7 @@ void KstDebug::log(const QString& msg, LogLevel level) {
 
 
 void KstDebug::clear() {
+  clearHasNewError(); // has to be before the lock is acquired
   QMutexLocker ml(&_lock);
   _messages.clear(); 
   LogEvent *e = new LogEvent(LogEvent::LogCleared);
@@ -176,5 +183,24 @@ int KstDebug::logLength() const {
   return _messages.size();
 }
 
+
+const QString& KstDebug::kstRevision() const {
+  QMutexLocker ml(&_lock);
+  return _kstRevision;
+}
+
+
+bool KstDebug::hasNewError() const {
+  QMutexLocker ml(&_lock);
+  return _hasNewError;
+}
+
+
+void KstDebug::clearHasNewError() {
+  QMutexLocker ml(&_lock);
+  _hasNewError = false;
+}
+
+
 #include "kstdebug.moc"
 // vim: ts=2 sw=2 et
