@@ -23,7 +23,6 @@
 
 // include files for KDE
 #include <kcolorbutton.h>
-#include <kdebug.h>
 #include <klocale.h>
 
 #include "kst.h"
@@ -31,7 +30,6 @@
 #include "kstdebugdialog_i.h"
 #include "kstdoc.h"
 #include "kstlogwidget.h"
-#include "kstversion.h"
 
 /*
  *  Constructs a KstDebugDialogI which is a child of 'parent', with the
@@ -54,7 +52,7 @@ KstDebugDialogI::KstDebugDialogI(QWidget* parent,
     new QListViewItem(_dataSources, *it);
   }
 
-  _buildInfo->setText(i18n("<h1>Kst</h1> version %1").arg(KSTVERSION));
+  _buildInfo->setText(i18n("<h1>Kst</h1> version %1 (%2)").arg(KSTVERSION).arg(KstDebug::self()->kstRevision()));
 
   connect(KstApp::inst()->document(), SIGNAL(logAdded(const KstDebug::LogMessage&)), _log, SLOT(logAdded(const KstDebug::LogMessage&)));
   connect(KstApp::inst()->document(), SIGNAL(logCleared()), _log, SLOT(clear()));
@@ -107,5 +105,11 @@ void KstDebugDialogI::email() {
   KstDebug::self()->sendEmail();
 }
 
+
+KstLogWidget *KstDebugDialogI::logWidget() const {
+  return _log;
+}
+
+
 #include "kstdebugdialog_i.moc"
 // vim: et ts=2 sw=2
