@@ -20,17 +20,20 @@
 
 #include <qstring.h>
 
-namespace KST {
-  extern QString suggestPlotName();
+#include "kst_export.h"
 
-  extern QString suggestVectorName(const QString &field);
-  extern QString suggestCurveName(const QString& vector_name, bool add_c=false);
-  extern QString suggestPSDName(const QString& vector_name);
-  extern QString suggestEQName(const QString& vector_name);
-  extern QString suggestHistogramName(const QString& vector_name);
-  extern QString suggestPluginName(const QString& pname, const QString& vname = QString::null);
-  extern QString suggestMatrixName(const QString& vector_name);
-  extern QString suggestImageName(const QString& matrix_name);
+namespace KST {
+  extern KST_EXPORT QString suggestPlotName();
+
+  extern KST_EXPORT QString suggestVectorName(const QString &field);
+  extern KST_EXPORT QString suggestCurveName(const QString& vector_name, bool add_c=false);
+  extern KST_EXPORT QString suggestPSDName(const QString& vector_name);
+  extern KST_EXPORT QString suggestCSDName(const QString& vector_name);
+  extern KST_EXPORT QString suggestEQName(const QString& vector_name);
+  extern KST_EXPORT QString suggestHistogramName(const QString& vector_name);
+  extern KST_EXPORT QString suggestPluginName(const QString& pname, const QString& vname = QString::null);
+  extern KST_EXPORT QString suggestMatrixName(const QString& vector_name);
+  extern KST_EXPORT QString suggestImageName(const QString& matrix_name);
 }
 
 #endif
