@@ -23,18 +23,16 @@
 class KstFitDialogI : public KstPluginDialogI {
   Q_OBJECT
   public:
-    KstFitDialogI(QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+    KstFitDialogI(QWidget* parent = 0, const char* name = 0, bool modal = false, WFlags fl = 0 );
     virtual ~KstFitDialogI();
-
     static KstFitDialogI *globalInstance();
 
   public slots:
     void show_setCurve(const QString& strCurve, const QString& strPlotName, const QString& strWindow);
-    bool new_I();
+    bool newObject();
     void updatePluginList();
 
   private:
-
     static QGuardedPtr<KstFitDialogI> _inst;
     
     QString _xvector;
