@@ -27,42 +27,53 @@ class KstGraphFileDialogI : public KstGraphFileDialog {
         bool modal = false, WFlags fl = 0 );
     virtual ~KstGraphFileDialogI();
 
-    bool autoSaving() const;
-    int autoSaveTimer() const;
+    void setAutoSave(bool as) {_autoSave = as;}
+    bool autoSaving() const {return _autoSave;}
 
-    void setAutoSaveTimer(int time);
-    void setAutoSave(bool on);
+    void setAutoSaveTimer(int time) {_savePeriod = time;}
+    int autoSaveTimer() const {return _savePeriod;}
 
-    KURL url() const;
+    KURL url() const {return _url;}
     void setURL(const QString&);
 
-    void setFormat(const QString&);
-    QString format() const;
+    void setFormat(const QString& format) {_format = format;}
+    QString format() const {return _format;}
 
-    void setSquare(bool on);
-    bool isSquare() const;
+    void setImageSize(int xsize, int ysize) {_w = xsize; _h = ysize;}
+    int imageXSize() const {return _w;}
+    int imageYSize() const {return _h;} // not used if isSquare
 
-    void setImageSize(int xsize, int ysize);
-    int imageXSize() const;
-    int imageYSize() const;
+    void setDisplay(int displayOption) {_displayOption = displayOption;}
+    int display() const {return _displayOption;}
 
   public slots:
-    /** shows/raises the dialog */
-    void showGraphFileDialog();
     void reqGraphFile();
+    void reqEpsGraphFile();
     void saveProperties();
     void loadProperties();
-    
-  private slots:
-    void xsizeChanged(int x);
-    void setAutoSave();
-    void square();
+    void updateDialog();
+    void enableWidthHeight();
+    void enableEPSVector(const QString& format);
 
+    void apply_I();
+    void ok_I();
+    void show_I();
+    void applyAutosave();
   private:
     QTimer *_autoSaveTimer;
+    QString _url;
+    QString _format;
+    unsigned _w;
+    unsigned _h;
+    bool _allWindows;
+    bool _autoSave;
+    bool _savePeriod;
+    bool _saveEPSAsVector;
+    int _displayOption;
 
   signals:
-    void graphFileReq(const QString &filename, const QString &format, int w, int h, bool all);
+    void graphFileReq(const QString &filename, const QString &format, int w, int h, bool all, int display);
+    void graphFileEpsReq(const QString &filename, int w, int h, bool all, int display);
 };
 
 #endif
