@@ -23,10 +23,11 @@
 #define KSTHISTOGRAM_H
 
 #include "kstbasecurve.h"
+#include "kst_export.h"
 
 enum KstHsNormType { KST_HS_NUMBER, KST_HS_PERCENT, KST_HS_FRACTION, KST_HS_MAX_ONE};
 
-class KstHistogram: public KstDataObject {
+class KST_EXPORT KstHistogram: public KstDataObject {
 public:
   KstHistogram(const QString &in_tag, KstVectorPtr in_V,
                double xmin_in, double xmax_in,
@@ -51,8 +52,6 @@ public:
   virtual QString yLabel() const;
   virtual QString xLabel() const;
 
-  virtual KstCurveType type() const;
-
   bool isNormNum()        const { return _NormMode == KST_HS_NUMBER; }
   void setIsNormNum()           { _NormMode = KST_HS_NUMBER; }
   bool isNormPercent()    const { return _NormMode == KST_HS_PERCENT; }
@@ -84,6 +83,8 @@ public:
   double vMax() const;
   double vMin() const;
   int vNumSamples() const;
+  
+  virtual KstDataObjectPtr makeDuplicate(KstDataObjectDataObjectMap& duplicatedMap);
 
 private:
   KstHsNormType _NormMode;
