@@ -210,16 +210,17 @@ bool KstHsDialogI::newObject() {
   KstHistogramPtr hs;
 
   KST::vectorList.lock().readLock();
-  KstVectorList::Iterator i = KST::vectorList.findTag(_w->_vector->selectedVector());
+  KstVectorPtr vp = *KST::vectorList.findTag(_w->_vector->selectedVector());
   KST::vectorList.lock().readUnlock();
-  if (i == KST::vectorList.end()) {
+  if (!vp) {
     kstdFatal() << "Bug in kst: the Vector field in plotDialog (Hs) refers to "
                 << " a non existant vector..." << endl;
   }
 
-  (*i)->readLock();
-  hs = new KstHistogram(tag_name, *i, new_min, new_max,
+  vp->readLock();
+  hs = new KstHistogram(tag_name, vp, new_min, new_max,
                         new_n_bins, new_norm_mode);
+  vp->readUnlock();
   hs->setRealTimeAutoBin(_w->_realTimeAutoBin->isChecked());
 
   KstVCurvePtr vc = new KstVCurve(KST::suggestCurveName(tag_name, true), hs->vX(), hs->vY(), 0L, 0L, 0L, 0L, _w->_curveAppearance->color());
@@ -270,7 +271,6 @@ bool KstHsDialogI::newObject() {
       }
     }
   }
-  (*i)->readUnlock();
 
   KST::dataObjectList.lock().writeLock();
   KST::dataObjectList.append(hs.data());
