@@ -25,19 +25,26 @@
 
 // application specific includes
 #include "kst.h"
+#include "kst2dplot.h"
 #include "kstcolorsequence.h"
 #include "kstdoc.h"
 #include "kstequation.h"
+#include "ksteventmonitorentry.h"
 #include "ksthistogram.h"
 #include "kstiface_impl.h"
+#include "kstimage.h"
 #include "kstplugin.h"
 #include "kstpsd.h"
+#include "kstrmatrix.h"
 #include "kstrvector.h"
+#include "kstsmatrix.h"
 #include "kstsvector.h"
 #include "kstvcurve.h"
 #include "kstviewwindow.h"
 #include "plugincollection.h"
 
+#include "kmessagebox.h"
+
 KstIfaceImpl::KstIfaceImpl(KstDoc *doc, KstApp *app)
 : DCOPObject("KstIface"), _doc(doc), _app(app) {
   assert(doc);
@@ -233,14 +240,16 @@ bool KstIfaceImpl::plotEquation(double start, double end, int numSamples, const
   if (!eq->isValid()) {
     return false;
   }
+  
+  KstVCurveList vcurves = kstObjectSubList<KstBaseCurve,KstVCurve>(plot->Curves);
 
-  KstVCurvePtr vc = new KstVCurve(KST::suggestCurveName(etag, true), eq->vX(), eq->vY(), 0L, 0L, 0L, 0L, color.isValid() ? color : KstColorSequence::next(plot->Curves,plot->backgroundColor()));
+  KstVCurvePtr vc = new KstVCurve(KST::suggestCurveName(etag, true), eq->vX(), eq->vY(), 0L, 0L, 0L, 0L, color.isValid() ? color : KstColorSequence::next(vcurves,plot->backgroundColor()));
   KST::dataObjectList.lock().writeLock();
   KST::dataObjectList.append(KstDataObjectPtr(eq));
   KST::dataObjectList.append(KstDataObjectPtr(vc));
   KST::dataObjectList.lock().writeUnlock();
 
-  plot->Curves.append(KstBaseCurvePtr(vc));
+  plot->addCurve(KstBaseCurvePtr(vc));
 
   _doc->forceUpdate();
   _doc->setModified();
@@ -326,13 +335,15 @@ bool KstIfaceImpl::plotEquation(const QString& xvector, const QString& equation,
     return false;
   }
 
-  KstVCurvePtr vc = new KstVCurve(KST::suggestCurveName(etag, true), eq->vX(), eq->vY(), 0L, 0L, 0L, 0L, color.isValid() ? color : KstColorSequence::next(plot->Curves,plot->backgroundColor()));
+  KstVCurveList vcurves = kstObjectSubList<KstBaseCurve,KstVCurve>(plot->Curves);
+  
+  KstVCurvePtr vc = new KstVCurve(KST::suggestCurveName(etag, true), eq->vX(), eq->vY(), 0L, 0L, 0L, 0L, color.isValid() ? color : KstColorSequence::next(vcurves,plot->backgroundColor()));
   KST::dataObjectList.lock().writeLock();
   KST::dataObjectList.append(KstDataObjectPtr(eq));
   KST::dataObjectList.append(KstDataObjectPtr(vc));
   KST::dataObjectList.lock().writeUnlock();
 
-  plot->Curves.append(KstBaseCurvePtr(vc));
+  plot->addCurve(KstBaseCurvePtr(vc));
 
   _doc->forceUpdate();
   _doc->setModified();
@@ -370,7 +381,7 @@ bool KstIfaceImpl::saveVector(const QString& vector, const QString& filename) {
     return false;
   }
 
-  return 0 == KST::vectorToFile(*it, &f);
+  return 0 == KstData::self()->vectorToFile(*it, &f);
 }
 
 
@@ -649,6 +660,7 @@ bool KstIfaceImpl::deletePlot(const QString& window, const QString& name) {
   return false;
 }
 
+
 QStringList KstIfaceImpl::plotContents(const QString& name) {
   //iterate through the windows until plot is found
   KstApp *app = KstApp::inst();
@@ -670,6 +682,7 @@ QStringList KstIfaceImpl::plotContents(const QString& name) {
   return QStringList();
 }
 
+
 bool KstIfaceImpl::addCurveToPlot(KMdiChildView *win, const QString& plot, const QString& curve) {
   KstViewWindow *w = dynamic_cast<KstViewWindow*>(win);
 
@@ -682,13 +695,8 @@ bool KstIfaceImpl::addCurveToPlot(KMdiChildView *win, const QString& plot, const
         KstBaseCurveList::Iterator ci = bcl.findTag(curve);
         Kst2DPlotPtr p = *(plots.findTag(plot));
         if (p && ci != bcl.end()) {
-          (*ci)->writeLock();
           p->addCurve(*ci);
-          (*ci)->writeUnlock();
-
           _doc->forceUpdate();
-          _doc->setModified();
-
           return true;
         }
       }
@@ -700,18 +708,12 @@ bool KstIfaceImpl::addCurveToPlot(KMdiChildView *win, const QString& plot, const
 
 
 bool KstIfaceImpl::addCurveToPlot(const QString& window, const QString& plot, const QString& curve) {
-  KstApp *app = KstApp::inst();
-  KMdiChildView *activewin = app->findWindow(window);
-
-  return addCurveToPlot(activewin, plot, curve);
+  return addCurveToPlot(KstApp::inst()->findWindow(window), plot, curve);
 }
 
 
 bool KstIfaceImpl::addCurveToPlot(const QString& plot, const QString& curve) {
-  KstApp *app = KstApp::inst();
-  KMdiChildView *activewin = app->activeWindow();
-
-  return addCurveToPlot(activewin, plot, curve);
+  return addCurveToPlot(KstApp::inst()->activeWindow(), plot, curve);
 }
 
 
@@ -727,13 +729,8 @@ bool KstIfaceImpl::removeCurveFromPlot(KMdiChildView *win, const QString& plot,
         KstBaseCurveList bcl = kstObjectSubList<KstDataObject,KstBaseCurve>(KST::dataObjectList);
         KstBaseCurveList::Iterator ci = bcl.findTag(curve);
         if (p && ci != bcl.end()) {
-          (*ci)->readLock();
-          p->Curves.remove(*ci);
-          (*ci)->readUnlock();
-
+          p->removeCurve(*ci);
           _doc->forceUpdate();
-          _doc->setModified();
-
           return true;
         }
       }
@@ -744,18 +741,12 @@ bool KstIfaceImpl::removeCurveFromPlot(KMdiChildView *win, const QString& plot,
 }
 
 bool KstIfaceImpl::removeCurveFromPlot(const QString& window, const QString& plot, const QString& curve) {
-  KstApp *app = KstApp::inst();
-  KMdiChildView *activewin = app->findWindow(window);
-
-  return removeCurveFromPlot(activewin, plot, curve);
+  return removeCurveFromPlot(KstApp::inst()->findWindow(window), plot, curve);
 }
 
 
 bool KstIfaceImpl::removeCurveFromPlot(const QString& plot, const QString& curve) {
-  KstApp *app = KstApp::inst();
-  KMdiChildView *activewin = app->activeWindow();
-
-  return removeCurveFromPlot(activewin, plot, curve);
+  return removeCurveFromPlot(KstApp::inst()->activeWindow(), plot, curve);
 }
 
 
@@ -887,7 +878,7 @@ const QString& KstIfaceImpl::loadVector(const QString& file, const QString& fiel
   KST::vectorList.lock().readLock();
   QString vname = "V" + QString::number(KST::vectorList.count() + 1);
 
-  while (KST::vectorTagNameNotUnique(vname, false)) {
+  while (KstData::self()->vectorTagNameNotUnique(vname, false)) {
     vname = "V" + QString::number(KST::vectorList.count() + 1);
   }
   KST::vectorList.lock().readUnlock();
@@ -1127,8 +1118,15 @@ bool KstIfaceImpl::setPlotAxes(const QString& plotName,
       Kst2DPlotList::Iterator plot_iter=plotlist.findTag(plotName);
       if (plot_iter != plotlist.end()) {
         app->deleteIterator(iter);
+      
+        (*plot_iter)->setXScaleMode(FIXED);
+        (*plot_iter)->setYScaleMode(FIXED);
         (*plot_iter)->setScale(XLower, YLower,
-                               XUpper, YUpper);  //set the scale
+                              XUpper, YUpper);  //set the scale
+        
+        // repaint the plot 
+        (*plot_iter)->setDirty();
+        viewwindow->view()->paint(KstPainter::P_PLOT);
         return true;
       }
     }
@@ -1146,13 +1144,55 @@ QString KstIfaceImpl::createHistogram(const QString& name,
     int normalizationType,
     const QColor& color) {
 
+  QStringList objList = createHistogram(name, vector, min, max, numBins, normalizationType);
+
+  if (objList.isEmpty())
+  {
+    return QString::null;
+  }
+  
+  // also create the curve for the histogram
+  QString n = objList[0] + "-C";
+  KST::vectorList.lock().readLock();
+  KstVectorPtr vx = *KST::vectorList.findTag(objList[1]);
+  KstVectorPtr vy = *KST::vectorList.findTag(objList[2]);
+  KST::vectorList.lock().readUnlock();
+
+  KST::dataObjectList.lock().readLock();
+  while (KST::dataObjectList.findTag(n) != KST::dataObjectList.end()) {
+    n += "'";
+  }
+  KST::dataObjectList.lock().readUnlock();
+
+  KstVCurvePtr c = new KstVCurve(n, vx, vy, 0L, 0L, 0L, 0L, color);
+  c->setHasPoints(false);
+  c->setHasLines(false);
+  c->setHasBars(true);
+  c->setBarStyle(1);
+  
+  KST::dataObjectList.lock().writeLock();
+  KST::dataObjectList.append(KstDataObjectPtr(c));
+  KST::dataObjectList.lock().writeUnlock();
+
+  _doc->forceUpdate();
+  _doc->setModified();
+  return c->tagName(); //return the curve name so user can plot it
+}
+
+QStringList KstIfaceImpl::createHistogram(const QString& name,
+                                          const QString& vector,
+                                          double min,
+                                          double max,
+                                          int numBins,
+                                          int normalizationType)
+{
   //get the vector
   KST::vectorList.lock().readLock();
   KstVectorList::Iterator iter = KST::vectorList.findTag(vector);
   KST::vectorList.lock().readUnlock();
 
   if (iter == KST::vectorList.end()) {
-    return QString::null;
+    return QStringList();
   }
 
   //set the normalization type
@@ -1161,18 +1201,18 @@ QString KstIfaceImpl::createHistogram(const QString& name,
   switch (normalizationType) {
     case 1:
       normtype = KST_HS_NUMBER;
-    break;
+      break;
     case 2:
       normtype = KST_HS_PERCENT;
-    break;
+      break;
     case 3:
       normtype = KST_HS_FRACTION;
-    break;
+      break;
     case 4:
       normtype = KST_HS_MAX_ONE;
     default:
       normtype = KST_HS_NUMBER;
-    break;
+      break;
   }
 
   //suggest a name if not supplied
@@ -1188,24 +1228,29 @@ QString KstIfaceImpl::createHistogram(const QString& name,
   QString stringnum;
   stringnum = stringnum.setNum(i);
 
-  QString htag = "C" + stringnum + "-HS_" + htag_end;
+  QString htag = stringnum + "-" + htag_end;
 
-  while (KST::dataTagNameNotUnique(htag, false)) {
+  while (KstData::self()->dataTagNameNotUnique(htag, false)) {
     stringnum.setNum(++i);
-    htag = "C" + stringnum + "-HS_" + htag_end;
+    htag = stringnum + "-" + htag_end;
   }
 
   KstHistogramPtr histogram = new KstHistogram(htag, *iter, min, max, numBins,
-                               normtype);
+                                               normtype);
 
   KST::dataObjectList.lock().writeLock();
   KST::dataObjectList.append(KstDataObjectPtr(histogram));
   KST::dataObjectList.lock().writeUnlock();
 
+  QStringList returnList;
+  returnList.push_back(histogram->tagName());
+  returnList.push_back(histogram->xVTag());
+  returnList.push_back(histogram->yVTag());
+  
   _doc->forceUpdate();
   _doc->setModified();
-
-  return htag;
+  
+  return returnList;
 }
 
 QString KstIfaceImpl::createPowerSpectrum(const QString & name,
@@ -1217,13 +1262,58 @@ QString KstIfaceImpl::createPowerSpectrum(const QString & name,
     double sampleRate,
     const QString& vectorUnits,
     const QColor& color) {
+
+  QStringList objList = createPowerSpectrum(name, vector, appodize, removeMean,
+                                            fftLength, rateUnits, sampleRate, 
+                                            vectorUnits);
+  if (objList.isEmpty())
+  {
+    return QString::null;
+  }
+  
+  KST::vectorList.lock().readLock();
+  KstVectorPtr vx = *KST::vectorList.findTag(objList[1]);
+  KstVectorPtr vy = *KST::vectorList.findTag(objList[2]);
+  KST::vectorList.lock().readUnlock();
+  
+  QString n = objList[0] + "-C";
+  KST::dataObjectList.lock().readLock();
+  while (KST::dataObjectList.findTag(n) != KST::dataObjectList.end()) {
+    n += "'";
+  }
+  KST::dataObjectList.lock().readUnlock();
+  
+  // create curve as well (but don't plot the curve)
+  KstVCurvePtr vc = new KstVCurve(n, vx, vy, 
+                                  0L, 0L, 0L, 0L, 
+                                  color.isValid() ? color : QColor("darkBlue"));
+
+  KST::dataObjectList.lock().writeLock();
+  KST::dataObjectList.append(KstDataObjectPtr(vc));
+  KST::dataObjectList.lock().writeUnlock();
+
+  _doc->forceUpdate();
+  _doc->setModified();
+
+  return vc->tagName(); //return the curve name so user can plot it
+}
+                                       
+QStringList KstIfaceImpl::createPowerSpectrum(const QString& name,
+                                              const QString& vector,
+                                              bool appodize,
+                                              bool removeMean,
+                                              int fftLength,
+                                              const QString& rateUnits,
+                                              double sampleRate,
+                                              const QString& vectorUnits)
+{
   //get the vector
   KST::vectorList.lock().readLock();
   KstVectorList::Iterator iter = KST::vectorList.findTag(vector);
   KST::vectorList.lock().readUnlock();
 
   if (iter == KST::vectorList.end()) {
-    return QString::null;
+    return QStringList();
   }
 
   //suggest a name if not supplied
@@ -1238,29 +1328,29 @@ QString KstIfaceImpl::createPowerSpectrum(const QString & name,
   int i = pslist.count() + 1;
   QString stringnum = QString::number(i);
 
-  QString pstag = "C" + stringnum + "-PSD_" + pstag_end;
+  QString pstag = stringnum + "-" + pstag_end;
 
-  while (KST::dataTagNameNotUnique(pstag, false)) {
+  while (KstData::self()->dataTagNameNotUnique(pstag, false)) {
     stringnum.setNum(++i);
-    pstag = "C" + stringnum + "-PSD_" + pstag_end;
+    pstag = stringnum + "-" + pstag_end;
   }
 
   KstPSDPtr powerspectrum = new KstPSD(pstag, *iter, sampleRate, true, fftLength,
-                               appodize, removeMean, vectorUnits, rateUnits);
-
-  // FIXME: should we be plotting this?  Otherwise, remove color
-  //KstVCurvePtr vc = new KstVCurve(pstag + "-curve", *iter, powerspectrum->vY(), 0L, 0L, color.isValid() ? color : QColor("darkBlue"));
-
+                                       appodize, removeMean, vectorUnits, rateUnits, 0);
+  
   KST::dataObjectList.lock().writeLock();
   KST::dataObjectList.append(KstDataObjectPtr(powerspectrum));
-  //KST::dataObjectList.append(KstDataObjectPtr(vc));
   KST::dataObjectList.lock().writeUnlock();
-
+  
+  QStringList returnList;
+  returnList.push_back(powerspectrum->tagName());
+  returnList.push_back(powerspectrum->xVTag());
+  returnList.push_back(powerspectrum->yVTag());
+  
   _doc->forceUpdate();
   _doc->setModified();
-
-  return pstag;
-
+  
+  return returnList;
 }
 
 QString KstIfaceImpl::createEvent(const QString& name,
@@ -1284,7 +1374,7 @@ QString KstIfaceImpl::createEvent(const QString& name,
 
   QString evtag = "E" + stringnum + "-" + evtag_end;
 
-  while (KST::dataTagNameNotUnique(evtag, false)) {
+  while (KstData::self()->dataTagNameNotUnique(evtag, false)) {
     stringnum.setNum(++i);
     evtag = "E" + stringnum + "-" + evtag_end;
   }
@@ -1382,7 +1472,7 @@ QStringList KstIfaceImpl::createPlugin(const QString& pluginName,
       if (scalarParamIter != scalarInputs.end()) {
         KST::scalarList.lock().readLock();
         KstScalarList::Iterator iter = KST::scalarList.findTag(*scalarParamIter);
-        KST::vectorList.lock().readUnlock();
+        KST::scalarList.lock().readUnlock();
         if (iter != KST::scalarList.end()) {
           kstplug_ptr->writeLock();
           kstplug_ptr->inputScalars().insert((*IOIter)._name, *iter);
@@ -1417,7 +1507,7 @@ QStringList KstIfaceImpl::createPlugin(const QString& pluginName,
 
   QString plugtag = "P" + stringnum + "-" + pluginName;
 
-  while (KST::dataTagNameNotUnique(plugtag, false)) {
+  while (KstData::self()->dataTagNameNotUnique(plugtag, false)) {
     stringnum.setNum(++i);
     plugtag = "P" + stringnum + "-" + pluginName;
   }
@@ -1434,7 +1524,7 @@ QStringList KstIfaceImpl::createPlugin(const QString& pluginName,
          && (*IOIter)._subType == Plugin::Data::IOValue::FloatSubType) {
       if (kstVectorIter != kstplug_ptr->outputVectors().end()) {
         QString vectorTag = plugtag + (*IOIter)._name;
-        while (KST::dataTagNameNotUnique(vectorTag, false)) {
+        while (KstData::self()->dataTagNameNotUnique(vectorTag, false)) {
           vectorTag += '\'';
         }
         kstplug_ptr->writeLock();
@@ -1446,7 +1536,7 @@ QStringList KstIfaceImpl::createPlugin(const QString& pluginName,
     else if ((*IOIter)._type == Plugin::Data::IOValue::FloatType) {
       if (kstScalarIter != kstplug_ptr->outputScalars().end()) {
         QString scalarTag = plugtag + (*IOIter)._name;
-        while (KST::dataTagNameNotUnique(scalarTag, false)) {
+        while (KstData::self()->dataTagNameNotUnique(scalarTag, false)) {
           scalarTag += '\'';
         }
         kstplug_ptr->writeLock();
@@ -1473,65 +1563,104 @@ QStringList KstIfaceImpl::createPlugin(const QString& pluginName,
   return outputList;
 }
 
-QString KstIfaceImpl::createMatrix(const QString& name, const QString& vector, double xMin, double yMin,
-                                                   double xStepSize, double yStepSize,
-                                                   uint xNumSteps, uint yNumSteps,
-                                                   bool useMaxX) {
-  //get the vector
-  KST::vectorList.lock().readLock();
-  KstVectorList::Iterator iter = KST::vectorList.findTag(vector);
-  KST::vectorList.lock().readUnlock();
 
-  if (iter == KST::vectorList.end()) {
-    return QString::null;
-  }
+QString KstIfaceImpl::loadMatrix(const QString& name, const QString& file, const QString& field,
+                                int xStart, int yStart, int xNumSteps, int yNumSteps, 
+                                int skipFrames, bool boxcarFilter) {
+  KstDataSourcePtr src;
+  /* generate or find the kstfile */
+  KST::dataSourceList.lock().writeLock();
+  KstDataSourceList::Iterator it = KST::dataSourceList.findReusableFileName(file);
 
-  //suggest a name if not supplied
-  QString artag;
-  if (name.isEmpty()) {
-    artag = KST::suggestMatrixName(vector);
+  if (it == KST::dataSourceList.end()) {
+    src = KstDataSource::loadSource(file);
+    if (!src || !src->isValid()) {
+      KST::dataSourceList.lock().writeUnlock();
+      return QString::null;
+    }
+    if (src->isEmpty()) {
+      KST::dataSourceList.lock().writeUnlock();
+      return QString::null;
+    }
+    KST::dataSourceList.append(src);
   } else {
-    QString artag_end = QString(name);
-    //count number of data objects and make a unique name
-    int i = KST::dataObjectList.count() + 1;
-    QString artag = "A" + QString::number(i) + "-" + artag_end;
+    src = *it;
   }
-  while (KST::dataTagNameNotUnique(artag, false)) {
-    artag += "\'";
+  src->writeLock();
+  KST::dataSourceList.lock().writeUnlock();
+
+  // make sure field is valid
+  if (!src->isValidMatrix(field)) {
+    src->writeUnlock();
+    return QString::null;  
+  }
+  
+  // make sure name is unique, else generate a unique one
+  KST::matrixList.lock().readLock();
+ 
+  QString matrixName;
+  if (name.isEmpty()) {
+    matrixName = "M" + QString::number(KST::matrixList.count() + 1); 
+  } else {
+    matrixName = name;  
   }
 
-  //basic check to see if parameters are consistent with vector
-  (*iter)->readLock();
-  if (!useMaxX && (*iter)->length() < int(xNumSteps * yNumSteps)) {
-    (*iter)->readUnlock();
-    return QString::null;
+  while (KstData::self()->matrixTagNameNotUnique(matrixName, false)) {
+    matrixName = "M" + QString::number(KST::matrixList.count() + 1);
+  }
+  KST::matrixList.lock().readUnlock();
+
+  KstMatrixPtr p = new KstRMatrix(src, field, matrixName, xStart, yStart, xNumSteps, yNumSteps, 
+                                  boxcarFilter, skipFrames > 0, skipFrames);
+  KST::addMatrixToList(p);
+
+  src->writeUnlock();
+
+  if (p) {
+    _doc->forceUpdate();
+    _doc->setModified();
+    return p->tagName();
   }
 
-  //can't let yNumSteps be less than 1, or will divide by 0
-  if (yNumSteps < 1) {
-    (*iter)->readUnlock();
-    return QString::null;
-  }
-
-  if (xStepSize <= 0 || yStepSize <= 0) {
-    (*iter)->readUnlock();
-    return QString::null;
-  }
-  (*iter)->readUnlock();
-
-  //create the matrix
-  KstMatrixPtr matrix = new KstMatrix(artag, *iter, xNumSteps, yNumSteps, xMin, yMin, xStepSize, yStepSize, useMaxX);
-
-  KST::dataObjectList.lock().writeLock();
-  KST::dataObjectList.append(KstDataObjectPtr(matrix));
-  KST::dataObjectList.lock().writeUnlock();
-
-  _doc->forceUpdate();
-  _doc->setModified();
-
-  return artag;
+  return QString::null;
 }
 
+  
+QString KstIfaceImpl::createGradient(const QString& name, bool xDirection, double zAtMin, double zAtMax, 
+                                     int xNumSteps, int yNumSteps, double xMin, double yMin, 
+                                     double xStepSize, double yStepSize) {
+  // make sure tag name is unique
+  // make sure name is unique, else generate a unique one
+  KST::matrixList.lock().readLock();
+
+  QString matrixName;
+  if (name.isEmpty()) {
+    matrixName = "M" + QString::number(KST::matrixList.count() + 1); 
+  } else {
+    matrixName = name;  
+  }
+
+  while (KstData::self()->matrixTagNameNotUnique(matrixName, false)) {
+    matrixName = "M" + QString::number(KST::matrixList.count() + 1);
+  }
+  KST::matrixList.lock().readUnlock();
+  
+  // create the gradient matrix
+  KstMatrixPtr p = new KstSMatrix(matrixName, xNumSteps, yNumSteps, xMin, yMin, xStepSize, yStepSize, 
+                                  zAtMin, zAtMax, xDirection);
+  
+  KST::addMatrixToList(p);
+
+  if (p) {
+    _doc->forceUpdate();
+    _doc->setModified();
+    return p->tagName();
+  }
+
+  return QString::null;
+}
+                
+
 QString KstIfaceImpl::createImage(const QString &name,
                                   const QString &in_matrix,
                                   double lowerZ,
@@ -1555,9 +1684,9 @@ QString KstIfaceImpl::createImage(const QString &name,
     QString imgtag_end = QString(name);
     //count number of data objects and make a unique name
     int i = KST::dataObjectList.count() + 1;
-    QString imgtag = "Img" + QString::number(i) + "-" + imgtag_end;
+    imgtag = QString::number(i) + "-" + imgtag_end;
   }
-  while (KST::dataTagNameNotUnique(imgtag, false)) {
+  while (KstData::self()->dataTagNameNotUnique(imgtag, false)) {
     imgtag += "\'";
   }
 
@@ -1620,6 +1749,9 @@ bool KstIfaceImpl::addPlotMarker(const QString &plotName, double markerValue) {
       Kst2DPlotList::Iterator plot_iter=plotlist.findTag(plotName);
       if (plot_iter != plotlist.end() && (*plot_iter)->setPlotMarker(markerValue)) {
         app->deleteIterator(iter);
+        // repaint the plot 
+        (*plot_iter)->setDirty();
+        viewwindow->view()->paint(KstPainter::P_PLOT);
         return true;
       }
     }
@@ -1657,7 +1789,6 @@ bool KstIfaceImpl::changeDataFile(const QString& vector, const QString& fileName
   KstDataSourceList::Iterator it = KST::dataSourceList.findReusableFileName(fileName);
   KstDataSourcePtr file;
   QString invalidSources;
-  int invalid = 0;
 
   if (it == KST::dataSourceList.end()) {
     file = KstDataSource::loadSource(fileName);
