@@ -1,5 +1,5 @@
 /***************************************************************************
-                       kstcurvedialog_i.h  -  Part of KST
+                       kstimagedialog_i.h  -  Part of KST
                              -------------------
     begin                :
     copyright            : (C) 2003 The University of Toronto
@@ -19,54 +19,67 @@
 #ifndef KSTIMAGEDIALOGI_H
 #define KSTIMAGEDIALOGI_H
 
-#include "imagedialog.h"
+#include "kstdatadialog.h"
 #include "kstimage.h"
+#include "kst_export.h"
 
-class KstImageDialogI : public KstImageDialog {
+class ImageDialogWidget;
+
+class KST_EXPORT KstImageDialogI : public KstDataDialog {
   Q_OBJECT
   public:
-    KstImageDialogI(QWidget *parent = 0, const char *name = 0,
-        bool modal = false, WFlags fl = 0 );
+    KstImageDialogI(QWidget *parent = 0, const char *name = 0, bool modal = false, WFlags fl = 0 );
     virtual ~KstImageDialogI();
+    static KstImageDialogI *globalInstance();
 
   public slots:
     void update();
     void updateWindow();
+    bool newObject();
+    bool editObject();
+    void populateEditMultiple();
+    void setMatrix(const QString& name);
 
-    bool new_I();
-    bool edit_I();
-
-    static KstImageDialogI *globalInstance();
-
+  private:
+    static QGuardedPtr<KstImageDialogI> _inst;
+    void placeInPlot(KstImagePtr image);
+    bool checkParameters(double& lowerZDouble, double& upperZDouble);
+    void fillFieldsForEditNoUpdate();
+    
+    // the following are for the multiple edit mode
+    bool _matrixDirty : 1;
+    bool _colorOnlyDirty : 1;
+    bool _contourOnlyDirty : 1;
+    bool _colorAndContourDirty : 1;
+    bool _paletteDirty : 1;
+    bool _lowerZDirty : 1;
+    bool _upperZDirty : 1;
+    bool _realTimeAutoThresholdDirty : 1;
+    bool _numContourLinesDirty : 1;
+    bool _contourWeightDirty : 1;
+    bool _useVariableWeightDirty : 1;
+    bool _contourColorDirty : 1;
+    bool editSingleObject(KstImagePtr imPtr);
+    
   private slots:
     void calcAutoThreshold();
     void updateGroups();
     void updateEnables();
-
-  signals:
-    void modified();
-
+    void updatePalette(const QString& palette);
+    
+    // for multiple edit mode
+    void setColorOnlyDirty() { _colorOnlyDirty = true; }
+    void setContourOnlyDirty() { _contourOnlyDirty = true; }
+    void setColorAndContourDirty() { _colorAndContourDirty = true; }
+    void setRealTimeAutoThresholdDirty();
+    void setUseVariableWeightDirty();
+    void setContourColorDirty() { _contourColorDirty = true; }
+    
   private:
-    static QGuardedPtr<KstImageDialogI> _inst;
-    KstImagePtr _getPtr(const QString& tagin);
-
-    bool _newDialog;
-    KstImagePtr DP;
-    void placeInPlot(KstImagePtr image);
-    bool checkParameters(double& lowerZDouble, double& upperZDouble);
-
-    /***********************************/
-    /** defined in dataobjectdialog.h **/
-  public slots:
-    void show_Edit(const QString &field);
-    void show_New();
-    void OK();
-    void Init();
-    void close();
-    void reject();
-  private:
-    void _fillFieldsForEdit();
-    void _fillFieldsForNew();
+    void fillFieldsForEdit();
+    void fillFieldsForNew();
+    void cleanup();
+    ImageDialogWidget *_w;
 };
 
 #endif
