@@ -216,6 +216,13 @@ KstPlotDialogI::KstPlotDialogI(KstDoc *in_doc, QWidget* parent,
 
   _yMarksInsidePlot->setChecked(true);
   _xMarksInsidePlot->setChecked(true);
+  
+#if 0
+  // FIXME: should use kstsettings
+  _axisPenWidth->setValue(0);
+  _majorPenWidth->setValue(0);
+  _minorPenWidth->setValue(0);
+#endif
 }
 
 
@@ -489,6 +496,10 @@ void KstPlotDialogI::update(int new_index) {
     plotColors->setForeground(plot->foregroundColor());
     plotColors->setBackground(plot->backgroundColor());
 
+#if 0
+    _axisPenWidth->setValue(plot->axisPenWidth());
+#endif
+
       //update the tick display options
     _xMarksInsidePlot->setChecked(plot->xTicksInPlot() && !plot->xTicksOutPlot());
     _xMarksOutsidePlot->setChecked(plot->xTicksOutPlot() && !plot->xTicksInPlot());
@@ -503,7 +514,7 @@ void KstPlotDialogI::update(int new_index) {
     _suppressBottom->setChecked(plot->suppressBottom());
     _suppressRight->setChecked(plot->suppressRight());
     _suppressLeft->setChecked(plot->suppressLeft());
-    
+
     //update axes transforms
     _yTransformRight->setChecked(!plot->yTransformedExp().isEmpty());
     _yTransformRightExp->setText(plot->yTransformedExp());
@@ -567,13 +578,19 @@ void KstPlotDialogI::applyAppearance(Kst2DPlotPtr plot) {
 
     plotExtra->setForegroundColor(plotColors->foreground());
     plotExtra->setBackgroundColor(plotColors->background());
-    
+
     // gridlines colors
     plotExtra->setGridLinesColor(_majorGridColor->color(),
                                  _minorGridColor->color(),
                                  _checkBoxDefaultMajorGridColor->isChecked(),
                                  _checkBoxDefaultMinorGridColor->isChecked());
 
+#if 0
+    plotExtra->setAxisPenWidth(_axisPenWidth->value());
+    plotExtra->setMajorPenWidth(_majorPenWidth->value());
+    plotExtra->setMinorPenWidth(_minorPenWidth->value());
+#endif
+
     plotExtra->xLabel()->setFontName(FontComboBox->currentText());
     plotExtra->xLabel()->setFontSize(XLabelFontSize->value());
 
@@ -1427,6 +1444,10 @@ void KstPlotDialogI::updateGridSettings() {
       _yMinorGrid->setChecked(plot->hasYMinorGrid());
       _majorGridColor->setColor(plot->majorGridColor());
       _minorGridColor->setColor(plot->minorGridColor());
+#if 0
+      _majorPenWidth->setValue(plot->majorPenWidth());
+      _minorPenWidth->setValue(plot->minorPenWidth());
+#endif
       _checkBoxDefaultMajorGridColor->setChecked(plot->defaultMajorGridColor());
       _checkBoxDefaultMinorGridColor->setChecked(plot->defaultMinorGridColor());
     }
@@ -1442,6 +1463,12 @@ void KstPlotDialogI::updateAxesButtons() {
   _checkBoxDefaultMinorGridColor->setEnabled(minor);
   _majorGridColor->setEnabled(major && !_checkBoxDefaultMajorGridColor->isChecked());
   _minorGridColor->setEnabled(minor && !_checkBoxDefaultMinorGridColor->isChecked());
+#if 0
+  _majorPenWidth->setEnabled(major);
+  _minorPenWidth->setEnabled(minor);
+  _majorPenWidthLabel->setEnabled(major);
+  _minorPenWidthLabel->setEnabled(minor);
+#endif
   _xMinorTicks->setEnabled(!_xMinorTicksAuto->isChecked());
   _yMinorTicks->setEnabled(!_yMinorTicksAuto->isChecked());
 }
