@@ -22,7 +22,7 @@
 #include <qstylesheet.h>
 
 // include files for KDE
-#include <kdebug.h>
+#include "ksdebug.h"
 #include <klocale.h>
 
 // application specific includes
@@ -33,14 +33,16 @@
 #include "plugincollection.h"
 
 
-KstPlugin::KstPlugin() : KstDataObject() {
+KstPlugin::KstPlugin()
+: KstDataObject() {
   _inStringCnt = 0;
   _outStringCnt = 0;
   commonConstructor();
 }
 
 
-KstPlugin::KstPlugin(const QDomElement &e) : KstDataObject(e) {
+KstPlugin::KstPlugin(const QDomElement& e)
+: KstDataObject(e) {
   QString pluginName;
 
   _inStringCnt = 0;
@@ -172,9 +174,10 @@ void KstPlugin::commonConstructor() {
   _inArrayCnt = 0;
   _outArrayCnt = 0;
   _typeString = i18n("Plugin");
+  _type = "Plugin";
   _plugin = 0L;
   _localData = 0L;
-  //kdDebug() << "Creating KSTPlugin: " << long(this) << endl;
+  //kstdDebug() << "Creating KSTPlugin: " << long(this) << endl;
 }
 
 
@@ -186,7 +189,7 @@ KstPlugin::~KstPlugin() {
     }
     _localData = 0L;
   }
-  //kdDebug() << "Destroying KSTPlugin: " << long(this) << endl;
+  //kstdDebug() << "Destroying KSTPlugin: " << long(this) << endl;
 }
 
 
@@ -369,6 +372,7 @@ KstObject::UpdateType KstPlugin::update(int update_counter) {
     itcnt = 0;
     vitcnt = 0;
     sitcnt = 0;
+    setLastUpdateResult(UPDATE); // make sure that provider callbacks work
     // Read back the output vectors and scalars
     for (QValueList<Plugin::Data::IOValue>::ConstIterator it = otable.begin();
         it != otable.end();
@@ -588,7 +592,7 @@ KstSharedPtr<Plugin> KstPlugin::plugin() const {
 
 
 void KstPlugin::_showDialog() {
-  KstDialogs::showPluginDialog(tagName());
+  KstDialogs::self()->showPluginDialog(tagName());
 }
 
 
@@ -596,9 +600,14 @@ const KstCurveHintList* KstPlugin::curveHints() const {
   _curveHints->clear();
   if (_plugin) {
     for (QValueList<Plugin::Data::CurveHint>::ConstIterator i = _plugin->data()._hints.begin(); i != _plugin->data()._hints.end(); ++i) {
-      _curveHints->append(new KstCurveHint((*i).name, _outputVectors[(*i).x]->tagName(), _outputVectors[(*i).y]->tagName()));
+      KstVectorPtr xv = _outputVectors[(*i).x];
+      KstVectorPtr yv = _outputVectors[(*i).y];
+      if (xv && yv) {
+        _curveHints->append(new KstCurveHint((*i).name, xv->tagName(), yv->tagName()));
+      }
     }
   }
+
   return KstDataObject::curveHints();
 }
 
@@ -608,22 +617,27 @@ QString KstPlugin::lastError() const {
 }
 
 
+// FIXME: KstPlugin should not know about fit scalars!!
 void KstPlugin::createFitScalars() {
   if (_plugin->data()._isFit && _outputVectors.contains("Parameters")) {
     KstVectorPtr vectorParam = _outputVectors["Parameters"];
     if (vectorParam) {
-      for (int i = 0; i < vectorParam->length(); i++) {
-        const QString& paramName = _plugin->parameterName(i);
-        if (!paramName.isEmpty()) {
+      QString paramName;
+      int i = 0;
+      int length = vectorParam->length();
+
+      for (paramName = _plugin->parameterName(i); 
+          !paramName.isEmpty() && i < length; 
+           paramName = _plugin->parameterName(++i)) {
+        double scalarValue = vectorParam->value(i);
+        if (!_outputScalars.contains(paramName)) {
           QString scalarName = i18n("%1-%2").arg(tagName()).arg(paramName);
-          double scalarValue = vectorParam->value(i);
-          if (!_outputScalars.contains(paramName)) {
-            KstScalarPtr s = new KstScalar(scalarName);
-            s->writeLock();
-            s->setProvider(this);
-            s->writeUnlock();
-            _outputScalars.insert(paramName, s);
-          }
+          KstScalarPtr s = new KstScalar(scalarName, scalarValue);
+          s->writeLock();
+          s->setProvider(this);
+          s->writeUnlock();
+          _outputScalars.insert(paramName, s);
+        } else {
           _outputScalars[paramName]->setValue(scalarValue);
         }
       }
@@ -631,4 +645,53 @@ void KstPlugin::createFitScalars() {
   }
 }
 
+
+KstDataObjectPtr KstPlugin::makeDuplicate(KstDataObjectDataObjectMap& duplicatedMap) {
+  KstPluginPtr plugin = new KstPlugin;
+
+  // use same inputs
+  for (KstVectorMap::ConstIterator iter = _inputVectors.begin(); iter != _inputVectors.end(); ++iter) {
+    plugin->inputVectors().insert(iter.key(), iter.data());
+  }
+  for (KstScalarMap::ConstIterator iter = _inputScalars.begin(); iter != _inputScalars.end(); ++iter) {
+    plugin->inputScalars().insert(iter.key(), iter.data());  
+  }
+  for (KstStringMap::ConstIterator iter = _inputStrings.begin(); iter != _inputStrings.end(); ++iter) {
+    plugin->inputStrings().insert(iter.key(), iter.data());  
+  }
+  
+  // create new outputs
+  for (KstVectorMap::ConstIterator iter = outputVectors().begin(); iter != outputVectors().end(); ++iter) {
+    KstVectorPtr v = new KstVector;
+    v->writeLock();
+    plugin->outputVectors().insert(iter.key(), v);
+    v->setTagName(iter.data()->tagName() + "'");
+    v->setProvider(plugin.data());
+    KST::addVectorToList(v);
+    v->writeUnlock();
+  }
+  for (KstScalarMap::ConstIterator iter = outputScalars().begin(); iter != outputScalars().end(); ++iter) {
+    KstScalarPtr s = new KstScalar;
+    s->writeLock();
+    plugin->outputScalars().insert(iter.key(), s);
+    s->setTagName(iter.data()->tagName() + "'");
+    s->setProvider(plugin.data());
+    s->writeUnlock();
+  }
+  for (KstStringMap::ConstIterator iter = outputStrings().begin(); iter != outputStrings().end(); ++iter) {
+    KstStringPtr s = new KstString;
+    s->writeLock();
+    plugin->outputStrings().insert(iter.key(), s);
+    s->setTagName(iter.data()->tagName() + "'");
+    s->setProvider(plugin.data());
+    s->writeUnlock();  
+  }
+  
+  // set the same plugin
+  plugin->setPlugin(_plugin);
+  plugin->setTagName(tagName() + "'");
+  duplicatedMap.insert(this, KstDataObjectPtr(plugin));  
+  return KstDataObjectPtr(plugin);
+}
+
 // vim: ts=2 sw=2 et
