@@ -28,11 +28,12 @@
 #include <qtextedit.h>
 #include <qtimer.h>
 #include <qtooltip.h>
+#include <qvbox.h>
 #include <qwhatsthis.h>
 
 // include files for KDE
 #include <kcolorbutton.h>
-#include <kdebug.h>
+#include <klocale.h>
 #include <kmessagebox.h>
 
 // application specific includes
@@ -40,15 +41,13 @@
 #include "kstplugindialog_i.h"
 #include "kstdefaultnames.h"
 #include "plugincollection.h"
+#include "plugindialogwidget.h"
 #include "pluginmanager.h"
 #include "scalarselector.h"
 #include "stringselector.h"
 #include "vectorselector.h"
 
-#define DIALOGTYPE KstPluginDialogI
-#define DTYPE "Plugin"
-#include "dataobjectdialog.h"
-
+const QString& KstPluginDialogI::plugin_defaultTag = KGlobal::staticQString("<Auto Name>");
 
 QGuardedPtr<KstPluginDialogI> KstPluginDialogI::_inst;
 
@@ -59,40 +58,33 @@ KstPluginDialogI *KstPluginDialogI::globalInstance() {
   return _inst;
 }
 
-KstPluginDialogI::KstPluginDialogI(QWidget* parent, const char* name,
-                                   bool modal, WFlags fl)
-: KstPluginDialog(parent, name, modal, fl) {
-  Init();
-  connect(PluginCombo, SIGNAL(activated(int)), this, SLOT(pluginChanged(int)));
-  connect(_pluginManager, SIGNAL(clicked()), this, SLOT(showPluginManager()));
-  
+
+KstPluginDialogI::KstPluginDialogI(QWidget* parent, const char* name, bool modal, WFlags fl)
+: KstDataDialog(parent, name, modal, fl) {
+  _w = new PluginDialogWidget(_contents);
+  setMultiple(false);
+  connect(_w->PluginCombo, SIGNAL(activated(int)), this, SLOT(pluginChanged(int)));
+  connect(_w->_pluginManager, SIGNAL(clicked()), this, SLOT(showPluginManager()));
+
   _pluginInfoGrid = 0L;
   _pluginInputOutputGrid = 0L;
 }
 
 
 KstPluginDialogI::~KstPluginDialogI() {
-  DP = 0L;
-}
-
-
-KstPluginPtr KstPluginDialogI::_getPtr(const QString &tagin) {
-  KstPluginList c = kstObjectSubList<KstDataObject, KstPlugin>(KST::dataObjectList);
-
-  return *c.findTag(tagin);
 }
 
 
 void KstPluginDialogI::updatePluginList() {
   PluginCollection *pc = PluginCollection::self();
-  QString previous = _pluginList[PluginCombo->currentItem()];
+  QString previous = _pluginList[_w->PluginCombo->currentItem()];
   int newFocus = -1;
 
   const QMap<QString,Plugin::Data>& pluginMap = pc->pluginList();
 
   QMap<QString,QString> oldIEntries, oldOEntries;
 
-  PluginCombo->clear();
+  _w->PluginCombo->clear();
   _pluginList.clear();
   int cnt = 0;
   Plugin::Data restoreEntry;
@@ -100,7 +92,7 @@ void KstPluginDialogI::updatePluginList() {
                                                   it != pluginMap.end();
                                                                    ++it) {
     _pluginList += it.data()._name;
-    PluginCombo->insertItem(i18n("%1 (v%2)").arg(it.data()._readableName).arg(it.data()._version));
+    _w->PluginCombo->insertItem(i18n("%1 (v%2)").arg(it.data()._readableName).arg(it.data()._version));
     if (it.data()._name == previous) {
       newFocus = cnt;
       oldIEntries = cacheInputs(it.data()._inputs);
@@ -111,40 +103,40 @@ void KstPluginDialogI::updatePluginList() {
   }
 
   if (newFocus != -1) {
-    PluginCombo->setCurrentItem(newFocus);
-    pluginChanged(PluginCombo->currentItem());
+    _w->PluginCombo->setCurrentItem(newFocus);
+    pluginChanged(_w->PluginCombo->currentItem());
     restoreInputs(restoreEntry._inputs, oldIEntries);
     restoreInputs(restoreEntry._outputs, oldOEntries);
   } else {
-    PluginCombo->setCurrentItem(0);
+    _w->PluginCombo->setCurrentItem(0);
     pluginChanged(0);
   }
 }
 
 
 void KstPluginDialogI::updateForm() {
-  KstSharedPtr<Plugin> plugin = PluginCollection::self()->plugin(_pluginList[PluginCombo->currentItem()]);
+  KstSharedPtr<Plugin> plugin = PluginCollection::self()->plugin(_pluginList[_w->PluginCombo->currentItem()]);
   if (plugin) {
     const QValueList<Plugin::Data::IOValue>& itable = plugin->data()._inputs;
     for (QValueList<Plugin::Data::IOValue>::ConstIterator it = itable.begin(); it != itable.end(); ++it) {
       if ((*it)._type == Plugin::Data::IOValue::TableType) { // vector
-        QObject *field = _pluginInputOutputFrame->child((*it)._name.latin1(), "VectorSelector");
+        QObject *field = _w->_pluginInputOutputFrame->child((*it)._name.latin1(), "VectorSelector");
         assert(field);
         if (field) {
           VectorSelector *vs = static_cast<VectorSelector*>(field);
           vs->update();
         }
       } else if ((*it)._type == Plugin::Data::IOValue::StringType) { // string
-        QObject *field = _pluginInputOutputFrame->child((*it)._name.latin1(), "StringSelector");
+        QObject *field = _w->_pluginInputOutputFrame->child((*it)._name.latin1(), "StringSelector");
         assert(field);
         if (field) {
           StringSelector *ss = static_cast<StringSelector*>(field);
           ss->update();
         }
-      } else if ((*it)._type == Plugin::Data::IOValue::PidType) { 
+      } else if ((*it)._type == Plugin::Data::IOValue::PidType) {
         // Nothing
       } else {
-        QObject *field = _pluginInputOutputFrame->child((*it)._name.latin1(), "ScalarSelector");
+        QObject *field = _w->_pluginInputOutputFrame->child((*it)._name.latin1(), "ScalarSelector");
         assert(field);
         if (field) {
           ScalarSelector *ss = static_cast<ScalarSelector*>(field);
@@ -156,88 +148,99 @@ void KstPluginDialogI::updateForm() {
 }
 
 
-void KstPluginDialogI::_fillFieldsForEdit() {
-  if (!DP || !DP->plugin()) {
+void KstPluginDialogI::fillFieldsForEdit() {
+  KstPluginPtr pp = kst_cast<KstPlugin>(_dp);
+  if (!pp) {
     return;
   }
-  DP->readLock();
-  _tagName->setText(DP->tagName());
+  pp->readLock();
+  if (!pp->plugin()) { // plugin() can be null if the kst file is invalid
+    pp->readUnlock();
+    return;
+  }
+  const QString pluginName(pp->tagName());
+  const QString pluginObjectName(pp->plugin()->data()._name);
+  const int usage = pp->getUsage();
+  KstSharedPtr<Plugin> plug = pp->plugin();
+  pp->readUnlock();
 
+  _tagName->setText(pluginName);
   updatePluginList();
 
-  int i = _pluginList.findIndex(DP->plugin()->data()._name);
-  PluginCombo->setCurrentItem(i);
-  pluginChanged(PluginCombo->currentItem());
+  int i = _pluginList.findIndex(pluginObjectName);
+  _w->PluginCombo->setCurrentItem(i);
+  pluginChanged(_w->PluginCombo->currentItem());
 
-  fillVectorScalarCombos(DP->plugin());
-  PluginCombo->setEnabled(DP->getUsage() < 2);
-  DP->readUnlock();
+  fillVectorScalarCombos(plug);
+  _w->PluginCombo->setEnabled(usage < 3);
 
-  show();
   fixupLayout();
 }
 
 
-void KstPluginDialogI::_fillFieldsForNew() { 
+void KstPluginDialogI::fillFieldsForNew() {
   updatePluginList();
-  PluginCombo->setCurrentItem(0);
-  pluginChanged(PluginCombo->currentItem());
-  _tagName->setText(plugin_defaultTag); 
+  _w->PluginCombo->setCurrentItem(0);
+  pluginChanged(_w->PluginCombo->currentItem());
+  _tagName->setText(plugin_defaultTag);
 }
 
 
 void KstPluginDialogI::fillVectorScalarCombos(KstSharedPtr<Plugin> plugin) {
   bool DPvalid = false;
+  KstPluginPtr pp = kst_cast<KstPlugin>(_dp);
 
-  if (DP && DP->isValid()) {
-    DPvalid = true;
+  if (pp) {
+    pp->readLock();
+    DPvalid = pp->isValid();
+    pp->readUnlock();
   }
 
   if (plugin) {
     if (DPvalid) {
-      DP->readLock();
+      pp->readLock();
     }
     // Update input vector and scalar combos
     const QValueList<Plugin::Data::IOValue>& itable = plugin->data()._inputs;
     for (QValueList<Plugin::Data::IOValue>::ConstIterator it = itable.begin();
          it != itable.end(); ++it) {
       if ((*it)._type == Plugin::Data::IOValue::TableType) { // vector
-        QObject *field = _pluginInputOutputFrame->child((*it)._name.latin1(), "VectorSelector");
+        QObject *field = _w->_pluginInputOutputFrame->child((*it)._name.latin1(), "VectorSelector");
         assert(field);
         if (field) {
           VectorSelector *vs = static_cast<VectorSelector*>(field);
           QString selectedVector = vs->selectedVector();
           vs->update();
           if (DPvalid) {
-            vs->setSelection(DP->inputVectors()[(*it)._name]->tagName());
+            vs->setSelection(pp->inputVectors()[(*it)._name]->tagName());
           } else {
             vs->setSelection(selectedVector);
           }
         }
       } else if ((*it)._type == Plugin::Data::IOValue::StringType) {
-        QObject *field = _pluginInputOutputFrame->child((*it)._name.latin1(), "StringSelector");
+        QObject *field = _w->_pluginInputOutputFrame->child((*it)._name.latin1(), "StringSelector");
         assert(field);
         if (field) {
           StringSelector *ss = static_cast<StringSelector*>(field);
           QString selectedString = ss->selectedString();
           ss->update();
           if (DPvalid) {
-            ss->setSelection(DP->inputStrings()[(*it)._name]->tagName());
+            ss->setSelection(pp->inputStrings()[(*it)._name]->tagName());
           } else {
             ss->setSelection(selectedString);
           }
         }
-      } else if ((*it)._type == Plugin::Data::IOValue::PidType) { 
+      } else if ((*it)._type == Plugin::Data::IOValue::PidType) {
         // Nothing
       } else {
-        QObject *field = _pluginInputOutputFrame->child((*it)._name.latin1(), "ScalarSelector");
+        QObject *field = _w->_pluginInputOutputFrame->child((*it)._name.latin1(), "ScalarSelector");
         assert(field);
         if (field) {
           ScalarSelector *ss = static_cast<ScalarSelector*>(field);
           QString selectedScalar = ss->selectedScalar();
           ss->update();
           if (DPvalid) {
-            ss->setSelection(DP->inputScalars()[(*it)._name]->tagName());
+            ss->setSelection(pp->inputScalars()[(*it)._name]->tagName());
           } else {
             ss->setSelection(selectedScalar);
           }
@@ -249,30 +252,30 @@ void KstPluginDialogI::fillVectorScalarCombos(KstSharedPtr<Plugin> plugin) {
     if (DPvalid) {
       const QValueList<Plugin::Data::IOValue>& otable = plugin->data()._outputs;
       for (QValueList<Plugin::Data::IOValue>::ConstIterator it = otable.begin(); it != otable.end(); ++it) {
-        QObject *field = _pluginInputOutputFrame->child((*it)._name.latin1(), "QLineEdit");
+        QObject *field = _w->_pluginInputOutputFrame->child((*it)._name.latin1(), "QLineEdit");
         assert(field);
         if (field) {
           QLineEdit *li = static_cast<QLineEdit*>(field);
           QString ts;
           if ((*it)._type == Plugin::Data::IOValue::TableType) { // vector
-            ts = DP->outputVectors()[(*it)._name]->tagName();
+            ts = pp->outputVectors()[(*it)._name]->tagName();
           } else if ((*it)._type == Plugin::Data::IOValue::PidType) {
           } else if ((*it)._type == Plugin::Data::IOValue::StringType) {
-            ts = DP->outputStrings()[(*it)._name]->tagName();
+            ts = pp->outputStrings()[(*it)._name]->tagName();
           } else { // scalar
-            ts = DP->outputScalars()[(*it)._name]->tagName();
+            ts = pp->outputScalars()[(*it)._name]->tagName();
           }
           li->setText(ts);
         }
       }
-      DP->readUnlock();
+      pp->readUnlock();
     }
   } else { // invalid plugin
     PluginCollection *pc = PluginCollection::self();
-    QString cur = _pluginList[PluginCombo->currentItem()];
+    QString cur = _pluginList[_w->PluginCombo->currentItem()];
     Plugin::Data pdata = pc->pluginList()[pc->pluginNameList()[cur]];
     for (QValueList<Plugin::Data::IOValue>::ConstIterator it = pdata._outputs.begin(); it != pdata._outputs.end(); ++it) {
-      QObject *field = _pluginInputOutputFrame->child((*it)._name.latin1(), "QLineEdit");
+      QObject *field = _w->_pluginInputOutputFrame->child((*it)._name.latin1(), "QLineEdit");
       if (field) {
         static_cast<QLineEdit*>(field)->setText(QString::null);
       }
@@ -297,22 +300,22 @@ QMap<QString,QString> KstPluginDialogI::cacheInputs(const QValueList<Plugin::Dat
   QMap<QString,QString> rc;
   for (QValueList<Plugin::Data::IOValue>::ConstIterator it = table.begin(); it != table.end(); ++it) {
     if ((*it)._type == Plugin::Data::IOValue::TableType) {
-      QObject *field = _pluginInputOutputFrame->child((*it)._name.latin1(), "VectorSelector");
+      QObject *field = _w->_pluginInputOutputFrame->child((*it)._name.latin1(), "VectorSelector");
       if (field) {
         rc[(*it)._name] = static_cast<VectorSelector*>(field)->selectedVector();
       } else {
-        field = _pluginInputOutputFrame->child((*it)._name.latin1(), "QLineEdit");
+        field = _w->_pluginInputOutputFrame->child((*it)._name.latin1(), "QLineEdit");
         if (field) {
           rc[(*it)._name] = static_cast<QLineEdit*>(field)->text();
         }
       }
 
     } else if ((*it)._type == Plugin::Data::IOValue::StringType) {
-      QObject *field = _pluginInputOutputFrame->child((*it)._name.latin1(), "StringSelector");
+      QObject *field = _w->_pluginInputOutputFrame->child((*it)._name.latin1(), "StringSelector");
       if (field) {
         rc[(*it)._name] = static_cast<StringSelector*>(field)->selectedString();
       } else {
-        field = _pluginInputOutputFrame->child((*it)._name.latin1(), "QLineEdit");
+        field = _w->_pluginInputOutputFrame->child((*it)._name.latin1(), "QLineEdit");
         if (field) {
           rc[(*it)._name] = static_cast<QLineEdit*>(field)->text();
         }
@@ -320,11 +323,11 @@ QMap<QString,QString> KstPluginDialogI::cacheInputs(const QValueList<Plugin::Dat
     } else if ((*it)._type == Plugin::Data::IOValue::PidType) {
       // Nothing
     } else if ((*it)._type == Plugin::Data::IOValue::FloatType) {
-      QObject *field = _pluginInputOutputFrame->child((*it)._name.latin1(), "ScalarSelector");
+      QObject *field = _w->_pluginInputOutputFrame->child((*it)._name.latin1(), "ScalarSelector");
       if (field) {
         rc[(*it)._name] = static_cast<ScalarSelector*>(field)->selectedScalar();
       } else {
-        field = _pluginInputOutputFrame->child((*it)._name.latin1(), "QLineEdit");
+        field = _w->_pluginInputOutputFrame->child((*it)._name.latin1(), "QLineEdit");
         if (field) {
           rc[(*it)._name] = static_cast<QLineEdit*>(field)->text();
         }
@@ -341,21 +344,21 @@ void KstPluginDialogI::restoreInputs(const QValueList<Plugin::Data::IOValue>& ta
       continue;
     }
     if ((*it)._type == Plugin::Data::IOValue::TableType) {
-      QObject *field = _pluginInputOutputFrame->child((*it)._name.latin1(), "VectorSelector");
+      QObject *field = _w->_pluginInputOutputFrame->child((*it)._name.latin1(), "VectorSelector");
       if (field) {
         static_cast<VectorSelector*>(field)->setSelection(v[(*it)._name]);
       } else {
-        field = _pluginInputOutputFrame->child((*it)._name.latin1(), "QLineEdit");
+        field = _w->_pluginInputOutputFrame->child((*it)._name.latin1(), "QLineEdit");
         if (field) {
           static_cast<QLineEdit*>(field)->setText(v[(*it)._name]);
         }
       }
     } else if ((*it)._type == Plugin::Data::IOValue::StringType) {
-      QObject *field = _pluginInputOutputFrame->child((*it)._name.latin1(), "StringSelector");
+      QObject *field = _w->_pluginInputOutputFrame->child((*it)._name.latin1(), "StringSelector");
       if (field) {
         static_cast<StringSelector*>(field)->setSelection(v[(*it)._name]);
       } else {
-        field = _pluginInputOutputFrame->child((*it)._name.latin1(), "QLineEdit");
+        field = _w->_pluginInputOutputFrame->child((*it)._name.latin1(), "QLineEdit");
         if (field) {
           static_cast<QLineEdit*>(field)->setText(v[(*it)._name]);
         }
@@ -363,11 +366,11 @@ void KstPluginDialogI::restoreInputs(const QValueList<Plugin::Data::IOValue>& ta
     } else if ((*it)._type == Plugin::Data::IOValue::PidType) {
       // Nothing
     } else if ((*it)._type == Plugin::Data::IOValue::FloatType) {
-      QObject *field = _pluginInputOutputFrame->child((*it)._name.latin1(), "ScalarSelector");
+      QObject *field = _w->_pluginInputOutputFrame->child((*it)._name.latin1(), "ScalarSelector");
       if (field) {
         static_cast<ScalarSelector*>(field)->setSelection(v[(*it)._name]);
       } else {
-        field = _pluginInputOutputFrame->child((*it)._name.latin1(), "QLineEdit");
+        field = _w->_pluginInputOutputFrame->child((*it)._name.latin1(), "QLineEdit");
         if (field) {
           static_cast<QLineEdit*>(field)->setText(v[(*it)._name]);
         }
@@ -379,14 +382,14 @@ void KstPluginDialogI::restoreInputs(const QValueList<Plugin::Data::IOValue>& ta
 
 bool KstPluginDialogI::saveInputs(KstPluginPtr plugin, KstSharedPtr<Plugin> p) {
   bool rc = true;
-  
+
   KST::vectorList.lock().readLock();
   KST::scalarList.lock().readLock();
   KST::stringList.lock().readLock();
   const QValueList<Plugin::Data::IOValue>& itable = p->data()._inputs;
   for (QValueList<Plugin::Data::IOValue>::ConstIterator it = itable.begin(); it != itable.end(); ++it) {
     if ((*it)._type == Plugin::Data::IOValue::TableType) {
-      QObject *field = _pluginInputOutputFrame->child((*it)._name.latin1(), "VectorSelector");
+      QObject *field = _w->_pluginInputOutputFrame->child((*it)._name.latin1(), "VectorSelector");
       assert(field);
       VectorSelector *vs = static_cast<VectorSelector*>(field);
       KstVectorPtr v = *KST::vectorList.findTag(vs->selectedVector());
@@ -398,9 +401,10 @@ bool KstPluginDialogI::saveInputs(KstPluginPtr plugin, KstSharedPtr<Plugin> p) {
         plugin->inputVectors().insert((*it)._name, v);
       } else if (plugin->inputVectors().contains((*it)._name)) {
         plugin->inputVectors().erase((*it)._name);
+        rc = false;
       }
     } else if ((*it)._type == Plugin::Data::IOValue::StringType) {
-      QObject *field = _pluginInputOutputFrame->child((*it)._name.latin1(), "StringSelector");
+      QObject *field = _w->_pluginInputOutputFrame->child((*it)._name.latin1(), "StringSelector");
       assert(field);
       StringSelector *ss = static_cast<StringSelector*>(field);
       KstStringPtr s = *KST::stringList.findTag(ss->selectedString());
@@ -422,7 +426,7 @@ bool KstPluginDialogI::saveInputs(KstPluginPtr plugin, KstSharedPtr<Plugin> p) {
     } else if ((*it)._type == Plugin::Data::IOValue::PidType) {
       // Nothing
     } else if ((*it)._type == Plugin::Data::IOValue::FloatType) {
-      QObject *field = _pluginInputOutputFrame->child((*it)._name.latin1(), "ScalarSelector");
+      QObject *field = _w->_pluginInputOutputFrame->child((*it)._name.latin1(), "ScalarSelector");
       assert(field);
       ScalarSelector *ss = static_cast<ScalarSelector*>(field);
       KstScalarPtr s = *KST::scalarList.findTag(ss->selectedScalar());
@@ -457,7 +461,7 @@ bool KstPluginDialogI::saveInputs(KstPluginPtr plugin, KstSharedPtr<Plugin> p) {
   KST::stringList.lock().readUnlock();
   KST::scalarList.lock().readUnlock();
   KST::vectorList.lock().readUnlock();
-  
+
   return rc;
 }
 
@@ -466,7 +470,7 @@ bool KstPluginDialogI::saveOutputs(KstPluginPtr plugin, KstSharedPtr<Plugin> p)
   const QValueList<Plugin::Data::IOValue>& otable = p->data()._outputs;
 
   for (QValueList<Plugin::Data::IOValue>::ConstIterator it = otable.begin(); it != otable.end(); ++it) {
-    QObject *field = _pluginInputOutputFrame->child((*it)._name.latin1(), "QLineEdit");
+    QObject *field = _w->_pluginInputOutputFrame->child((*it)._name.latin1(), "QLineEdit");
     if (!field) {
       continue; // Some are unsupported
     }
@@ -483,7 +487,7 @@ bool KstPluginDialogI::saveOutputs(KstPluginPtr plugin, KstSharedPtr<Plugin> p)
 
     QString nt = li->text();
     if ((*it)._type == Plugin::Data::IOValue::TableType) {
-      if (!KST::vectorTagNameNotUnique(nt, false)) {
+      if (!KstData::self()->vectorTagNameNotUnique(nt, false)) {
         // Implicitly creates it if it doesn't exist
         KstVectorPtr v = plugin->outputVectors()[(*it)._name];
         if (!v) {
@@ -495,7 +499,7 @@ bool KstPluginDialogI::saveOutputs(KstPluginPtr plugin, KstSharedPtr<Plugin> p)
         v->setTagName(nt);
         v->setProvider(plugin.data()); // in case it's implicitly created
       } else if (plugin->outputVectors()[(*it)._name]->tagName() != nt) {
-        while (KST::vectorTagNameNotUnique(nt, false)) {
+        while (KstData::self()->vectorTagNameNotUnique(nt, false)) {
           nt += "'";
         }
         KstVectorPtr v;
@@ -511,7 +515,7 @@ bool KstPluginDialogI::saveOutputs(KstPluginPtr plugin, KstSharedPtr<Plugin> p)
         v->setTagName(nt);
       }
     } else if ((*it)._type == Plugin::Data::IOValue::StringType) {
-      if (!KST::vectorTagNameNotUnique(nt, false)) {
+      if (!KstData::self()->vectorTagNameNotUnique(nt, false)) {
         KstStringPtr s;
         if (plugin->outputStrings().contains((*it)._name)) {
           s = plugin->outputStrings()[(*it)._name];
@@ -523,7 +527,7 @@ bool KstPluginDialogI::saveOutputs(KstPluginPtr plugin, KstSharedPtr<Plugin> p)
         s->setTagName(nt);
         s->setProvider(plugin.data());
       } else if (plugin->outputStrings()[(*it)._name]->tagName() != nt) {
-        while (KST::vectorTagNameNotUnique(nt, false)) {
+        while (KstData::self()->vectorTagNameNotUnique(nt, false)) {
           nt += "'";
         }
         KstStringPtr s;
@@ -540,7 +544,7 @@ bool KstPluginDialogI::saveOutputs(KstPluginPtr plugin, KstSharedPtr<Plugin> p)
     } else if ((*it)._type == Plugin::Data::IOValue::PidType) {
       // Nothing
     } else if ((*it)._type == Plugin::Data::IOValue::FloatType) {
-      if (!KST::vectorTagNameNotUnique(nt, false)) {
+      if (!KstData::self()->vectorTagNameNotUnique(nt, false)) {
         KstScalarPtr s;
         if (plugin->outputScalars().contains((*it)._name)) {
           s = plugin->outputScalars()[(*it)._name];
@@ -552,7 +556,7 @@ bool KstPluginDialogI::saveOutputs(KstPluginPtr plugin, KstSharedPtr<Plugin> p)
         s->setTagName(nt);
         s->setProvider(plugin.data());
       } else if (plugin->outputScalars()[(*it)._name]->tagName() != nt) {
-        while (KST::vectorTagNameNotUnique(nt, false)) {
+        while (KstData::self()->vectorTagNameNotUnique(nt, false)) {
           nt += "'";
         }
         KstScalarPtr s;
@@ -573,21 +577,22 @@ bool KstPluginDialogI::saveOutputs(KstPluginPtr plugin, KstSharedPtr<Plugin> p)
 }
 
 
-bool KstPluginDialogI::new_I() {
+bool KstPluginDialogI::newObject() {
   QString tagName = _tagName->text();
 
-  if (tagName != plugin_defaultTag && KST::dataTagNameNotUnique(tagName, true, this)) {
+  if (tagName != plugin_defaultTag && KstData::self()->dataTagNameNotUnique(tagName, true, this)) {
     _tagName->setFocus();
     return false;
   }
   KstPluginPtr plugin;
-  int pitem = PluginCombo->currentItem();
-  if (pitem >= 0 && PluginCombo->count() > 0) {
+  int pitem = _w->PluginCombo->currentItem();
+  if (pitem >= 0 && _w->PluginCombo->count() > 0) {
     KstSharedPtr<Plugin> pPtr = PluginCollection::self()->plugin(_pluginList[pitem]);
     if (pPtr) {
       plugin = new KstPlugin;
       plugin->writeLock();
       if (!saveInputs(plugin, pPtr)) {
+        KMessageBox::sorry(this, i18n("One or more of the inputs was undefined."));
         plugin->writeUnlock();
         plugin = 0L;
         return false;
@@ -600,6 +605,7 @@ bool KstPluginDialogI::new_I() {
       }
       plugin->setTagName(tagName);
       if (!saveOutputs(plugin, pPtr)) {
+        KMessageBox::sorry(this, i18n("One or more of the outputs was undefined."));
         plugin->writeUnlock();
         plugin = 0L;
         return false;
@@ -609,7 +615,7 @@ bool KstPluginDialogI::new_I() {
   }
 
   if (!plugin || !plugin->isValid()) {
-    KMessageBox::sorry(this, i18n("There is an error in the plugin you entered.  Please fix the plugin."));
+    KMessageBox::sorry(this, i18n("There is an error in the plugin you entered."));
     return false;
   }
 
@@ -624,68 +630,68 @@ bool KstPluginDialogI::new_I() {
 }
 
 
-bool KstPluginDialogI::edit_I() {
-  if (!DP) { // something is dreadfully wrong - this should never happen
+bool KstPluginDialogI::editObject() {
+  KstPluginPtr pp = kst_cast<KstPlugin>(_dp);
+  if (!pp) { // something is dreadfully wrong - this should never happen
     return false;
   }
 
-  DP->writeLock();
-  if (_tagName->text() != DP->tagName() && KST::dataTagNameNotUnique(_tagName->text())) {
+  pp->writeLock();
+  if (_tagName->text() != pp->tagName() && KstData::self()->dataTagNameNotUnique(_tagName->text())) {
     _tagName->setFocus();
-    DP->writeUnlock();
+    pp->writeUnlock();
     return false;
   }
 
-  DP->setTagName(_tagName->text());
+  pp->setTagName(_tagName->text());
 
-  int pitem = PluginCombo->currentItem();
+  int pitem = _w->PluginCombo->currentItem();
   KstSharedPtr<Plugin> pPtr = PluginCollection::self()->plugin(_pluginList[pitem]);
 
   // Must unlock before clear()
-  for (KstVectorMap::Iterator i = DP->inputVectors().begin(); i != DP->inputVectors().end(); ++i) {
+  for (KstVectorMap::Iterator i = pp->inputVectors().begin(); i != pp->inputVectors().end(); ++i) {
     (*i)->writeUnlock();
   }
-  for (KstScalarMap::Iterator i = DP->inputScalars().begin(); i != DP->inputScalars().end(); ++i) {
+  for (KstScalarMap::Iterator i = pp->inputScalars().begin(); i != pp->inputScalars().end(); ++i) {
     (*i)->writeUnlock();
   }
-  for (KstStringMap::Iterator i = DP->inputStrings().begin(); i != DP->inputStrings().end(); ++i) {
+  for (KstStringMap::Iterator i = pp->inputStrings().begin(); i != pp->inputStrings().end(); ++i) {
     (*i)->writeUnlock();
   }
-  DP->inputVectors().clear();
-  DP->inputScalars().clear();
-  DP->inputStrings().clear();
+  pp->inputVectors().clear();
+  pp->inputScalars().clear();
+  pp->inputStrings().clear();
 
   // Save the vectors and scalars
-  if (!saveInputs(DP, pPtr)) {
-    KMessageBox::sorry(this, i18n("There is an error in the plugin you "
-                                  "entered. Please fix it."));
-    DP->writeUnlock();
+  if (!saveInputs(pp, pPtr)) {
+    KMessageBox::sorry(this, i18n("There is an error in the plugin you entered."));
+    pp->writeUnlock();
     return false;
   }
 
-  if (pitem >= 0 && PluginCombo->count() > 0) {
-    DP->setPlugin(pPtr);
+  if (pitem >= 0 && _w->PluginCombo->count() > 0) {
+    pp->setPlugin(pPtr);
   }
 
-  if (!saveOutputs(DP, pPtr)) {
-    KMessageBox::sorry(this, i18n("There is an error in the plugin you "
-                                  "entered. Please fix it."));
-    DP->writeUnlock();
+  if (!saveOutputs(pp, pPtr)) {
+    KMessageBox::sorry(this, i18n("There is an error in the plugin you entered."));
+    pp->writeUnlock();
     return false;
   }
 
-  if (!DP->isValid()) {
-    KMessageBox::sorry(this, i18n("There is an error in the plugin you entered. Please fix it."));
-    DP->writeUnlock();
+  if (!pp->isValid()) {
+    KMessageBox::sorry(this, i18n("There is an error in the plugin you entered."));
+    pp->writeUnlock();
     return false;
   }
-  DP->setDirty();
-  DP->writeUnlock();
+  pp->setDirty();
+  pp->writeUnlock();
 
   emit modified();
   return true;
 }
 
+
 void KstPluginDialogI::generateEntries(bool input, int& cnt, QWidget *parent, QGridLayout *grid, const QValueList<Plugin::Data::IOValue>& table) {
   QString scalarLabelTemplate, vectorLabelTemplate, stringLabelTemplate;
 
@@ -778,7 +784,7 @@ void KstPluginDialogI::generateEntries(bool input, int& cnt, QWidget *parent, QG
     grid->addWidget(label, cnt, 0);
     _pluginWidgets.push_back(label);
     label->show();
-    
+
     grid->addWidget(widget, cnt, 1);
     _pluginWidgets.push_back(widget);
     widget->show();
@@ -790,13 +796,13 @@ void KstPluginDialogI::generateEntries(bool input, int& cnt, QWidget *parent, QG
       QWhatsThis::add(widget, (*it)._description);
     }
 
-    cnt++;
+    ++cnt;
   }
 }
 
 
 void KstPluginDialogI::pluginChanged(int idx) {
-  
+
   // find all children and delete them and the grids
   while (!_pluginWidgets.isEmpty())
   {
@@ -808,64 +814,64 @@ void KstPluginDialogI::pluginChanged(int idx) {
   delete _pluginInputOutputGrid;
 
   // create new info grid
-  _pluginInfoGrid = new QGridLayout(_pluginInfoFrame, 2, 2, 0, 8);
+  _pluginInfoGrid = new QGridLayout(_w->_pluginInfoFrame, 2, 2, 0, 8);
   _pluginInfoGrid->setColStretch(1,1); // stretch the right column
   _pluginInfoGrid->setColStretch(0,0); // don't stretch the left column
 
-  if (idx >= 0 && PluginCombo->count() > 0) {
-    
+  if (idx >= 0 && _w->PluginCombo->count() > 0) {
+
     // get the plugin data
     const QString& pluginName = _pluginList[idx];
     const Plugin::Data& pluginData = PluginCollection::self()->pluginList()[PluginCollection::self()->pluginNameList()[pluginName]];
 
     // Setup the grid and the "static" entries
     QLabel* infoLabel;
-    
-    infoLabel = new QLabel(i18n("Plugin name:"), _pluginInfoFrame);
+
+    infoLabel = new QLabel(i18n("Plugin name:"), _w->_pluginInfoFrame);
     _pluginInfoGrid->addWidget(infoLabel, 0, 0);
-    _pluginWidgets.push_back(infoLabel);
+    _pluginWidgets.append(infoLabel);
     infoLabel->show();
-    
-    infoLabel = new QLabel(pluginData._readableName, _pluginInfoFrame);
+
+    infoLabel = new QLabel(pluginData._readableName, _w->_pluginInfoFrame);
     _pluginInfoGrid->addWidget(infoLabel, 0, 1);
-    _pluginWidgets.push_back(infoLabel);
+    _pluginWidgets.append(infoLabel);
     infoLabel->show();
-    
-    infoLabel = new QLabel(i18n("Description:"), _pluginInfoFrame);
+
+    infoLabel = new QLabel(i18n("Description:"), _w->_pluginInfoFrame);
     infoLabel->setAlignment(Qt::AlignTop);
     _pluginInfoGrid->addWidget(infoLabel, 1, 0);
-    _pluginWidgets.push_back(infoLabel);
+    _pluginWidgets.append(infoLabel);
     infoLabel->show();
-    
-    infoLabel = new QLabel(pluginData._description,  _pluginInfoFrame);
+
+    infoLabel = new QLabel(pluginData._description,  _w->_pluginInfoFrame);
     _pluginInfoGrid->addWidget(infoLabel, 1, 1);
-    _pluginWidgets.push_back(infoLabel);
+    _pluginWidgets.append(infoLabel);
     infoLabel->show();
-    
+
     // create a new inputoutput grid
     int cnt = 0;
     int numInputOutputs = pluginData._inputs.count() + pluginData._outputs.count();
-    
+
     // generate inputs
-    _pluginInputOutputGrid = new QGridLayout(_pluginInputOutputFrame, numInputOutputs + 1, 2, 0, 8);
+    _pluginInputOutputGrid = new QGridLayout(_w->_pluginInputOutputFrame, numInputOutputs + 1, 2, 0, 8);
     _pluginInputOutputGrid->setColStretch(1,1);
-    _pluginInputOutputGrid->setColStretch(0,0); 
-    generateEntries(true, cnt, _pluginInputOutputFrame, _pluginInputOutputGrid, pluginData._inputs);
-    
+    _pluginInputOutputGrid->setColStretch(0,0);
+    generateEntries(true, cnt, _w->_pluginInputOutputFrame, _pluginInputOutputGrid, pluginData._inputs);
+
     // insert separator
     cnt++;
-    QFrame* line = new QFrame(_pluginInputOutputFrame);
+    QFrame* line = new QFrame(_w->_pluginInputOutputFrame);
     line->setFrameShadow(QFrame::Sunken);
     line->setFrameShape(QFrame::HLine);
     _pluginInputOutputGrid->addMultiCellWidget(line, cnt, cnt, 0, 1);
     _pluginWidgets.push_back(line);
     line->show();
     cnt++;
-    
+
     // generate outputs
     _pluginInputOutputGrid->setColStretch(1,1);
-    _pluginInputOutputGrid->setColStretch(0,0); 
-    generateEntries(false, cnt, _pluginInputOutputFrame, _pluginInputOutputGrid, pluginData._outputs);
+    _pluginInputOutputGrid->setColStretch(0,0);
+    generateEntries(false, cnt, _w->_pluginInputOutputFrame, _pluginInputOutputGrid, pluginData._outputs);
   }
   // resize everything
   fixupLayout();
