@@ -23,13 +23,14 @@
 #define KSTPSD_H
 
 #include "kstdataobject.h"
+#include "kst_export.h"
 
-class KstPSD : public KstDataObject {
+class KST_EXPORT KstPSD : public KstDataObject {
   public:
     KstPSD(const QString& in_tag, KstVectorPtr in_V, double freq,
         bool average, int len,
         bool in_apodize, bool in_removeMean,
-        const QString& VUnits, const QString& RUnits);
+        const QString& VUnits, const QString& RUnits, int in_apodizeFxn = 0, double in_gaussianSigma = 3.0);
     KstPSD(const QDomElement& e);
     virtual ~KstPSD();
 
@@ -40,6 +41,12 @@ class KstPSD : public KstDataObject {
 
     bool apodize() const;
     void setApodize(bool in_apodize);
+    
+    int apodizeFxn() const;
+    void setApodizeFxn(int in_apodizeFxn);
+    
+    double gaussianSigma() const;
+    void setGaussianSigma(double in_gaussianSigma);
 
     bool removeMean() const;
     void setRemoveMean(bool in_removeMean);
@@ -72,16 +79,21 @@ class KstPSD : public KstDataObject {
     KstVectorPtr vY() const { return *_sVector; }
 
     const KstCurveHintList *curveHints() const;
+    
+    virtual KstDataObjectPtr makeDuplicate(KstDataObjectDataObjectMap& duplicatedMap);
 
   private:
     void GenW(int len);
     void commonConstructor(const QString& in_tag, KstVectorPtr in_V,
         double freq, bool average, int len,
         bool apodize, bool removeMean,
-        const QString& VUnits, const QString& RUnits);
+        const QString& VUnits, const QString& RUnits, int in_apodizeFxn, double in_gaussianSigma);
 
     void _adjustLengths();
     bool _Apodize;
+    int _apodizeFxn;
+    double _gaussianSigma;
+    int _prevApodizeFxn;
     bool _RemoveMean;
     bool _Average;
     int _last_f0;
@@ -98,6 +110,9 @@ class KstPSD : public KstDataObject {
     QString _rUnits;
 
     KstVectorMap::Iterator _sVector, _fVector;
+    static const QString& INVECTOR;
+    static const QString& SVECTOR;
+    static const QString& FVECTOR;
 };
 
 typedef KstSharedPtr<KstPSD> KstPSDPtr;
