@@ -22,12 +22,13 @@
 
 #include <qstylesheet.h>
 
-#include <kdebug.h>
+#include "ksdebug.h"
 #include <klocale.h>
 
 #include "kstdatacollection.h"
 #include "kstdebug.h"
 #include "kstrvector.h"
+#include "kstmath.h"
 
 // ReqNF <=0 means read from ReqF0 to end of File
 // ReqF0 < means start at EndOfFile-ReqNF.
@@ -304,27 +305,27 @@ int KstRVector::reqStartFrame() const {
 /** Save vector information */
 void KstRVector::save(QTextStream &ts, const QString& indent, bool saveAbsolutePosition) {
   if (_file) {    
-    ts << "  <vector>" << endl;
+    ts << indent << "<vector>" << endl;
 
-    ts << indent << "<tag>" << QStyleSheet::escape(tagName()) << "</tag>" << endl;
+    ts << indent << "  <tag>" << QStyleSheet::escape(tagName()) << "</tag>" << endl;
     _file->readLock();
-    ts << indent << "<filename>" << QStyleSheet::escape(_file->fileName()) << "</filename>" << endl;
+    ts << indent << "  <filename>" << QStyleSheet::escape(_file->fileName()) << "</filename>" << endl;
     _file->readUnlock();
-    ts << indent << "<field>" << _field << "</field>" << endl;
+    ts << indent << "  <field>" << _field << "</field>" << endl;
     if (saveAbsolutePosition) {
-      ts << indent << "<start>" << F0 << "</start>" << endl;
-      ts << indent << "<num>" << NF << "</num>" << endl;
+      ts << indent << "  <start>" << F0 << "</start>" << endl;
+      ts << indent << "  <num>" << NF << "</num>" << endl;
     } else {
-      ts << indent << "<start>" << ReqF0 << "</start>" << endl;
-      ts << indent << "<num>" << ReqNF << "</num>" << endl;
+      ts << indent << "  <start>" << ReqF0 << "</start>" << endl;
+      ts << indent << "  <num>" << ReqNF << "</num>" << endl;
     }
     if (doSkip()) {
-      ts << indent << "<skip>" << Skip << "</skip>" << endl;
+      ts << indent << "  <skip>" << Skip << "</skip>" << endl;
       if (doAve()) {
-        ts << indent << "<doAve/>" << endl;
+        ts << indent << "  <doAve/>" << endl;
       }
     }
-    ts << "  </vector>" << endl;
+    ts << indent << "</vector>" << endl;
   }
 }
 
@@ -430,7 +431,8 @@ KstObject::UpdateType KstRVector::doUpdate(bool force) {
   int i, k, shift, n_read=0;
   int ave_nread;
   int new_f0, new_nf;
-
+  bool start_past_eof = false;
+  
   checkIntegrity();
 
   if (DoSkip && Skip < 2 && SPF == 1) {
@@ -462,6 +464,7 @@ KstObject::UpdateType KstRVector::doUpdate(bool force) {
       // Tried to read starting past the end.
       new_f0 = 0;
       new_nf = 1;
+      start_past_eof = true;
     }
   }
 
@@ -499,7 +502,7 @@ KstObject::UpdateType KstRVector::doUpdate(bool force) {
 
   if (DoSkip) {
     // reallocate V if necessary
-    //kdDebug() << "new_nf = " << new_nf << " and skip = " << Skip << " so new_nf/Skip+1 = " << (new_nf / Skip + 1) << endl;
+    //kstdDebug() << "new_nf = " << new_nf << " and skip = " << Skip << " so new_nf/Skip+1 = " << (new_nf / Skip + 1) << endl;
     if (new_nf / Skip != _size) {
       bool rc = resize(new_nf/Skip);
       if (!rc) {
@@ -516,7 +519,7 @@ KstObject::UpdateType KstRVector::doUpdate(bool force) {
       } else {
         rc = _file->readField(_v + _numSamples, _field, new_f0, (new_nf - NF)/Skip, Skip, &lastRead);
         if (rc != -9999) {
-          //kdDebug() << "USED SKIP FOR READ - " << _field << " - rc=" << rc << " for Skip=" << Skip << " s=" << new_f0 << " n=" << (new_nf - NF)/Skip << endl;
+          //kstdDebug() << "USED SKIP FOR READ - " << _field << " - rc=" << rc << " for Skip=" << Skip << " s=" << new_f0 << " n=" << (new_nf - NF)/Skip << endl;
           if (rc >= 0) {
             n_read = rc;
           } else {
@@ -530,7 +533,7 @@ KstObject::UpdateType KstRVector::doUpdate(bool force) {
     if (_dontUseSkipAccel) {
       n_read = 0;
       /** read each sample from the File */
-      //kdDebug() << "NF = " << NF << " numsamples = " << _numSamples << " new_f0 = " << new_f0 << endl;
+      //kstdDebug() << "NF = " << NF << " numsamples = " << _numSamples << " new_f0 = " << new_f0 << endl;
       double *t = _v + _numSamples;
       int new_nf_Skip = new_nf - Skip;
       if (DoAve) {
@@ -555,7 +558,7 @@ KstObject::UpdateType KstRVector::doUpdate(bool force) {
         }
       } else {
         for (i = NF; new_nf_Skip >= i; i += Skip) {
-          //kdDebug() << "readField " << _field << " start=" << new_f0 + i << " n=-1" << endl;
+          //kstdDebug() << "readField " << _field << " start=" << new_f0 + i << " n=-1" << endl;
           n_read += _file->readField(t++, _field, new_f0 + i, -1);
         }
       }
@@ -575,14 +578,17 @@ KstObject::UpdateType KstRVector::doUpdate(bool force) {
     }
 
     // read the new data from file
-    if (_file->samplesPerFrame(_field) > 1) {
+    if (start_past_eof) {
+      _v[0] = KST::NOPOINT;
+      n_read = 1;
+    } else if (_file->samplesPerFrame(_field) > 1) {
       assert(new_nf - NF - 1 > 0 || new_nf - NF - 1 == -1);
       assert(new_f0 + NF >= 0);
       assert(new_f0 + new_nf - 1 >= 0);
       n_read = _file->readField(_v+NF*SPF, _field, new_f0 + NF, new_nf - NF - 1);
       n_read += _file->readField(_v+(new_nf-1)*SPF, _field, new_f0 + new_nf - 1, -1);
     } else {
-      //kdDebug() << "Reading into _v=" << (void*)_v << " which has size " << _size << " and starting at offset " << NF*SPF << " for s=" << new_f0 + NF << " and n=" << new_nf - NF << endl;
+      //kstdDebug() << "Reading into _v=" << (void*)_v << " which has size " << _size << " and starting at offset " << NF*SPF << " for s=" << new_f0 + NF << " and n=" << new_nf - NF << endl;
       assert(new_f0 + NF >= 0);
       if (new_nf - NF > 0 || new_nf - NF == -1) {
         n_read = _file->readField(_v+NF*SPF, _field, new_f0 + NF, new_nf - NF);
@@ -604,7 +610,7 @@ KstObject::UpdateType KstRVector::doUpdate(bool force) {
   // As a first fix, mount all nsf mounted dirfiles with "-o noac"
   _dirty = false;
   if (_numSamples != _size && !(_numSamples == 0 && _size == 1)) {
-    //kdDebug() << "SET DIRTY since _numSamples = " << _numSamples << " but _size = " << _size << endl;
+    //kstdDebug() << "SET DIRTY since _numSamples = " << _numSamples << " but _size = " << _size << endl;
     _dirty = true;
     for (i = _numSamples; i < _size; i++) {
       _v[i] = _v[0];
@@ -683,4 +689,9 @@ KstDataSourcePtr KstRVector::dataSource() const {
 }
 
 
+KstRVectorPtr KstRVector::makeDuplicate() const {
+  return new KstRVector(_file, _field, tagName() + "'", ReqF0, ReqNF, Skip, DoSkip, DoAve);
+}
+
+
 // vim: ts=2 sw=2 et
