@@ -20,17 +20,20 @@
 #include <kemailsettings.h>
 #include <kprinter.h>
 #include <kstaticdeleter.h>
+#include "ksttimezones.h"
 
 // application specific includes
 #include "kstsettings.h"
 
 KstSettings::KstSettings() {
   plotUpdateTimer = 200;
+  plotFontSize    = 12;
   backgroundColor = QColor(255, 255, 255); // white
   foregroundColor = QColor(0,0,0); // black
   promptWindowClose = true;
   showQuickStart = true;
-
+  curveColorSequencePalette = "Kst Colors";
+  
   xMajor = false;
   yMajor = false;
   xMinor = false;
@@ -52,14 +55,10 @@ KstSettings::KstSettings() {
   emailEncryption = EMailEncryptionNone;
   emailAuthentication = EMailAuthenticationPLAIN;
 
-  useUTC = true;
-
-  printing.pageSize = QString::number((int)KPrinter::Letter);
-  printing.orientation = "Landscape";
-  printing.plotDateTimeFooter = "0";
-  printing.maintainAspect = "0";
-  printing.curveWidthAdjust = "0";
-  printing.monochrome = "0";
+  timezone = "UTC";
+  offsetSeconds = 0;
+  
+  setPrintingDefaults();
 }
 
 
@@ -70,11 +69,16 @@ KstSettings::KstSettings(const KstSettings& x) {
 
 KstSettings& KstSettings::operator=(const KstSettings& x) {
   plotUpdateTimer = x.plotUpdateTimer;
+  plotFontSize    = x.plotFontSize;
   backgroundColor = x.backgroundColor;
   foregroundColor = x.foregroundColor;
   promptWindowClose = x.promptWindowClose;
   showQuickStart = x.showQuickStart;
-
+  curveColorSequencePalette = x.curveColorSequencePalette;
+  
+  timezone = x.timezone;
+  offsetSeconds = x.offsetSeconds;
+  
   xMajor = x.xMajor;
   yMajor = x.yMajor;
   xMinor = x.xMinor;
@@ -106,8 +110,19 @@ KstSettings& KstSettings::operator=(const KstSettings& x) {
   printing.maintainAspect = x.printing.maintainAspect;
   printing.curveWidthAdjust = x.printing.curveWidthAdjust;
   printing.monochrome = x.printing.monochrome;
-
-  useUTC = x.useUTC;
+  
+  printing.monochromeSettings.enhanceReadability = 
+      x.printing.monochromeSettings.enhanceReadability;
+  printing.monochromeSettings.pointStyleOrder = 
+      x.printing.monochromeSettings.pointStyleOrder;
+  printing.monochromeSettings.lineStyleOrder = 
+      x.printing.monochromeSettings.lineStyleOrder;
+  printing.monochromeSettings.lineWidthOrder = 
+      x.printing.monochromeSettings.lineWidthOrder;
+  printing.monochromeSettings.maxLineWidth = 
+      x.printing.monochromeSettings.maxLineWidth;
+  printing.monochromeSettings.pointDensity = 
+      x.printing.monochromeSettings.pointDensity;
 
   return *this;
 }
@@ -128,7 +143,6 @@ KstSettings *KstSettings::globalSettings() {
 
 void KstSettings::setGlobalSettings(const KstSettings *settings) {
   globalSettings(); // force instantiation
-
   *_self = *settings;
 }
 
@@ -138,12 +152,16 @@ void KstSettings::save() {
 
   cfg.setGroup("Kst");
   cfg.writeEntry("Plot Update Timer", plotUpdateTimer);
+  cfg.writeEntry("Plot Font Size", plotFontSize);
   cfg.writeEntry("Background Color", backgroundColor);
   cfg.writeEntry("Foreground Color", foregroundColor);
   cfg.writeEntry("Prompt on Window Close", promptWindowClose);
   cfg.writeEntry("Show QuickStart", showQuickStart);
-  cfg.writeEntry("Use UTC", useUTC);
-
+  cfg.writeEntry("Curve Color Sequence", curveColorSequencePalette);
+  
+  cfg.writeEntry("Timezone", timezone);
+  cfg.writeEntry("OffsetSeconds", offsetSeconds);
+  
   cfg.setGroup("Grid Lines");
   cfg.writeEntry("X Major", xMajor);
   cfg.writeEntry("Y Major", yMajor);
@@ -180,6 +198,19 @@ void KstSettings::save() {
   cfg.writeEntry("kst-plot-maintain-aspect-ratio", printing.maintainAspect);
   cfg.writeEntry("kst-plot-curve-width-adjust", printing.curveWidthAdjust);
   cfg.writeEntry("kst-plot-monochrome", printing.monochrome);
+  
+  cfg.writeEntry("kst-plot-monochromesettings-enhancereadability", 
+                 printing.monochromeSettings.enhanceReadability);
+  cfg.writeEntry("kst-plot-monochromesettings-pointstyleorder",
+                 printing.monochromeSettings.pointStyleOrder);
+  cfg.writeEntry("kst-plot-monochromesettings-linestyleorder",
+                 printing.monochromeSettings.lineStyleOrder);
+  cfg.writeEntry("kst-plot-monochromesettings-linewidthorder",
+                 printing.monochromeSettings.lineWidthOrder);
+  cfg.writeEntry("kst-plot-monochromesettings-maxlinewidth",
+                 printing.monochromeSettings.maxLineWidth);
+  cfg.writeEntry("kst-plot-monochromesettings-pointdensity",
+                 printing.monochromeSettings.pointDensity);
 
   cfg.sync();
 }
@@ -190,12 +221,16 @@ void KstSettings::reload() {
 
   cfg.setGroup("Kst");
   plotUpdateTimer = cfg.readNumEntry("Plot Update Timer", 200);
+  plotFontSize    = cfg.readNumEntry("Plot Font Size", 12);
   backgroundColor = cfg.readColorEntry("Background Color", &backgroundColor);
   foregroundColor = cfg.readColorEntry("Foreground Color", &foregroundColor);
   promptWindowClose = cfg.readBoolEntry("Prompt on Window Close", true);
   showQuickStart = cfg.readBoolEntry("Show QuickStart", true);
-  useUTC = cfg.readBoolEntry("Use UTC", true);
-
+  curveColorSequencePalette = cfg.readEntry("Curve Color Sequence", "Kst Colors");
+  
+  timezone = cfg.readEntry("Timezone", "UTC");
+  offsetSeconds = cfg.readNumEntry("OffsetSeconds", 0);
+  
   cfg.setGroup("Grid Lines");
   xMajor = cfg.readBoolEntry("X Major", false);
   yMajor = cfg.readBoolEntry("Y Major", false);
@@ -233,6 +268,18 @@ void KstSettings::reload() {
   printing.maintainAspect = cfg.readEntry("kst-plot-maintain-aspect-ratio", "0");
   printing.curveWidthAdjust = cfg.readEntry("kst-plot-curve-width-adjust", "0");
   printing.monochrome = cfg.readEntry("kst-plot-monochrome", "0");
+  printing.monochromeSettings.enhanceReadability = 
+      cfg.readEntry("kst-plot-monochromesettings-enhancereadability", "0");
+  printing.monochromeSettings.pointStyleOrder = 
+      cfg.readEntry("kst-plot-monochromesettings-pointstyleorder", "0");
+  printing.monochromeSettings.lineStyleOrder = 
+      cfg.readEntry("kst-plot-monochromesettings-linestyleorder", "1");
+  printing.monochromeSettings.lineWidthOrder = 
+      cfg.readEntry("kst-plot-monochromesettings-linewidthorder", "2");
+  printing.monochromeSettings.maxLineWidth = 
+      cfg.readEntry("kst-plot-monochromesettings-maxlinewidth", "3");
+  printing.monochromeSettings.pointDensity = 
+      cfg.readEntry("kst-plot-monochromesettings-pointdensity", "2");
 }
 
 
@@ -243,4 +290,25 @@ void KstSettings::checkUpdates() {
 }
 
 
+void KstSettings::setPrintingDefaults() {
+  printing.pageSize = QString::number((int)KPrinter::Letter);
+  printing.orientation = "Landscape";
+  printing.plotDateTimeFooter = "0";
+  printing.maintainAspect = "0";
+  printing.curveWidthAdjust = "0";
+  printing.monochrome = "0";
+  printing.monochromeSettings.enhanceReadability = "0";
+  printing.monochromeSettings.pointStyleOrder = "0";
+  printing.monochromeSettings.lineStyleOrder = "1";
+  printing.monochromeSettings.lineWidthOrder = "2";
+  printing.monochromeSettings.maxLineWidth = "3";
+  printing.monochromeSettings.pointDensity = "2";
+}
+
+
+int KstSettings::utcOffset() {
+  return offsetSeconds;
+}
+
+
 // vim: ts=2 sw=2 et
