@@ -63,7 +63,7 @@ KstVCurve::KstVCurve(const QString &in_tag, KstVectorPtr in_X, KstVectorPtr in_Y
   setHasPoints(false);
   setHasBars(false);
   setHasLines(true);
-  setLineWidth(0);
+  setLineWidth(1);
   setLineStyle(0);
   setBarStyle(0);
   setPointDensity(0);
@@ -107,7 +107,7 @@ KstVCurve::KstVCurve(QDomElement &e)
   setHasPoints(false);
   setHasLines(false);
   setHasBars(false);
-  setLineWidth(0);
+  setLineWidth(1);
   setLineStyle(0);
   setBarStyle(0);
   setPointDensity(0);
@@ -861,7 +861,7 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
   if (sampleCount() > 0) {
     Qt::PenStyle style = KstLineStyle[lineStyle()];
     int i0, iN;
-    int width = kMax(lineWidth(), penWidth);
+    int width = lineWidth() * penWidth; //kMax(lineWidth(), penWidth);
 
     if (xv->isRising()) {
       i0 = indexNearX(XMin, xv, NS);
@@ -1295,7 +1295,7 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
         QRegion rgn((int)Lx, (int)Ly, (int)w, (int)h);
         const int size = int(kMax(w, h)) / int(pow(3.0, KSTPOINTDENSITY_MAXTYPE - pointDensity()));
         QPoint pt;
-        const int lineWidth = this->lineWidth();
+        const int lineWidth = width; //this->lineWidth();
         for (i_pt = i0; i_pt <= iN; ++i_pt) {
           rX = xv->interpolate(i_pt, NS);
           rY = yv->interpolate(i_pt, NS);
@@ -1314,7 +1314,7 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
           }
         }
       } else {
-        const int lineWidth = this->lineWidth();
+        const int lineWidth = width; //this->lineWidth();
         for (i_pt = i0; i_pt <= iN; ++i_pt) {
           rX = xv->interpolate(i_pt, NS);
           rY = yv->interpolate(i_pt, NS);
