@@ -23,32 +23,25 @@
 #include <qdeepcopy.h>
 #include <qstylesheet.h>
 
-#include <kdebug.h>
+#include "ksdebug.h"
 #include <klocale.h>
 #include "kstdatacollection.h"
 #include "kstdefaultnames.h"
 #include "kstmath.h"
 #include "kstvector.h"
+#include "kstvcurve.h"
 
-static int anonymousVectorCounter = 0;
+static int anonymousVectorCounter = 1;
 
 // Use 1 for a simple for() loop
 #define ZERO_MEMORY 2
 
-#ifdef NAN
-double KST::NOPOINT = NAN;
-#else
-double KST::NOPOINT = 0.0/0.0; // NaN
-#endif
-
 #define INITSIZE 1
 
-// FIXME: optimize scalar access
-
 /** Create a vector */
 KstVector::KstVector(const QString& name, int size, bool isScalarList)
 : KstObject(), _nsum(0), _scalars(isScalarList ? 0 : 11) {
-  //kdDebug() << "+++ CREATING VECTOR: " << (void*) this << endl;
+  //kstdDebug() << "+++ CREATING VECTOR: " << (void*) this << endl;
   KstObject::setTagName(name);
   _editable = false;
   NumShifted = 0;
@@ -67,10 +60,10 @@ KstVector::KstVector(const QString& name, int size, bool isScalarList)
 
     do {
       KstObject::setTagName(nt.arg(anonymousVectorCounter++));
-    } while (KST::vectorTagNameNotUnique(tagName(), false));
+    } while (KstData::self()->vectorTagNameNotUnique(tagName(), false));
   } else {
-    while (KST::vectorTagNameNotUnique(tagName(), false)) {
-      KstObject::setTagName(tagName() + "'");
+    while (KstData::self()->vectorTagNameNotUnique(tagName(), false)) {
+      KstObject::setTagName(tagName() + '\'');
     }
   }
 
@@ -89,7 +82,7 @@ KstVector::KstVector(const QString& name, int size, bool isScalarList)
 
 
 KstVector::~KstVector() {
-  //kdDebug() << "+++ DELETING VECTOR: " << (void*) this << endl;
+  //kstdDebug() << "+++ DELETING VECTOR: " << (void*) this << endl;
   KST::scalarList.lock().writeLock();
   for (QDictIterator<KstScalar> it(_scalars); it.current(); ++it) {
     KST::scalarList.remove(it.current());
@@ -106,10 +99,6 @@ KstVector::~KstVector() {
 
 #define GENERATE_INTERPOLATION              \
   assert(_size > 0);                        \
-  if (_size == 0) {                         \
-      return KST::NOPOINT;                  \
-  }                                         \
-                                            \
   /** Limits checks - optional? **/         \
   if (in_i < 0 || _size == 1) {             \
     return _v[0];                           \
@@ -128,16 +117,8 @@ KstVector::~KstVector() {
                                             \
   int j = int(floor(fj)); /* index of sample one lower */ \
   assert(j+1 < _size && j >= 0);            \
-  /* This is optimized to avoid unnecessary isnan calls! */  \
-  if (_v[j + 1] != _v[j + 1]) {             \
-    if (KST_ISNAN(_v[j + 1])) {             \
-      return KST::NOPOINT;                  \
-    }                                       \
-  }                                         \
-  if (_v[j] != _v[j]) {                     \
-    if (KST_ISNAN(_v[j])) {                 \
-      return KST::NOPOINT;                  \
-    }                                       \
+  if (_v[j + 1] != _v[j + 1] || _v[j] != _v[j]) { \
+    return KST::NOPOINT;                    \
   }                                         \
                                             \
   double fdj = fj - float(j); /* fdj is fraction between _v[j] and _v[j+1] */ \
@@ -169,6 +150,7 @@ double KstVector::value(int i) {
 
 void KstVector::CreateScalars() {
   if (!_isScalarList) {
+    _min = _max = _mean = _minPos = 0.0;
     _scalars.insert("max", new KstScalar(tagName() + "-Max"));
     _scalars["max"]->_KShared_ref();
     _scalars.insert("min", new KstScalar(tagName() + "-Min"));
@@ -212,19 +194,25 @@ void KstVector::updateScalars() {
     _scalars["ns"]->setValue(_size);
 
     if (_nsum >= 2) {
-      _scalars["mean"]->setValue(_scalars["sum"]->value()/double(_nsum));
-      _scalars["sigma"]->setValue( sqrt(
-        (_scalars["sumsquared"]->value() - _scalars["sum"]->value()*_scalars["sum"]->value()/double(_nsum))/ double(_nsum-1) ) );
-      _scalars["rms"]->setValue(sqrt(_scalars["sumsquared"]->value()/double(_nsum)));
+      double sum = _scalars["sum"]->value();
+      double sumsq = _scalars["sumsquared"]->value();
+      _scalars["mean"]->setValue(_mean = sum/double(_nsum));
+      _scalars["sigma"]->setValue(sqrt((sumsq - sum * sum / double(_nsum)) / double(_nsum-1)));
+      _scalars["rms"]->setValue(sqrt(sumsq/double(_nsum)));
     } else {
-      _scalars["sigma"]->setValue(_scalars["max"]->value() - _scalars["min"]->value());
+      _scalars["sigma"]->setValue(_max - _min);
       _scalars["rms"]->setValue(sqrt(_scalars["sumsquared"]->value()));
-      _scalars["mean"]->setValue(0);
+      _scalars["mean"]->setValue(_mean = 0);
     }
   }
 }
 
 
+const QDict<KstScalar>& KstVector::scalars() const {  
+  return _scalars;
+}
+
+
 double* KstVector::realloced(double *memptr, int newSize) {
   double *old = _v;
   _v = memptr;
@@ -242,15 +230,13 @@ double* KstVector::realloced(double *memptr, int newSize) {
 void KstVector::zero() {
   setDirty();
   _ns_min = _ns_max = 0.0;
-  for (int i = 0; i < _size; i++) {
-    _v[i] = 0.0;
-  }
+  memset(_v, 0, sizeof(double)*_size);
   updateScalars();
 }
 
 
 bool KstVector::resize(int sz, bool reinit) {
-  //kdDebug() << "resizing to: " << sz << endl;
+  //kstdDebug() << "resizing to: " << sz << endl;
   if (sz > 0) {
     _v = static_cast<double*>(KST::realloc(_v, sz*sizeof(double)));
     if (!_v) {
@@ -291,7 +277,9 @@ KstObject::UpdateType KstVector::update(int update_counter) {
   if (update_counter > 0) {
     KstObjectPtr prov = KstObjectPtr(_provider);
     if (prov) {
+      prov->writeLock();
       providerRC = prov->update(update_counter);
+      prov->writeUnlock();
       if (!force && providerRC == KstObject::NO_CHANGE) {
         return setLastUpdateResult(providerRC);
       }
@@ -306,10 +294,10 @@ KstObject::UpdateType KstVector::update(int update_counter) {
 
 KstObject::UpdateType KstVector::internalUpdate(KstObject::UpdateType providerRC) {
   int i, i0;
-  double max, min, sum, sum2, minpos, last, v;
+  double sum, sum2, last, v;
   double last_v;
   double dv2 = 0.0, dv, no_spike_max_dv;
-  max = min = sum = sum2 = minpos = last = 0.0;
+  _max = _min = sum = sum2 = _minPos = last = 0.0;
   _nsum = 0;
   if (_size > 0) {
     _is_rising = true;
@@ -321,9 +309,9 @@ KstObject::UpdateType KstVector::internalUpdate(KstObject::UpdateType providerRC
       if (!_isScalarList) {
         _scalars["sum"]->setValue(sum);
         _scalars["sumsquared"]->setValue(sum2);
-        _scalars["max"]->setValue(max);
-        _scalars["min"]->setValue(min);
-        _scalars["minpos"]->setValue(minpos);
+        _scalars["max"]->setValue(_max);
+        _scalars["min"]->setValue(_min);
+        _scalars["minpos"]->setValue(_minPos);
         _scalars["last"]->setValue(last);
       }
       _ns_max = _ns_min = 0;
@@ -338,13 +326,13 @@ KstObject::UpdateType KstVector::internalUpdate(KstObject::UpdateType providerRC
       _is_rising = false;
     }
 
-    max = min = _v[i0];
+    _max = _min = _v[i0];
     sum = sum2 = 0.0;
 
     if (_v[i0] > 0) {
-      minpos = _v[i0];
+      _minPos = _v[i0];
     } else {
-      minpos = 1.0E300;
+      _minPos = 1.0E300;
     }
 
     last_v = _v[i0];
@@ -367,13 +355,13 @@ KstObject::UpdateType KstVector::internalUpdate(KstObject::UpdateType providerRC
         sum += v;
         sum2 += v*v;
 
-        if (v > max) {
-          max = v;
-        } else if (v < min) {
-          min = v;
+        if (v > _max) {
+          _max = v;
+        } else if (v < _min) {
+          _min = v;
         }
-        if (v < minpos && v > 0) {
-            minpos = v;
+        if (v < _minPos && v > 0) {
+            _minPos = v;
         }
       } else {
         _is_rising = false;
@@ -406,12 +394,14 @@ KstObject::UpdateType KstVector::internalUpdate(KstObject::UpdateType providerRC
       }
     }
 
-    if (!_isScalarList) {
+    if (_isScalarList) {
+      _max = _min = _minPos = 0.0;
+    } else {
       _scalars["sum"]->setValue(sum);
       _scalars["sumsquared"]->setValue(sum2);
-      _scalars["max"]->setValue(max);
-      _scalars["min"]->setValue(min);
-      _scalars["minpos"]->setValue(minpos);
+      _scalars["max"]->setValue(_max);
+      _scalars["min"]->setValue(_min);
+      _scalars["minpos"]->setValue(_minPos);
       _scalars["last"]->setValue(last);
     }
 
@@ -458,62 +448,11 @@ double *const KstVector::value() const {
 }
 
 
-double KstVector::min() const {
-  if (!_isScalarList) {
-    return _scalars["min"]->value();
-  } else {
-    return 0.0;
-  }
-}
-
-
-double KstVector::max() const {
-  if (!_isScalarList) {
-    return _scalars["max"]->value();
-  } else {
-    return 0.0;
-  }
-}
-
-
-double KstVector::mean() const {
-  if (!_isScalarList) {
-    return _scalars["mean"]->value();
-  } else {
-    return 0.0;
-  }
-}
-
-
-double KstVector::minPos() const {
-  if (!_isScalarList) {
-    return _scalars["minpos"]->value();
-  } else {
-    return 0.0;
-  }
-}
-
-
-int KstVector::numNew() const {
-  return NumNew;
-}
-
-
-int KstVector::numShift() const {
-  return NumShifted;
-}
-
-
 void KstVector::newSync() {
   NumNew = NumShifted = 0;
 }
 
 
-int KstVector::length() const {
-  return _size;
-}
-
-
 KstVectorPtr KstVector::generateVector(double x0, double x1, int n, const QString &tag) {
   if (n < 2) {
     n = 2;
@@ -575,6 +514,35 @@ bool KstVector::deleteDependents() {
 }
 
 
+bool KstVector::duplicateDependents(KstDataObjectDataObjectMap& duplicatedMap, 
+                                    QMap<KstVectorPtr, KstVectorPtr> &duplicatedVectors) {
+
+  // work with a copy of the data object list
+  KST::dataObjectList.lock().readLock();
+  KstDataObjectList dol = QDeepCopy<KstDataObjectList>(KST::dataObjectList);
+  KST::dataObjectList.lock().readUnlock();
+  
+  for (KstDataObjectList::Iterator i = dol.begin(); i != dol.end(); ++i) {
+    if ((*i)->uses(this)) {
+      if (duplicatedMap.contains(*i)) {
+        (duplicatedMap[*i])->replaceDependency(this, duplicatedVectors[this]);  
+      } else {
+        KstDataObjectPtr newObject = (*i)->makeDuplicate(duplicatedMap);
+        newObject->replaceDependency(this, duplicatedVectors[this]);
+        if (newObject) {
+          KST::dataObjectList.lock().writeLock();
+          KST::dataObjectList.append(newObject.data());
+          KST::dataObjectList.lock().writeUnlock();
+          (*i)->duplicateDependents(duplicatedMap);
+        }
+      }
+    }
+  }
+
+  return true;
+}
+
+
 void KstVector::setLabel(const QString& label_in) {
   _label = label_in;
 }
