@@ -340,17 +340,17 @@ void KstViewLabel::paintSelf(KstPainter& p, const QRegion& bounds) {
   p.save();
   if (p.type() == KstPainter::P_PRINT || p.type() == KstPainter::P_EXPORT) {
     if (_autoResize) {
-      adjustSizeForText(p.window());
+      adjustSizeForText(_parent->geometry());
     } else {
       computeTextSize(_parsed);
     }
     KstBorderedViewObject::paintSelf(p, bounds);
-    const QRect geom(contentsRect());
+    const QRect geom(contentsRectForDevice(p));
     p.setViewport(geom);
     p.setWindow(0, 0, geom.width(), geom.height());
 
     if (!_transparent) {
-      p.fillRect(p.window(), backgroundColor());
+      p.fillRect(0, 0, geom.width(), geom.height(), backgroundColor());
     }
 
     drawToPainter(_parsed, p);
@@ -386,7 +386,7 @@ QRegion KstViewLabel::clipRegion() {
     _myClipMask = QRegion(bm);
     _myClipMask.translate(cr.topLeft().x(), cr.topLeft().y());
 
-    QBitmap bm1(_geom.bottomRight().x(), _geom.bottomRight().y(), true);
+    QBitmap bm1(_geom.bottomRight().x() + 1, _geom.bottomRight().y() + 1, true);
     if (!bm1.isNull()) {
       KstPainter p;
       p.setMakingMask(true);
@@ -584,11 +584,7 @@ bool KstViewLabel::fillConfigWidget(QWidget *w, bool isNew) const {
     }
 
   } else { 
-    // replace \n & \t with tabs and newlines for the text edit box
-    QString tmpstr = text();
-    tmpstr.replace(QString("\\n"), "\n");
-    tmpstr.replace(QString("\\t"), "\t");
-    widget->_text->setText(tmpstr);
+    widget->_text->setText(text());
 
     widget->_precision->setValue(int(dataPrecision()));
     widget->_rotation->setValue(double(rotation()));
@@ -616,10 +612,7 @@ bool KstViewLabel::readConfigWidget(QWidget *w) {
     return false;
   }
 
-  // Replace tabs and newlines in text edit box with \n and \t 
   _txt = widget->_text->text();
-  _txt.replace(QString("\n"), "\\n");
-  _txt.replace(QString("\t"), "\\t");
 
   setDataPrecision(widget->_precision->value());
   setRotation(widget->_rotation->value());
