@@ -15,19 +15,12 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <qlabel.h>
 #include <qlayout.h>
 #include <qpushbutton.h>
-#include <qstring.h>
-#include <qtable.h>
-#include <qwidget.h>
 
-#include <kdebug.h>
 #include <klocale.h>
 
 #include "kstdatacollection.h"
-#include "kstrvector.h"
-#include "kstscalartable.h"
 #include "kstviewscalarsdialog_i.h"
 
 KstViewScalarsDialogI::KstViewScalarsDialogI(QWidget* parent,
@@ -44,7 +37,6 @@ KstViewScalarsDialogI::KstViewScalarsDialogI(QWidget* parent,
   QBoxLayout *box = dynamic_cast<QBoxLayout*>(layout());
   if (box) {
     box->insertWidget(0, tableScalars);
-
     if (tableScalars->numCols() != 2) {
       for (; 0 < tableScalars->numCols(); ) {
         tableScalars->removeColumn(0);
@@ -55,45 +47,47 @@ KstViewScalarsDialogI::KstViewScalarsDialogI(QWidget* parent,
     tableScalars->setReadOnly(true);
     languageChange();
   }
-  
+
   connect(Cancel, SIGNAL(clicked()), this, SLOT(close()));
 }
 
+
 KstViewScalarsDialogI::~KstViewScalarsDialogI() {
 }
 
+
 void KstViewScalarsDialogI::updateViewScalarsDialog() {
   KST::scalarList.lock().readLock();
   int needed = KST::scalarList.count();
   KST::scalarList.lock().readUnlock();
-    
+
   tableScalars->setNumRows(needed);
   QRect rect = tableScalars->horizontalHeader()->rect();
-  tableScalars->setColumnWidth( 0, rect.width()/2 );
-  tableScalars->setColumnWidth( 1, rect.width()/2 );
+  tableScalars->setColumnWidth(0, rect.width()/2);
+  tableScalars->setColumnWidth(1, rect.width()/2);
 }
 
+
 void KstViewScalarsDialogI::showViewScalarsDialog() {
   updateViewScalarsDialog();
   updateDefaults(0);
-
   show();
   raise();
 }
 
+
 /*
  *  Sets the strings of the subwidgets using the current
  *  language.
  */
-void KstViewScalarsDialogI::languageChange()
-{
+void KstViewScalarsDialogI::languageChange() {
   setCaption(i18n("View Scalar Values"));
   tableScalars->horizontalHeader()->setLabel(0, i18n("Scalar"));
   tableScalars->horizontalHeader()->setLabel(1, i18n("Value"));
-
   KstViewScalarsDialog::languageChange();      
 }
 
+
 void KstViewScalarsDialogI::updateDefaults(int index) {
   Q_UNUSED(index)
 }
