@@ -19,7 +19,6 @@
 #include <qpushbutton.h>
 #include <qtable.h>
 
-#include <kdebug.h>
 #include <klocale.h>
 
 #include "kstviewvectorsdialog_i.h"
@@ -30,7 +29,6 @@ KstViewVectorsDialogI::KstViewVectorsDialogI(QWidget* parent,
                                              bool modal,
                                              WFlags fl)
 : KstViewVectorsDialog(parent, name, modal, fl) {
-  
   tableVectors = new KstVectorTable(this, "tableVectors");
   tableVectors->setNumRows(0);
   tableVectors->setNumCols(1);
@@ -42,38 +40,42 @@ KstViewVectorsDialogI::KstViewVectorsDialogI(QWidget* parent,
   connect(Cancel, SIGNAL(clicked()), this, SLOT(close()));
   connect(vectorSelector, SIGNAL(selectionChanged(const QString&)), this, SLOT( vectorChanged(const QString&)));
   connect(vectorSelector, SIGNAL(newVectorCreated(const QString&)), this, SLOT(vectorChanged(const QString&)));
-  
+
   if (tableVectors->numCols() != 1) {  
     for (; 0 < tableVectors->numCols(); ) {
       tableVectors->removeColumn(0);
     }
     tableVectors->insertColumns(0, 1);
   }
-  
+
   tableVectors->setReadOnly(true);
   languageChange();
 }
 
+
 KstViewVectorsDialogI::~KstViewVectorsDialogI() {
 }
 
+
 void KstViewVectorsDialogI::updateViewVectorsDialog() {
   vectorSelector->update();
-  
   QString vector = vectorSelector->selectedVector();
   tableVectors->setVector(vector);
   updateViewVectorsDialog(vector);
 }
 
+
 void KstViewVectorsDialogI::updateViewVectorsDialog(const QString& vectorName) {
   int needed = 0;
+  KST::vectorList.lock().readLock();
   KstVectorPtr vector = *KST::vectorList.findTag(vectorName);
+  KST::vectorList.lock().readUnlock();
   if (vector) {
     vector->readLock();
     needed = vector->length();
     vector->readUnlock();
   }
-  
+
   if (needed != tableVectors->numRows()) {
     tableVectors->setNumRows(needed);
   }
@@ -81,32 +83,33 @@ void KstViewVectorsDialogI::updateViewVectorsDialog(const QString& vectorName) {
   tableVectors->setColumnWidth(0, rect.width());
 }
 
+
 void KstViewVectorsDialogI::showViewVectorsDialog() {
   updateViewVectorsDialog();
   updateDefaults(0);
-  
   show();
   raise();
 }
 
+
 void KstViewVectorsDialogI::vectorChanged(const QString& vector) {
   updateViewVectorsDialog(vector);
   tableVectors->setVector(vector);
   tableVectors->update();
 }
 
+
 /*
  *  Sets the strings of the subwidgets using the current
  *  language.
  */
-void KstViewVectorsDialogI::languageChange()
-{
+void KstViewVectorsDialogI::languageChange() {
   setCaption(i18n("View Vector Values"));
   tableVectors->horizontalHeader()->setLabel(0, i18n("Values"));
-
   KstViewVectorsDialog::languageChange();
 }
 
+
 void KstViewVectorsDialogI::updateDefaults(int index) {
   Q_UNUSED(index)
 }
