@@ -19,40 +19,40 @@
 #include <stdio.h>
 
 #include <qstringlist.h>
+#include <qfileinfo.h>
 
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
 #include "ksdebug.h"
 #include <kimageio.h>
 
+#include "dialoglauncher-gui.h"
 #include "kst.h"
 #include "kstcolorsequence.h"
-#include "kstdatacollection.h"
+#include "kstdatacollection-gui.h"
 #include "kstdefaultnames.h"
 #include "kstdoc.h"
 #include "kstequation.h"
 #include "ksthistogram.h"
-#include "kstlegend.h"
+#include "kst2dplot.h"
+#include "kstviewlegend.h"
 #include "kstpsd.h"
 #include "kstrvector.h"
 #include "kstsvector.h"
 #include "kstavector.h"
 #include "kstvcurve.h"
-#include "kstversion.h"
-#include "plugincollection.h"
+#include "kstrmatrix.h"
+#include "kstimage.h"
 
 
-// George is going to freak out if main() gets more complicated. :-)
-// Let's try to come up with a KstCommandLineProcessor class that can
-// properly and cleanly deal with all of this.
-
 static const char description[] = I18N_NOOP("Kst: a data viewing program.");
-static QStringList strErrors;
+static QStringList startupErrors;
 
 static KCmdLineOptions options[] = {
-  {"F <dataFile>", I18N_NOOP("Specify data file: used to override a kst file default"), "|"},
   { "y <Y>",  I18N_NOOP("Field for Y axis (multiple allowed)"), 0 },
+  { "z <Z>",  I18N_NOOP("Field for a Z image (multiple allowed)"), 0 },
   { "ye <equation>",  I18N_NOOP("Equation for Y axis (multiple allowed)"), 0 },
+  { "E <text>",  I18N_NOOP("Pass argument to extension.  text is of format extensionname:argumentlist"), 0 },
   { "e <E>",  I18N_NOOP("Field for Y errors (multiple allowed)"), 0 },
   { "x <X>",  I18N_NOOP("Field or range for X axis"),        "INDEX"},
   { "xe <X>", I18N_NOOP("X vector for equations x0:x1:n"),   "INDEX"},
@@ -69,9 +69,11 @@ static KCmdLineOptions options[] = {
   { "m <NC>", I18N_NOOP("Separate plots arranged in <NC> columns"),0},
   { "d",      I18N_NOOP("Display as points rather than curves"),0},
   { "g",      I18N_NOOP("Provide a legend box"),0},
+  { "w <file>",      I18N_NOOP("Display the data wizard"),"<none>"},
   { "print <file>",  I18N_NOOP("Print to file and exit"),"<none>"},
   { "png <file>",  I18N_NOOP("Save as a png file and exit"),"<none>"},
   { "nq",     I18N_NOOP("Bypass the quickstart dialog"), 0},
+  {"F <dataFile>", I18N_NOOP("Override a *.kst file's data file with <datafile>"), "|"},
   { "+[Files]", I18N_NOOP("Data files (if -y given) or *.kst file"), 0},
   KCmdLineLastOption
 };
@@ -189,28 +191,20 @@ static void SetCMDOptions(KCmdLineArgs *args, InType &in, int n_y) {
 static void CreatePlots(InType &in, KstTopLevelViewPtr tlv) {
   KstApp *kst = KstApp::inst();
   QString creatingPlots = i18n("Creating plots");
-  Kst2DPlotPtr plot;
-  int i_plot;
-  int size_boost;
-  int count;
-  int handled;
 
   kst->slotUpdateProgress( 0, 0, creatingPlots );
-  count = in.n_plots;
-  handled = 0;
+  int count = in.n_plots;
+  int handled = 0;
 
-  for (i_plot=0; i_plot < in.n_plots; i_plot++) {
-    plot = new Kst2DPlot(KST::suggestPlotName());
-    size_boost = (in.n_rows + in.n_cols)/2-1;
-    size_boost = size_boost*12/2;
-    plot->initFonts(QFont::QFont(), size_boost);
+  for (int i_plot = 0; i_plot < in.n_plots; ++i_plot) {
+    Kst2DPlotPtr plot = new Kst2DPlot(KST::suggestPlotName());
     tlv->appendChild(plot.data());
 
     plot->resizeFromAspect(double(i_plot%in.n_cols)/double(in.n_cols),
                             double(i_plot/in.n_cols)/double(in.n_rows),
                             1.0/double(in.n_cols), 1.0/double(in.n_rows));
 
-    handled++;
+    ++handled;
     kst->slotUpdateProgress( count, handled, creatingPlots );
   }
 
@@ -277,7 +271,7 @@ static KstRVector *GetOrCreateVector(const QString& field, KstDataSourcePtr file
   if (V->isValid()) {
     KST::addVectorToList(V);
   } else {
-    strErrors.append(i18n("Failed to create vector '%1' from file '%2'.").arg(field).arg(file->fileName()));
+    startupErrors.append(i18n("Failed to create vector '%1' from file '%2'.").arg(field).arg(file->fileName()));
 
     delete V;
     V = 0L;
@@ -328,12 +322,13 @@ static void exitHelper(void) {
 int main(int argc, char *argv[]) {
   int i_file, i_v, i_curve;
   int i_plot;
+  QString fullPath;
 
   KAboutData aboutData("kst", I18N_NOOP("Kst"),
                        KSTVERSION, description, KAboutData::License_GPL,
-                       I18N_NOOP("(c) 2000-2005 Barth Netterfield"),
+                       I18N_NOOP("(c) 2000-2006 Barth Netterfield"),
                        0,
-                       "http://extragear.kde.org/apps/kst/");
+                       "http://kst.kde.org/");
   aboutData.addAuthor("Barth Netterfield",
                       I18N_NOOP("Original author and maintainer."),
                       "netterfield@astro.utoronto.ca",
@@ -354,6 +349,14 @@ int main(int argc, char *argv[]) {
                       "",
                       "",
                       "");
+  aboutData.addAuthor("Matthew Truch",
+                      "",
+                      "http://matt.truch.net/",
+                      "matt@truch.net");
+  aboutData.addAuthor("Theodore Kisner",
+                      "",
+                      "tskisner.public@gmail.com",
+                      "");
 
   KCmdLineArgs::init( argc, argv, &aboutData );
   KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
@@ -361,6 +364,8 @@ int main(int argc, char *argv[]) {
   KApplication app;
   KImageIO::registerFormats();
 
+  KstDialogs::replaceSelf(new KstGuiDialogs);
+  KstData::replaceSelf(new KstGuiData);
   KstApp::initialize();
 
   atexit(exitHelper);
@@ -373,6 +378,7 @@ int main(int argc, char *argv[]) {
     QColor color;
     KstDataSourcePtr file;
     QCStringList ycolList;
+    QCStringList matrixList;
     QCStringList yEqList;
     QCStringList psdList;
     QCStringList hsList;
@@ -380,33 +386,20 @@ int main(int argc, char *argv[]) {
     unsigned int i_ycol;
     QCStringList::Iterator hs_string;
     QCStringList::Iterator eq_i;
+    QCStringList::Iterator mat_i;
     bool showQuickStart = false;
+    bool showDataWizard = false;
     bool nOK;
     int n_y = 0;
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
     CheckForCMDErrors(args);
 
+    QString wizardfile = args->getOption("w");
     QString printfile = args->getOption("print");
     QString pngfile = args->getOption("png");
     bool print_and_exit = false;
 
-
-#if 0
-    // test code
-    KstAVectorPtr tmpav = new KstAVector(3, "tmpV" );
-    tmpav->value()[0] = 0;
-    tmpav->value()[1] = 10;
-    tmpav->value()[2] = 4;
-
-    KST::addVectorToList(KstVectorPtr(tmpav));
-
-    KstVectorPtr tmpv;
-    tmpv = new KstSVector(-5,5,100,"tmpV");
-    KST::addVectorToList( tmpv );
-#endif
-    // end test code...
-
     if (printfile != "<none>") {
       print_and_exit = true;
     }
@@ -414,9 +407,6 @@ int main(int argc, char *argv[]) {
       print_and_exit = true;
     }
 
-    // Initialise the plugin loader and collection.
-    PluginCollection::self();
-
     if (!print_and_exit) {
       app.setMainWidget(kst);
       kst->show();
@@ -424,13 +414,14 @@ int main(int argc, char *argv[]) {
 
     // get Y axis columns
     ycolList = args->getOptionList("y");
+    matrixList = args->getOptionList("z");
     yEqList = args->getOptionList("ye");
     psdList = args->getOptionList("p");
     hsList = args->getOptionList("h");
     errorList = args->getOptionList("e");
 
     // y axis or PSD specified, so the files are data files, not kst files.
-    n_y = ycolList.count() + psdList.count() + hsList.count() + yEqList.count();
+    n_y = ycolList.count() + psdList.count() + hsList.count() + yEqList.count() + matrixList.count();
     if (n_y > 0) {
       QString creatingEquations = i18n("Creating equations");
       QString creatingCurves = i18n("Creating curves");
@@ -461,6 +452,8 @@ int main(int argc, char *argv[]) {
       i_plot = 0;
       Kst2DPlotPtr plot = *plist.at(i_plot);
 
+      KstVCurveList vcurves = kstObjectSubList<KstBaseCurve,KstVCurve>(plot->Curves);
+
       // make stand alone equations if there are no files
       if (args->count() < 1) {
         if (!yEqList.isEmpty()) {
@@ -481,7 +474,7 @@ int main(int argc, char *argv[]) {
                 KstEquationPtr eq = new KstEquation(KST::suggestEQName(eqS), eqS, min, max, n);
                 KstVCurvePtr vc = new KstVCurve(KST::suggestCurveName(eq->tagName(), true),
                                         eq->vX(), eq->vY(), 0L, 0L, 0L, 0L,
-                                        KstColorSequence::next(plot->Curves,plot->backgroundColor()));
+                                        KstColorSequence::next(vcurves,plot->backgroundColor()));
                 KST::dataObjectList.lock().writeLock();
                 KST::dataObjectList.append(eq.data());
                 KST::dataObjectList.append(vc.data());
@@ -490,7 +483,9 @@ int main(int argc, char *argv[]) {
 
                 if (in.sep_plots) {
                   i_plot++;
-                  if (i_plot <in.n_plots) plot = *plist.at(i_plot);
+                  if (i_plot < in.n_plots) {
+                    plot = *plist.at(i_plot);
+                  }
                 }
               }
 
@@ -508,7 +503,12 @@ int main(int argc, char *argv[]) {
 
       for (i_curve = i_v = 0, i_file = 0; i_file < args->count(); i_file++) {
         // make the file
-        file = KstDataSource::loadSource(args->arg(i_file));
+        if (QFile::exists(args->arg(i_file))) {
+          fullPath = QFileInfo(args->arg(i_file)).absFilePath();
+        } else {
+          fullPath = args->arg(i_file);
+        }
+        file = KstDataSource::loadSource(fullPath);
         if (file) {
           if (!file->isValid() || file->isEmpty()) {
             kstdError() << i18n("No data in file %1.  Trying to continue...").arg(args->arg(i_file)) << endl;
@@ -535,7 +535,7 @@ int main(int argc, char *argv[]) {
                 yvector = GetOrCreateVector(*(ycolList.at(i_ycol)), file, in);
                 if (yvector) {
                   // make the curves
-                  color = KstColorSequence::next(plot->Curves,plot->backgroundColor());
+                  color = KstColorSequence::next(vcurves,plot->backgroundColor());
                   curve = new KstVCurve(KST::suggestCurveName(yvector->field(), false),
                                       KstVectorPtr(xvector), KstVectorPtr(yvector),
                                       0L, 0L, 0L, 0L, color);
@@ -548,7 +548,7 @@ int main(int argc, char *argv[]) {
                     evector = GetOrCreateVector(*(errorList.at(i_ycol)), file, in);
                     if (evector) {
                       curve->setYError(KstVectorPtr(evector));
-                      curve->setYMinusError(KstVectorPtr(evector)); 
+                      curve->setYMinusError(KstVectorPtr(evector));
                     }
                   }
 
@@ -596,7 +596,7 @@ int main(int argc, char *argv[]) {
               if (eq) {
                 KstVCurvePtr vc = new KstVCurve(KST::suggestCurveName(eq->tagName(), true),
                                       eq->vX(), eq->vY(), 0L, 0L, 0L, 0L,
-                                      KstColorSequence::next(plot->Curves,plot->backgroundColor()));
+                                      KstColorSequence::next(vcurves,plot->backgroundColor()));
                 KST::dataObjectList.lock().writeLock();
                 KST::dataObjectList.append(eq.data());
                 KST::dataObjectList.append(vc.data());
@@ -620,11 +620,11 @@ int main(int argc, char *argv[]) {
 
               yvector = GetOrCreateVector(*it, file, in);
               if (yvector) {
-                color = KstColorSequence::next(plot->Curves,plot->backgroundColor());
+                color = KstColorSequence::next(vcurves,plot->backgroundColor());
 
                 psd = new KstPSD( KST::suggestPSDName(yvector->field()),
                     KstVectorPtr(yvector), in.rate, true, in.len,
-                    true, true, in.VUnits, in.RUnits);
+                    true, true, in.VUnits, in.RUnits, 0);
                 KstVCurvePtr vc = new KstVCurve(KST::suggestCurveName(psd->tagName(), true),
                     psd->vX(), psd->vY(),
                     0L, 0L, 0L, 0L, color);
@@ -657,7 +657,7 @@ int main(int argc, char *argv[]) {
             for (hs_string = hsList.begin(); hs_string != hsList.end(); ++hs_string) {
               yvector = GetOrCreateVector(*hs_string, file, in);
               if (yvector) {
-                color = KstColorSequence::next(plot->Curves,plot->backgroundColor());
+                color = KstColorSequence::next(vcurves,plot->backgroundColor());
 
                 KstHistogram::AutoBin(KstVectorPtr(yvector), &N, &max, &min);
 
@@ -688,8 +688,49 @@ int main(int argc, char *argv[]) {
               }
             } // next histogram
           } // end (if there are some histograms)
+
+          if (matrixList.count() > 0) { // if there are some matrixes
+            for (mat_i = matrixList.begin(); mat_i != matrixList.end(); ++mat_i) {
+              QString tag_name = KST::suggestMatrixName(*mat_i);
+              if (!file->isValidMatrix(*mat_i)) {
+                startupErrors.append(i18n("Failed to create matrix '%1' from file '%2'.").arg(*mat_i).arg(file->fileName()));
+              }
+              KstRMatrixPtr matrix = new KstRMatrix(file, *mat_i, tag_name, 
+                  0,0,-1,-1,false,false,0);
+                  // xStart, yStart, xNumSteps, yNumSteps, 
+                  //doAve, doSkip, skip);
+              KST::addMatrixToList(KstMatrixPtr(matrix));
+              
+              // Time to create the image from the matrix
+              tag_name = KST::suggestImageName(matrix->tagName());
+              QStringList palList = KPalette::getPaletteList();
+              QString pal;
+              if (palList.contains("IDL 13 RAINBOW")) {
+                pal = QString("IDL 13 RAINBOW");
+              } else {
+                pal = QString(*palList.at(0));
+              }
+              
+              KPalette* newPal = new KPalette(pal);
+              KstImagePtr image = new KstImage(tag_name, KstMatrixPtr(matrix), 0.0, 1.0,
+                                   true, newPal);
+              plot->addCurve(KstBaseCurvePtr(image));
+              KST::dataObjectList.lock().writeLock();
+              KST::dataObjectList.append(image.data());
+              KST::dataObjectList.lock().writeUnlock();
+              image = 0L; // drop the reference
+              
+              if (in.sep_plots) {
+                plot->setTagName(matrix->tagName());
+                i_plot++;
+                if (i_plot < in.n_plots) {
+                  plot = *plist.at(i_plot);
+                }
+              }
+            }
+          }
         } else {
-          strErrors.append(i18n("Failed to load file '%1'.").arg(args->arg(i_file)));
+          startupErrors.append(i18n("Failed to load file '%1'.").arg(args->arg(i_file)));
         }
         handled++;
         kst->slotUpdateProgress( count, handled, creatingCurves );
@@ -700,10 +741,19 @@ int main(int argc, char *argv[]) {
       kst->slotUpdateProgress( count, handled, creatingPlots );
       for (i_plot = 0; i_plot < in.n_plots; i_plot++) {
         plot = *plist.at(i_plot);
-        plot->GenerateDefaultLabels();
+        plot->generateDefaultLabels();
+      
+        // if we have only images in a plot then set the scale mode to AUTO (instead of AUTOBORDER)
+        KstImageList images = kstObjectSubList<KstBaseCurve,KstImage>(plot->Curves);
+        if (images.count() == plot->Curves.count()) {
+          plot->setXScaleMode(AUTO);
+          plot->setYScaleMode(AUTO);
+        }
+    
         if (plot->Curves.count() > 3 || in.dolegend) {
-          plot->Legend->setShow(true);
-          plot->Legend->setFront(true);
+          KstViewLegendPtr vl = plot->getOrCreateLegend();
+          vl->resizeFromAspect(0.1, 0.1, 0.2, 0.1);
+          vl->setBorderWidth(2);
         }
         handled++;
         kst->slotUpdateProgress( count, handled, creatingPlots );
@@ -727,6 +777,10 @@ int main(int argc, char *argv[]) {
     if (args->isSet("nq")) {
       showQuickStart = false;
     }
+    if (args->isSet("w")) {
+      showDataWizard = true;
+      showQuickStart = false;
+    }
 
     if (printfile != "<none>") {
       kst->forceUpdate();
@@ -739,20 +793,21 @@ int main(int argc, char *argv[]) {
     }
 
     if (print_and_exit) {
-      args->clear();
       delete kst;
       return 0;
     } else {
-      args->clear();
       kst->updateDialogs();
-      kst->document()->setModified(false);
+      
       if (showQuickStart) {
         kst->showQuickStartDialog();
       }
-      for (size_t i=0; i<strErrors.size(); i++) {
-        KstDebug::self()->log(strErrors[i], KstDebug::Warning);
+      if (showDataWizard) {
+        kst->showDataWizardWithFile(wizardfile);
       }
-      strErrors.clear();
+      for (size_t i = 0; i < startupErrors.size(); ++i) {
+        KstDebug::self()->log(startupErrors[i], KstDebug::Error);
+      }
+      startupErrors.clear();
     }
 
     // LEAVE THIS HERE - causes crashes otherwise!
