@@ -20,12 +20,13 @@
 
 
 #include "plugin.h"
+#include "kst_export.h"
 
 #include <kstaticdeleter.h>
 
 class PluginXMLParser;
 
-class PluginCollection : public QObject {
+class KST_EXPORT PluginCollection : public QObject {
   Q_OBJECT
   friend class KStaticDeleter<PluginCollection>;
   public:
