@@ -19,11 +19,16 @@
 
 #include "ksdebug.h"
 
-
 #define MAXREADERS 30
 
 //#define LOCKTRACE
 
+#ifdef LOCKTRACE
+#include <stdio.h>
+#include <qthread.h>
+#endif
+
+
 KstRWLock::KstRWLock()
 : _sem(MAXREADERS), _writeLock(true), _writeRecursion(0) {
 }
