@@ -20,9 +20,11 @@
 
 #include <qmutex.h>
 #include <qthread.h>
+#include <qvaluelist.h>
 
 #include "kstwaitcondition.h"
 
+class KstBaseCurve;
 class KstDoc;
 
 class UpdateThread : public QThread {
@@ -31,6 +33,7 @@ class UpdateThread : public QThread {
     virtual ~UpdateThread();
 
     void setPaused(bool paused);
+    bool paused() const;
     void setFinished(bool finished);
     void setUpdateTime(int updateTime);
     void forceUpdate();
@@ -42,12 +45,13 @@ class UpdateThread : public QThread {
 
   private:
     bool _paused, _done;
+    bool _force;
     KstWaitCondition _waitCondition;
-    QMutex _statusMutex;
+    mutable QMutex _statusMutex;
     KstDoc *_doc;
     int _updateCounter;
     int _updateTime;
-    bool _force;
+    QValueList<KstBaseCurve*> _updatedCurves; // HACK: temporary use in update reworking
 };
 
 
