@@ -8,6 +8,14 @@
 *****************************************************************************/
 
 
+void VectorSelector::init()
+{
+    _provideNoneVector = false;
+    update();
+    connect(_vector, SIGNAL(activated(const QString&)), this, SIGNAL(selectionChanged(const QString&))); // annoying that signal->signal doesn't seem to work in .ui files
+}
+
+
 void VectorSelector::allowNewVectors( bool allowed )
 {
     _newVector->setEnabled(allowed);
@@ -35,47 +43,42 @@ void VectorSelector::update()
     bool found = false;
     _vector->clear();
     if (_provideNoneVector) {
-      _vector->insertItem(tr("<None>"));
+	_vector->insertItem(tr("<None>"));
     }
-    for (KstVectorList::Iterator i = KST::vectorList.begin(); i != KST::vectorList.end(); ++i) {
-      if (!(*i)->isScalarList()){
-        _vector->insertItem((*i)->tagName());
-        if (!found && (*i)->tagName() == prev) {
-          found = true;
-        }
-      }
+    QStringList vectors;
+    KST::vectorList.lock().readLock();
+    for (KstVectorList::ConstIterator i = KST::vectorList.begin(); i != KST::vectorList.end(); ++i) {
+	(*i)->readLock();
+	if (!(*i)->isScalarList()){
+	    vectors << (*i)->tagName();
+	    if (!found && (*i)->tagName() == prev) {
+		found = true;
+	    }
+	}
+	(*i)->readUnlock();
     }
+    KST::vectorList.lock().readUnlock();
+    qHeapSort(vectors);
+    _vector->insertStringList(vectors);
     if (found) {
-      _vector->setCurrentText(prev);
+	_vector->setCurrentText(prev);
     }
     blockSignals(false);
-}
-
-
-void VectorSelector::init()
-{
-    _provideNoneVector = false;
-    update();
-    connect(_vector, SIGNAL(activated(const QString&)), this, SIGNAL(selectionChanged(const QString&)));
+    setEdit(_vector->currentText());
 }
 
 
 void VectorSelector::createNewVector()
 {
-    KstVectorDialogI *vd = new KstVectorDialogI(this, "vector dialog");
-    connect(vd, SIGNAL(vectorCreated(KstVectorPtr)), this, SLOT(newVectorCreated(KstVectorPtr)));
-    connect(vd, SIGNAL(vectorCreated(KstVectorPtr)), this, SLOT(setSelection(KstVectorPtr)));
-    connect(vd, SIGNAL(modified()), this, SLOT(update()));
-    vd->show_New();
-    vd->exec();
-    delete vd;
+    KstDialogs::self()->newVectorDialog(this, SLOT(newVectorCreated(KstVectorPtr)), SLOT(setSelection(KstVectorPtr)), SLOT(update()));
 }
 
 
 void VectorSelector::selectionWatcher( const QString & tag )
 {
-    QString label = "["+tag+"]";
+    QString label = "[" + tag + "]";
     emit selectionChangedLabel(label);
+    setEdit(tag);
 }
 
 
@@ -86,18 +89,24 @@ void VectorSelector::setSelection( const QString & tag )
 	    blockSignals(true);
 	    _vector->setCurrentItem(0);
 	    blockSignals(false);
+
+	    _editVector->setEnabled(false);
 	}
 	return;
     }
     blockSignals(true);
     _vector->setCurrentText(tag);  // What if it isn't in the combo?
     blockSignals(false);
+
+    setEdit(tag);
 }
 
 
 void VectorSelector::newVectorCreated( KstVectorPtr v )
 {
+    v->readLock();
     QString name = v->tagName();
+    v->readUnlock();
     v = 0L; // deref
     emit newVectorCreated(name);
 }
@@ -105,7 +114,9 @@ void VectorSelector::newVectorCreated( KstVectorPtr v )
 
 void VectorSelector::setSelection( KstVectorPtr v )
 {
+    v->readLock();
     setSelection(v->tagName());
+    v->readUnlock();
 }
 
 
@@ -116,3 +127,21 @@ void VectorSelector::provideNoneVector( bool provide )
 	update();
     }
 }
+
+
+void VectorSelector::editVector()
+{
+    KstDialogs::self()->showVectorDialog(_vector->currentText());
+}
+
+
+void VectorSelector::setEdit( const QString& tag )
+{
+    KST::vectorList.lock().readLock();
+    KstRVectorPtr rvp = kst_cast<KstRVector>(*KST::vectorList.findTag(tag));
+    KstSVectorPtr svp = kst_cast<KstSVector>(*KST::vectorList.findTag(tag));
+    KST::vectorList.lock().readUnlock();
+    _editVector->setEnabled(rvp||svp);
+}
+
+// vim: ts=8 sw=4 noet
