@@ -332,6 +332,8 @@ int main(int argc, char **argv) {
   test("[test4]*[test5]", 0.0, NOPOINT);
   test("[sdf]", 0.0, NOPOINT);
 
+  test("[=10+10]", 0.0, 20.0);
+  
   // Vectors
   KstVector::generateVector(0, 1.0, 10, "1");
   KstVector::generateVector(0, 1.0, 10, "V1");
@@ -340,6 +342,9 @@ int main(int argc, char **argv) {
   KstVector::generateVector(-1.0, 1.0, 1000, "V4");
   KstVector::generateVector(-1.0, 1.0, 1000, "V5-%+-_!");
   test("[V2] - [V1]", 0.0, 1.0);
+  test("[V2[9]]", 0.0, 2.0);
+  test("[V2[5+4]]", 0.0, 2.0);
+  test("[V2[]]", 0.0, 1.0);
   test("2*sin([V5-%+-_!])", 0.0, -1.6829419696157930);
   // TODO: interpolation, more vector combinations
 
